@@ -1,4 +1,4 @@
-/* $ANTLR 2.7.6 (2005-12-22): "format.in.g" -> "FMTIn.cpp"$ */
+/* $ANTLR 2.7.7 (2006-11-01): "format.in.g" -> "FMTIn.cpp"$ */
 
 #include "includefirst.hpp"
 
@@ -77,7 +77,7 @@ void FMTIn::format(RefFMTNode _t) {
 	case TERM:
 	case NONL:
 	case Q: case T: case X: case A:
-	case F: case D: case E: case G:
+	case F: case D: case E: case SE: case G: case SG:
 	case I: case O: case B: case Z: case ZZ: case C:
 	{
 	f(_t);
@@ -132,7 +132,9 @@ void FMTIn::q(RefFMTNode _t) {
 	case A:
 	case F:
 	case E:
+	case SE:
 	case G:
+	case SG:
 	case I:
 	case O:
 	case B:
@@ -157,7 +159,9 @@ void FMTIn::f(RefFMTNode _t) {
 	RefFMTNode a = RefFMTNode(antlr::nullAST);
 	RefFMTNode ff = RefFMTNode(antlr::nullAST);
 	RefFMTNode ee = RefFMTNode(antlr::nullAST);
+	RefFMTNode se = RefFMTNode(antlr::nullAST);
 	RefFMTNode g = RefFMTNode(antlr::nullAST);
+	RefFMTNode sg = RefFMTNode(antlr::nullAST);
 	RefFMTNode i = RefFMTNode(antlr::nullAST);
 	RefFMTNode o = RefFMTNode(antlr::nullAST);
 	RefFMTNode b = RefFMTNode(antlr::nullAST);
@@ -257,7 +261,9 @@ void FMTIn::f(RefFMTNode _t) {
 	}
 	case F:
 	case E:
+	case SE:
 	case G:
+	case SG:
 	{
 		{
 		if (_t == RefFMTNode(antlr::nullAST) )
@@ -279,6 +285,14 @@ void FMTIn::f(RefFMTNode _t) {
 			actNode = ee;
 			break;
 		}
+		case SE:
+		{
+			se = _t;
+			match(antlr::RefAST(_t),SE);
+			_t = _t->getNextSibling();
+			actNode = se;
+			break;
+		}
 		case G:
 		{
 			g = _t;
@@ -287,6 +301,14 @@ void FMTIn::f(RefFMTNode _t) {
 			actNode = g;
 			break;
 		}
+		case SG:
+		{
+			sg = _t;
+			match(antlr::RefAST(_t),SG);
+			_t = _t->getNextSibling();
+			actNode = sg;
+			break;
+		}
 		default:
 		{
 			throw antlr::NoViableAltException(antlr::RefAST(_t));
@@ -418,29 +440,82 @@ void FMTIn::f(RefFMTNode _t) {
 	}
 	case C:
 	{
-		RefFMTNode __t18 = _t;
+		{
+		RefFMTNode __t19 = _t;
 		c = (_t == RefFMTNode(ASTNULL)) ? RefFMTNode(antlr::nullAST) : _t;
 		match(antlr::RefAST(_t),C);
 		_t = _t->getFirstChild();
-		{ // ( ... )+
-		int _cnt20=0;
-		for (;;) {
-			if (_t == RefFMTNode(antlr::nullAST) )
-				_t = ASTNULL;
-			if ((_tokenSet_1.member(_t->getType()))) {
-				csubcode(_t);
-				_t = _retTree;
+		
+		int r = c->getRep();  if (r<1) r=1;
+		if( actPar == NULL) break;
+		
+		{
+		if (_t == RefFMTNode(antlr::nullAST) )
+			_t = ASTNULL;
+		switch ( _t->getType()) {
+		case STRING:
+		case TL:
+		case TR:
+		case X:
+		case CMOA:
+		case CMoA:
+		case CmoA:
+		case CHI:
+		case ChI:
+		case CDWA:
+		case CDwA:
+		case CdwA:
+		case CAPA:
+		case CApA:
+		case CapA:
+		case CMOI:
+		case CDI:
+		case CYI:
+		case CMI:
+		case CSI:
+		case CSF:
+		{
+			{ // ( ... )+
+			int _cnt22=0;
+			for (;;) {
+				if (_t == RefFMTNode(antlr::nullAST) )
+					_t = ASTNULL;
+				if ((_tokenSet_1.member(_t->getType()))) {
+					calendar_code(_t,r);
+					_t = _retTree;
+				}
+				else {
+					if ( _cnt22>=1 ) { goto _loop22; } else {throw antlr::NoViableAltException(antlr::RefAST(_t));}
+				}
+				
+				_cnt22++;
 			}
-			else {
-				if ( _cnt20>=1 ) { goto _loop20; } else {throw antlr::NoViableAltException(antlr::RefAST(_t));}
-			}
-			
-			_cnt20++;
+			_loop22:;
+			}  // ( ... )+
+			break;
 		}
-		_loop20:;
-		}  // ( ... )+
-		_t = __t18;
+		case 3:
+		{
+			
+			if( actPar == NULL) break;
+			SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, 24, BaseGDL::DEFAULT);
+			
+			break;
+		}
+		default:
+		{
+			throw antlr::NoViableAltException(antlr::RefAST(_t));
+		}
+		}
+		}
+		
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, 0, BaseGDL::COMPUTE);
+		NextVal(tCount);
+		if( actPar == NULL) break;
+		
+		_t = __t19;
 		_t = _t->getNextSibling();
+		}
 		break;
 	}
 	default:
@@ -509,7 +584,7 @@ void FMTIn::format_recursive(RefFMTNode _t) {
 	case TERM:
 	case NONL:
 	case Q: case T: case X: case A:
-	case F: case D: case E: case G:
+	case F: case D: case E: case SE: case G: case SG:
 	case I: case O: case B: case Z: case ZZ: case C:
 	{
 	f(_t);
@@ -578,7 +653,7 @@ void FMTIn::format_reversion(RefFMTNode _t) {
 	case TERM:
 	case NONL:
 	case Q: case T: case X: case A:
-	case F: case D: case E: case G:
+	case F: case D: case E: case SE: case G: case SG:
 	case I: case O: case B: case Z: case ZZ: case C:
 	{
 	f(_t);
@@ -611,6 +686,11 @@ void FMTIn::f_csubcode(RefFMTNode _t) {
 		s = _t;
 		match(antlr::RefAST(_t),STRING);
 		_t = _t->getNextSibling();
+		
+				SizeT actP  = ioss.tellg(); 
+				int  strlen = s->getText().length();
+				ioss.seekg( actP + strlen);
+		
 		break;
 	}
 	case TL:
@@ -657,15 +737,17 @@ void FMTIn::x(RefFMTNode _t) {
 	
 	if( _t != static_cast<RefFMTNode>(antlr::nullAST))
 	{
-	int    tlVal = tl->getW();
+	int    tlVal = tl->getW();if (tlVal<1) tlVal=1;
 	ioss.seekg( tlVal, std::ios_base::cur);
 	}
 	
 	_retTree = _t;
 }
 
-void FMTIn::csubcode(RefFMTNode _t) {
-	RefFMTNode csubcode_AST_in = (_t == RefFMTNode(ASTNULL)) ? RefFMTNode(antlr::nullAST) : _t;
+void FMTIn::calendar_code(RefFMTNode _t,
+	SizeT r
+) {
+	RefFMTNode calendar_code_AST_in = (_t == RefFMTNode(ASTNULL)) ? RefFMTNode(antlr::nullAST) : _t;
 	RefFMTNode c1 = RefFMTNode(antlr::nullAST);
 	RefFMTNode c2 = RefFMTNode(antlr::nullAST);
 	RefFMTNode c3 = RefFMTNode(antlr::nullAST);
@@ -692,6 +774,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c1 = _t;
 		match(antlr::RefAST(_t),CMOA);
 		_t = _t->getNextSibling();
+		
+		int w = c1->getW(); if(w<1) w=3;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CMOA);
+		
 		break;
 	}
 	case CMoA:
@@ -699,6 +785,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c2 = _t;
 		match(antlr::RefAST(_t),CMoA);
 		_t = _t->getNextSibling();
+		
+		int w = c2->getW(); if(w<1) w=3;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CMoA);
+		
 		break;
 	}
 	case CmoA:
@@ -706,6 +796,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c3 = _t;
 		match(antlr::RefAST(_t),CmoA);
 		_t = _t->getNextSibling();
+		
+		int w = c3->getW(); if(w<1) w=3;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CmoA);
+		
 		break;
 	}
 	case CHI:
@@ -713,6 +807,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c4 = _t;
 		match(antlr::RefAST(_t),CHI);
 		_t = _t->getNextSibling();
+		
+		int w = c4->getW(); if(w<1) w=2;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CHI);
+		
 		break;
 	}
 	case ChI:
@@ -720,6 +818,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c5 = _t;
 		match(antlr::RefAST(_t),ChI);
 		_t = _t->getNextSibling();
+		
+		int w = c5->getW(); if(w<1) w=2;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::ChI);
+		
 		break;
 	}
 	case CDWA:
@@ -727,6 +829,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c6 = _t;
 		match(antlr::RefAST(_t),CDWA);
 		_t = _t->getNextSibling();
+		
+		int w = c6->getW(); if(w<1) w=3;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CDWA);
+		
 		break;
 	}
 	case CDwA:
@@ -734,6 +840,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c7 = _t;
 		match(antlr::RefAST(_t),CDwA);
 		_t = _t->getNextSibling();
+		
+		int w = c7->getW(); if(w<1) w=3;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CDwA);
+		
 		break;
 	}
 	case CdwA:
@@ -741,6 +851,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c8 = _t;
 		match(antlr::RefAST(_t),CdwA);
 		_t = _t->getNextSibling();
+		
+		int w = c8->getW(); if(w<1) w=3;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CdwA);
+		
 		break;
 	}
 	case CAPA:
@@ -748,6 +862,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c9 = _t;
 		match(antlr::RefAST(_t),CAPA);
 		_t = _t->getNextSibling();
+		
+		int w = c9->getW(); if(w<1) w=2;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CAPA);
+		
 		break;
 	}
 	case CApA:
@@ -755,6 +873,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c10 = _t;
 		match(antlr::RefAST(_t),CApA);
 		_t = _t->getNextSibling();
+		
+		int w = c10->getW(); if(w<1) w=2;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CApA);
+		
 		break;
 	}
 	case CapA:
@@ -762,6 +884,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c11 = _t;
 		match(antlr::RefAST(_t),CapA);
 		_t = _t->getNextSibling();
+		
+		int w = c11->getW(); if(w<1) w=2;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CapA);
+		
 		break;
 	}
 	case CMOI:
@@ -769,6 +895,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c12 = _t;
 		match(antlr::RefAST(_t),CMOI);
 		_t = _t->getNextSibling();
+		
+		int w = c12->getW(); if(w<1) w=2;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CMOI);
+		
 		break;
 	}
 	case CDI:
@@ -776,6 +906,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c13 = _t;
 		match(antlr::RefAST(_t),CDI);
 		_t = _t->getNextSibling();
+		
+		int w = c13->getW(); if(w<1) w=2;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CDI);
+		
 		break;
 	}
 	case CYI:
@@ -783,6 +917,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c14 = _t;
 		match(antlr::RefAST(_t),CYI);
 		_t = _t->getNextSibling();
+		
+		int w = c14->getW(); if(w<1) w=4;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CYI);
+		
 		break;
 	}
 	case CMI:
@@ -790,6 +928,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c15 = _t;
 		match(antlr::RefAST(_t),CMI);
 		_t = _t->getNextSibling();
+		
+		int w = c15->getW(); if(w<1) w=2;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CMI);
+		
 		break;
 	}
 	case CSI:
@@ -797,6 +939,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c16 = _t;
 		match(antlr::RefAST(_t),CSI);
 		_t = _t->getNextSibling();
+		
+		int w = c16->getW(); if(w<1) w=2;
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CSI);
+		
 		break;
 	}
 	case CSF:
@@ -804,6 +950,10 @@ void FMTIn::csubcode(RefFMTNode _t) {
 		c17 = _t;
 		match(antlr::RefAST(_t),CSF);
 		_t = _t->getNextSibling();
+		
+		int w = c17->getW(); 
+		SizeT tCount = actPar->IFmtCal( &ioss, valIx, r, w, BaseGDL::CSF);
+		
 		break;
 	}
 	case X:
@@ -836,7 +986,7 @@ const char* FMTIn::tokenNames[] = {
 	"EOF",
 	"<2>",
 	"NULL_TREE_LOOKAHEAD",
-	"ALL",
+	"CSTYLE",
 	"CSTR",
 	"CSTR1",
 	"CSTR2",
@@ -846,9 +996,11 @@ const char* FMTIn::tokenNames[] = {
 	"HEXESC",
 	"HDIGIT",
 	"CD",
+	"CSE",
 	"CE",
 	"CI",
 	"CF",
+	"CSG",
 	"CG",
 	"CO",
 	"CB",
@@ -856,6 +1008,10 @@ const char* FMTIn::tokenNames[] = {
 	"CX",
 	"CZ",
 	"CDOT",
+	"PM",
+	"MP",
+	"PLUS",
+	"MOINS",
 	"DIGITS",
 	"CNUMBER",
 	"CWS",
@@ -876,7 +1032,9 @@ const char* FMTIn::tokenNames[] = {
 	"F",
 	"D",
 	"E",
+	"SE",
 	"G",
+	"SG",
 	"I",
 	"O",
 	"B",
@@ -894,12 +1052,12 @@ const char* FMTIn::tokenNames[] = {
 	"CAPA",
 	"CApA",
 	"CapA",
-	"\"cmoi\"",
-	"\"cdi\"",
-	"\"cyi\"",
-	"\"cmi\"",
-	"\"csi\"",
-	"\"csf\"",
+	"CMOI",
+	"CDI",
+	"CYI",
+	"CMI",
+	"CSI",
+	"CSF",
 	"NUMBER",
 	"DOT",
 	"CSTRING",
@@ -913,12 +1071,12 @@ const char* FMTIn::tokenNames[] = {
 	0
 };
 
-const unsigned long FMTIn::_tokenSet_0_data_[] = { 134217728UL, 523263UL, 0UL, 0UL };
-// FORMAT STRING "tl" "tr" TERM NONL Q T X A F E G I O B Z ZZ C 
+const unsigned long FMTIn::_tokenSet_0_data_[] = { 0UL, 134152130UL, 0UL, 0UL };
+// FORMAT STRING "tl" "tr" TERM NONL Q T X A F E SE G SG I O B Z ZZ C 
 const antlr::BitSet FMTIn::_tokenSet_0(_tokenSet_0_data_,4);
-const unsigned long FMTIn::_tokenSet_1_data_[] = { 0UL, 4294443143UL, 15UL, 0UL, 0UL, 0UL, 0UL, 0UL };
+const unsigned long FMTIn::_tokenSet_1_data_[] = { 0UL, 4160758208UL, 4095UL, 0UL, 0UL, 0UL, 0UL, 0UL };
 // STRING "tl" "tr" X CMOA CMoA CmoA CHI ChI CDWA CDwA CdwA CAPA CApA CapA 
-// "cmoi" "cdi" "cyi" "cmi" "csi" "csf" 
+// CMOI CDI CYI CMI CSI CSF 
 const antlr::BitSet FMTIn::_tokenSet_1(_tokenSet_1_data_,8);
 
 
