@@ -3,7 +3,7 @@
 
 #include <antlr/config.hpp>
 #include "FMTInTokenTypes.hpp"
-/* $ANTLR 2.7.6 (2005-12-22): "format.in.g" -> "FMTIn.hpp"$ */
+/* $ANTLR 2.7.7 (2006-11-01): "format.in.g" -> "FMTIn.hpp"$ */
 #include <antlr/TreeParser.hpp>
 
 
@@ -223,7 +223,9 @@ public:
 	public: void format_reversion(RefFMTNode _t);
 	public: void f_csubcode(RefFMTNode _t);
 	public: void x(RefFMTNode _t);
-	public: void csubcode(RefFMTNode _t);
+	public: void calendar_code(RefFMTNode _t,
+		SizeT r
+	);
 public:
 	antlr::RefAST getAST()
 	{
@@ -236,10 +238,10 @@ protected:
 private:
 	static const char* tokenNames[];
 #ifndef NO_STATIC_CONSTS
-	static const int NUM_TOKENS = 78;
+	static const int NUM_TOKENS = 86;
 #else
 	enum {
-		NUM_TOKENS = 78
+		NUM_TOKENS = 86
 	};
 #endif
 	
