@@ -1,4 +1,4 @@
-/* $ANTLR 2.7.7 (20130428): "format.g" -> "FMTLexer.cpp"$ */
+/* $ANTLR 2.7.7 (2006-11-01): "format.g" -> "FMTLexer.cpp"$ */
 
 #include "includefirst.hpp"
 
@@ -31,8 +31,8 @@ FMTLexer::FMTLexer(const antlr::LexerSharedInputState& state)
 
 void FMTLexer::initLiterals()
 {
-	literals["tl"] = 33;
-	literals["tr"] = 34;
+	literals["tl"] = 39;
+	literals["tr"] = 40;
 }
 
 antlr::RefToken FMTLexer::nextToken()
@@ -109,19 +109,29 @@ antlr::RefToken FMTLexer::nextToken()
 				break;
 			}
 			case 0x45 /* 'E' */ :
-			case 0x65 /* 'e' */ :
 			{
 				mE(true);
 				theRetToken=_returnToken;
 				break;
 			}
+			case 0x65 /* 'e' */ :
+			{
+				mSE(true);
+				theRetToken=_returnToken;
+				break;
+			}
 			case 0x47 /* 'G' */ :
-			case 0x67 /* 'g' */ :
 			{
 				mG(true);
 				theRetToken=_returnToken;
 				break;
 			}
+			case 0x67 /* 'g' */ :
+			{
+				mSG(true);
+				theRetToken=_returnToken;
+				break;
+			}
 			case 0x49 /* 'I' */ :
 			case 0x69 /* 'i' */ :
 			{
@@ -299,18 +309,18 @@ antlr::RefToken FMTLexer::nextToken()
 					mPERCENT(true);
 					theRetToken=_returnToken;
 				}
-				else if ((_tokenSet_0.member(LA(1))) && (true)) {
+				else if ((LA(1) == 0x2b /* '+' */ ) && (true)) {
+					mPLUS(true);
+					theRetToken=_returnToken;
+				}
+				else if ((LA(1) == 0x2d /* '-' */ ) && (true)) {
+					mMOINS(true);
+					theRetToken=_returnToken;
+				}
+				else {
 					mNUMBER(true);
 					theRetToken=_returnToken;
 				}
-			else {
-				if (LA(1)==EOF_CHAR)
-				{
-					uponEOF();
-					_returnToken = makeToken(antlr::Token::EOF_TYPE);
-				}
-				else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
-			}
 			}
 			if ( !_returnToken )
 				goto tryAgain; // found SKIP token
@@ -352,17 +362,17 @@ void FMTLexer::mSTRING(bool _createToken) {
 				match('\"' /* charlit */ );
 				text.erase(_saveIndex);
 			}
-			else if ((_tokenSet_1.member(LA(1)))) {
+			else if ((_tokenSet_0.member(LA(1)))) {
 				{
-				match(_tokenSet_1);
+				match(_tokenSet_0);
 				}
 			}
 			else {
-				goto _loop54;
+				goto _loop59;
 			}
 			
 		}
-		_loop54:;
+		_loop59:;
 		} // ( ... )*
 		_saveIndex = text.length();
 		match('\"' /* charlit */ );
@@ -382,17 +392,17 @@ void FMTLexer::mSTRING(bool _createToken) {
 				match('\'' /* charlit */ );
 				text.erase(_saveIndex);
 			}
-			else if ((_tokenSet_2.member(LA(1)))) {
+			else if ((_tokenSet_1.member(LA(1)))) {
 				{
-				match(_tokenSet_2);
+				match(_tokenSet_1);
 				}
 			}
 			else {
-				goto _loop57;
+				goto _loop62;
 			}
 			
 		}
-		_loop57:;
+		_loop62:;
 		} // ( ... )*
 		_saveIndex = text.length();
 		match('\'' /* charlit */ );
@@ -630,22 +640,23 @@ void FMTLexer::mE(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	switch ( LA(1)) {
-	case 0x65 /* 'e' */ :
+	match('E' /* charlit */ );
+	}
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mSE(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = SE;
+	std::string::size_type _saveIndex;
+	
 	{
-		match('e' /* charlit */ );
-		break;
-	}
-	case 0x45 /* 'E' */ :
-	{
-		match('E' /* charlit */ );
-		break;
-	}
-	default:
-	{
-		throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());
-	}
-	}
+	match('e' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -661,22 +672,23 @@ void FMTLexer::mG(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	switch ( LA(1)) {
-	case 0x67 /* 'g' */ :
+	match('G' /* charlit */ );
+	}
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mSG(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = SG;
+	std::string::size_type _saveIndex;
+	
 	{
-		match('g' /* charlit */ );
-		break;
-	}
-	case 0x47 /* 'G' */ :
-	{
-		match('G' /* charlit */ );
-		break;
-	}
-	default:
-	{
-		throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());
-	}
-	}
+	match('g' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1406,6 +1418,34 @@ void FMTLexer::mMP(bool _createToken) {
 	_saveIndex=0;
 }
 
+void FMTLexer::mPLUS(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = PLUS;
+	std::string::size_type _saveIndex;
+	
+	match('+' /* charlit */ );
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mMOINS(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = MOINS;
+	std::string::size_type _saveIndex;
+	
+	match('-' /* charlit */ );
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
 void FMTLexer::mW(bool _createToken) {
 	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
 	_ttype = W;
@@ -1443,18 +1483,18 @@ void FMTLexer::mWHITESPACE(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{ // ( ... )+
-	int _cnt143=0;
+	int _cnt154=0;
 	for (;;) {
 		if ((LA(1) == 0x9 /* '\t' */  || LA(1) == 0x20 /* ' ' */ )) {
 			mW(false);
 		}
 		else {
-			if ( _cnt143>=1 ) { goto _loop143; } else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
+			if ( _cnt154>=1 ) { goto _loop154; } else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
 		}
 		
-		_cnt143++;
+		_cnt154++;
 	}
-	_loop143:;
+	_loop154:;
 	}  // ( ... )+
 	_ttype=antlr::Token::SKIP;
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
@@ -1471,18 +1511,18 @@ void FMTLexer::mDIGITS(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{ // ( ... )+
-	int _cnt146=0;
+	int _cnt157=0;
 	for (;;) {
 		if (((LA(1) >= 0x30 /* '0' */  && LA(1) <= 0x39 /* '9' */ ))) {
 			matchRange('0','9');
 		}
 		else {
-			if ( _cnt146>=1 ) { goto _loop146; } else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
+			if ( _cnt157>=1 ) { goto _loop157; } else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
 		}
 		
-		_cnt146++;
+		_cnt157++;
 	}
-	_loop146:;
+	_loop157:;
 	}  // ( ... )+
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1514,85 +1554,49 @@ void FMTLexer::mNUMBER(bool _createToken) {
 	std::string::size_type _saveIndex;
 	antlr::RefToken num;
 	
-	SizeT n;
+	SizeT n = -1;
 	SizeT i = 0;
-	bool uPlus = false;
-	bool uMinus = false;
 	
 	
 	{
-	switch ( LA(1)) {
-	case 0x2d /* '-' */ :
-	{
-		match('-' /* charlit */ );
-		
-		uMinus = true;
-		
-		break;
-	}
-	case 0x2b /* '+' */ :
-	{
-		match('+' /* charlit */ );
-		
-		uPlus = true;
-		
-		break;
-	}
-	case 0x30 /* '0' */ :
-	case 0x31 /* '1' */ :
-	case 0x32 /* '2' */ :
-	case 0x33 /* '3' */ :
-	case 0x34 /* '4' */ :
-	case 0x35 /* '5' */ :
-	case 0x36 /* '6' */ :
-	case 0x37 /* '7' */ :
-	case 0x38 /* '8' */ :
-	case 0x39 /* '9' */ :
-	{
-		break;
-	}
-	default:
-	{
-		throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());
-	}
-	}
-	}
-	mDIGITS(true);
-	num=_returnToken;
-	
-	if( uMinus) num->setText( "-" + num->getText());
-	if( uPlus) num->setText( "+" + num->getText());
-	
-	{
-	if ((LA(1) == 0x48 /* 'H' */ )) {
-		
-		_ttype = STRING; 
-		std::istringstream s(num->getText());
-		s >> n;
-		{ text.erase(_begin); text += ""; }; // clear string (remove number)
-		
-		_saveIndex = text.length();
-		match('H' /* charlit */ );
-		text.erase(_saveIndex);
-		{ // ( ... )+
-		int _cnt153=0;
-		for (;;) {
-			// init action gets executed even in guessing mode
-			if( i == n )
-			break;
-			i++; // count chars here so that guessing mode works
+	if (((LA(1) >= 0x30 /* '0' */  && LA(1) <= 0x39 /* '9' */ ))) {
+		mDIGITS(true);
+		num=_returnToken;
+		{
+		if ((LA(1) == 0x48 /* 'H' */  || LA(1) == 0x68 /* 'h' */ )) {
 			
-			if (((LA(1) >= 0x3 /* '\3' */  && LA(1) <= 0xff))) {
-				mCHAR(false);
-			}
-			else {
-				if ( _cnt153>=1 ) { goto _loop153; } else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
-			}
+			_ttype = STRING; 
+			std::istringstream s(num->getText());
+			s >> n;
+			{ text.erase(_begin); text += ""; }; // clear string (remove number)
 			
-			_cnt153++;
+			_saveIndex = text.length();
+			mH(false);
+			text.erase(_saveIndex);
+			{ // ( ... )+
+			int _cnt164=0;
+			for (;;) {
+				// init action gets executed even in guessing mode
+				if( i == n )
+				break;
+				i++; // count chars here so that guessing mode works
+				
+				if (((LA(1) >= 0x3 /* '\3' */  && LA(1) <= 0xff))) {
+					mCHAR(false);
+				}
+				else {
+					if ( _cnt164>=1 ) { goto _loop164; } else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
+				}
+				
+				_cnt164++;
+			}
+			_loop164:;
+			}  // ( ... )+
+		}
+		else {
+		}
+		
 		}
-		_loop153:;
-		}  // ( ... )+
 	}
 	else {
 	}
@@ -1607,19 +1611,16 @@ void FMTLexer::mNUMBER(bool _createToken) {
 }
 
 
-const unsigned long FMTLexer::_tokenSet_0_data_[] = { 0UL, 67053568UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
-// + - 0 1 2 3 4 5 6 7 8 9 
-const antlr::BitSet FMTLexer::_tokenSet_0(_tokenSet_0_data_,10);
-const unsigned long FMTLexer::_tokenSet_1_data_[] = { 4294967288UL, 4294967291UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
+const unsigned long FMTLexer::_tokenSet_0_data_[] = { 4294967288UL, 4294967291UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
 // 0x3 0x4 0x5 0x6 0x7 0x8 0x9 0xa 0xb 0xc 0xd 0xe 0xf 0x10 0x11 0x12 0x13 
 // 0x14 0x15 0x16 0x17 0x18 0x19 0x1a 0x1b 0x1c 0x1d 0x1e 0x1f   ! # $ 
 // % & \' ( ) * + , - . / 0 1 2 3 4 5 6 7 8 9 : ; < = > ? @ A B C D E F 
-// G H I J K L M N O 
-const antlr::BitSet FMTLexer::_tokenSet_1(_tokenSet_1_data_,16);
-const unsigned long FMTLexer::_tokenSet_2_data_[] = { 4294967288UL, 4294967167UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
+// G H I J K L M N O P Q R S T U 
+const antlr::BitSet FMTLexer::_tokenSet_0(_tokenSet_0_data_,16);
+const unsigned long FMTLexer::_tokenSet_1_data_[] = { 4294967288UL, 4294967167UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
 // 0x3 0x4 0x5 0x6 0x7 0x8 0x9 0xa 0xb 0xc 0xd 0xe 0xf 0x10 0x11 0x12 0x13 
 // 0x14 0x15 0x16 0x17 0x18 0x19 0x1a 0x1b 0x1c 0x1d 0x1e 0x1f   ! \" # 
 // $ % & ( ) * + , - . / 0 1 2 3 4 5 6 7 8 9 : ; < = > ? @ A B C D E F 
-// G H I J K L M N O 
-const antlr::BitSet FMTLexer::_tokenSet_2(_tokenSet_2_data_,16);
+// G H I J K L M N O P Q R S T U 
+const antlr::BitSet FMTLexer::_tokenSet_1(_tokenSet_1_data_,16);
 
