@@ -70,7 +70,7 @@ void FMTOut::format(RefFMTNode _t) {
 	case TERM:
 	case NONL:
 	case Q: case T: case X: case A:
-	case F: case D: case E: case G:
+	case F: case D: case E: case SE: case G: case SG:
 	case I: case O: case B: case Z: case ZZ: case C:
 	{
 	if( actPar == NULL && termFlag) goto endFMT;
@@ -136,7 +136,9 @@ void FMTOut::q(RefFMTNode _t) {
 	case A:
 	case F:
 	case E:
+	case SE:
 	case G:
+	case SG:
 	case I:
 	case O:
 	case B:
@@ -160,7 +162,9 @@ void FMTOut::f(RefFMTNode _t) {
 	RefFMTNode t = RefFMTNode(antlr::nullAST);
 	RefFMTNode a = RefFMTNode(antlr::nullAST);
 	RefFMTNode ff = RefFMTNode(antlr::nullAST);
+	RefFMTNode se = RefFMTNode(antlr::nullAST);
 	RefFMTNode ee = RefFMTNode(antlr::nullAST);
+	RefFMTNode sg = RefFMTNode(antlr::nullAST);
 	RefFMTNode g = RefFMTNode(antlr::nullAST);
 	RefFMTNode i = RefFMTNode(antlr::nullAST);
 	RefFMTNode o = RefFMTNode(antlr::nullAST);
@@ -237,8 +241,9 @@ void FMTOut::f(RefFMTNode _t) {
 		
 		int r = a->getRep();
 		int w = a->getW();
+		int c = a->getCode();
 		do {
-		SizeT tCount = actPar->OFmtA( os, valIx, r, w);
+		SizeT tCount = actPar->OFmtA( os, valIx, r, w, c);
 		r -= tCount;
 		NextVal( tCount);
 		if( actPar == NULL) break;
@@ -257,9 +262,30 @@ void FMTOut::f(RefFMTNode _t) {
 		int r = ff->getRep();
 		int w = ff->getW();
 		int d = ff->getD();
-		char f = ff->getFill();
+		int c = ff->getCode();
 		do {
-		SizeT tCount = actPar->OFmtF( os, valIx, r, w, d, f);
+		SizeT tCount = actPar->OFmtF( os, valIx, r, w, d, c, BaseGDL::FIXED);
+		r -= tCount;
+		NextVal( tCount);
+		if( actPar == NULL) break;
+		} while( r>0);
+		
+		break;
+	}
+	case SE:
+	{
+		se = _t;
+		match(antlr::RefAST(_t),SE);
+		_t = _t->getNextSibling();
+		
+		if( actPar == NULL) break;
+		
+		int r = se->getRep();
+		int w = se->getW();
+		int d = se->getD();
+		int c = se->getCode();
+		do {
+		SizeT tCount = actPar->OFmtF( os, valIx, r, w, d, c, BaseGDL::SCIENTIFIC);
 		r -= tCount;
 		NextVal( tCount);
 		if( actPar == NULL) break;
@@ -278,10 +304,31 @@ void FMTOut::f(RefFMTNode _t) {
 		int r = ee->getRep();
 		int w = ee->getW();
 		int d = ee->getD();
-		char f = ee->getFill();
+		ee->setUpper();  //'E' in uppercase
+		int c = ee->getCode();
 		do {
-		SizeT tCount = actPar->OFmtF( os, valIx, r, w, d, f,
-		BaseGDL::SCIENTIFIC);
+		SizeT tCount = actPar->OFmtF( os, valIx, r, w, d, c, BaseGDL::SCIENTIFIC);
+		r -= tCount;
+		NextVal( tCount);
+		if( actPar == NULL) break;
+		} while( r>0);
+		
+		break;
+	}
+	case SG:
+	{
+		sg = _t;
+		match(antlr::RefAST(_t),SG);
+		_t = _t->getNextSibling();
+		
+		if( actPar == NULL) break;
+		
+		int r = sg->getRep();
+		int w = sg->getW();
+		int d = sg->getD();
+		int c = sg->getCode();
+		do {
+		SizeT tCount = actPar->OFmtF( os, valIx, r, w, d, c, BaseGDL::AUTO);
 		r -= tCount;
 		NextVal( tCount);
 		if( actPar == NULL) break;
@@ -300,10 +347,10 @@ void FMTOut::f(RefFMTNode _t) {
 		int r = g->getRep();
 		int w = g->getW();
 		int d = g->getD();
-		int f = g->getFill();
+		g->setUpper();  //'E' in uppercase
+		int c = g->getCode();
 		do {
-		SizeT tCount = actPar->OFmtF( os, valIx, r, w, d, f,
-		BaseGDL::AUTO);
+		SizeT tCount = actPar->OFmtF( os, valIx, r, w, d, c, BaseGDL::AUTO);
 		r -= tCount;
 		NextVal( tCount);
 		if( actPar == NULL) break;
@@ -322,10 +369,9 @@ void FMTOut::f(RefFMTNode _t) {
 		int r = i->getRep();
 		int w = i->getW();
 		int d = i->getD();
-		int f = i->getFill();
+		int c = i->getCode();
 		do {
-		SizeT tCount = actPar->OFmtI( os, valIx, r, w, d, f,
-		BaseGDL::DEC);
+		SizeT tCount = actPar->OFmtI( os, valIx, r, w, d, c, BaseGDL::DEC);
 		r -= tCount;
 		NextVal( tCount);
 		if( actPar == NULL) break;
@@ -344,10 +390,9 @@ void FMTOut::f(RefFMTNode _t) {
 		int r = o->getRep();
 		int w = o->getW();
 		int d = o->getD();
-		int f = o->getFill();
+		int c = o->getCode();
 		do {
-		SizeT tCount = actPar->OFmtI( os, valIx, r, w, d, f,
-		BaseGDL::OCT);
+		SizeT tCount = actPar->OFmtI( os, valIx, r, w, d, c, BaseGDL::OCT);
 		r -= tCount;
 		NextVal( tCount);
 		if( actPar == NULL) break;
@@ -366,10 +411,9 @@ void FMTOut::f(RefFMTNode _t) {
 		int r = b->getRep();
 		int w = b->getW();
 		int d = b->getD();
-		int f = b->getFill();
+		int c = b->getCode();
 		do {
-		SizeT tCount = actPar->OFmtI( os, valIx, r, w, d, f,
-		BaseGDL::BIN);
+		SizeT tCount = actPar->OFmtI( os, valIx, r, w, d, c, BaseGDL::BIN);
 		r -= tCount;
 		NextVal( tCount);
 		if( actPar == NULL) break;
@@ -388,10 +432,9 @@ void FMTOut::f(RefFMTNode _t) {
 		int r = z->getRep();
 		int w = z->getW();
 		int d = z->getD();
-		int f = z->getFill();
+		int c = z->getCode();
 		do {
-		SizeT tCount = actPar->OFmtI( os, valIx, r, w, d, f,
-		BaseGDL::HEX);
+		SizeT tCount = actPar->OFmtI( os, valIx, r, w, d, c, BaseGDL::HEX);
 		r -= tCount;
 		NextVal( tCount);
 		if( actPar == NULL) break;
@@ -410,10 +453,9 @@ void FMTOut::f(RefFMTNode _t) {
 		int r = zz->getRep();
 		int w = zz->getW();
 		int d = zz->getD();
-		int f = zz->getFill();
+		int c = zz->getCode();
 		do {
-		SizeT tCount = actPar->OFmtI( os, valIx, r, w, d, f,
-		BaseGDL::HEXL);
+		SizeT tCount = actPar->OFmtI( os, valIx, r, w, d, c, BaseGDL::HEXL);
 		r -= tCount;
 		NextVal( tCount);
 		if( actPar == NULL) break;
@@ -433,7 +475,7 @@ void FMTOut::f(RefFMTNode _t) {
 		if( actPar == NULL) break;
 		SizeT nTrans = actPar->ToTransfer();
 		if (r > nTrans) r=nTrans;
-		actPar->OFmtCal( os, valIx, r, 0, 0, NULL, BaseGDL::COMPUTE); //convert to hour, min, etc
+		actPar->OFmtCal( os, valIx, r, 0, 0, NULL, 0, BaseGDL::COMPUTE); //convert to hour, min, etc
 		
 		{
 		if (_t == RefFMTNode(antlr::nullAST) )
@@ -465,7 +507,7 @@ void FMTOut::f(RefFMTNode _t) {
 				if (_t == RefFMTNode(antlr::nullAST) )
 					_t = ASTNULL;
 				if ((_tokenSet_1.member(_t->getType()))) {
-					csubcode(_t,r);
+					calendar_code(_t,r);
 					_t = _retTree;
 				}
 				else {
@@ -482,7 +524,7 @@ void FMTOut::f(RefFMTNode _t) {
 		{
 			
 			if( actPar == NULL) break;
-			actPar->OFmtCal( os, valIx, r, 0, 0, NULL, BaseGDL::DEFAULT);
+			actPar->OFmtCal( os, valIx, r, 0, 0, NULL, 0, BaseGDL::DEFAULT);
 			
 			break;
 		}
@@ -494,7 +536,7 @@ void FMTOut::f(RefFMTNode _t) {
 		}
 		
 		if( actPar == NULL) break;
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, 0, 0, NULL, BaseGDL::WRITE); //Write the complete formatted string to os.
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, 0, 0, NULL, 0, BaseGDL::WRITE); //Write the complete formatted string to os.
 		NextVal( tCount);
 		if( actPar == NULL) break;
 		
@@ -556,7 +598,7 @@ void FMTOut::format_reversion(RefFMTNode _t) {
 	case TERM:
 	case NONL:
 	case Q: case T: case X: case A:
-	case F: case D: case E: case G:
+	case F: case D: case E: case SE: case G: case SG:
 	case I: case O: case B: case Z: case ZZ: case C:
 	{
 	f(_t);
@@ -636,23 +678,23 @@ void FMTOut::x(RefFMTNode _t) {
 	match(antlr::RefAST(_t),X);
 	_t = _t->getNextSibling();
 	
-	if( _t != static_cast<RefFMTNode>(antlr::nullAST))
-	{
-	int    tlVal = tl->getW();
-	(*os) << " "; //for format "X" (no width)
-	for( int i=tlVal; i>1; --i)
-	(*os) << " "; //for format "nX"
-	//                os->seekp( tlVal, std::ios_base::cur);
-	}
-	// for( int r=x->getW(); r > 0; r--) (*os) << ' ';
+	//            if( _t != static_cast<RefFMTNode>(antlr::nullAST))
+	//            {
+	//                int    tlVal = #tl->getW();
+	//                (*os) << " "; //for format "X" (no width)
+	//                for( int i=tlVal; i>1; --i)
+	//                (*os) << " "; //for format "nX"
+	////                os->seekp( tlVal, std::ios_base::cur);
+	//            }
+	for( int r=tl->getW(); r > 0; r--) (*os) << ' ';
 	
 	_retTree = _t;
 }
 
-void FMTOut::csubcode(RefFMTNode _t,
+void FMTOut::calendar_code(RefFMTNode _t,
 	SizeT r
 ) {
-	RefFMTNode csubcode_AST_in = (_t == RefFMTNode(ASTNULL)) ? RefFMTNode(antlr::nullAST) : _t;
+	RefFMTNode calendar_code_AST_in = (_t == RefFMTNode(ASTNULL)) ? RefFMTNode(antlr::nullAST) : _t;
 	RefFMTNode c1 = RefFMTNode(antlr::nullAST);
 	RefFMTNode c2 = RefFMTNode(antlr::nullAST);
 	RefFMTNode c3 = RefFMTNode(antlr::nullAST);
@@ -685,8 +727,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		if( actPar == NULL) break;
 		int w = c1->getW();
 		int d = c1->getD();
-		char f = c1->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CMOA);
+		int c = c1->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CMOA);
 		
 		break;
 	}
@@ -700,8 +742,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c2->getW();
 		int d = c2->getD();
-		char f = c2->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CMoA);
+		int c = c2->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CMoA);
 		
 		break;
 	}
@@ -715,8 +757,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c3->getW();
 		int d = c3->getD();
-		char f = c3->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CmoA);
+		int c = c3->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CmoA);
 		
 		break;
 	}
@@ -730,8 +772,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c4->getW();
 		int d = c4->getD();
-		char f = c4->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CHI);
+		int c = c4->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CHI);
 		
 		break;
 	}
@@ -745,8 +787,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c5->getW();
 		int d = c5->getD();
-		char f = c5->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::ChI);
+		int c = c5->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::ChI);
 		
 		break;
 	}
@@ -760,8 +802,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c6->getW();
 		int d = c6->getD();
-		char f = c6->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CDWA);
+		int c = c6->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CDWA);
 		
 		break;
 	}
@@ -775,8 +817,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c7->getW();
 		int d = c7->getD();
-		char f = c7->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CDwA);
+		int c = c7->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CDwA);
 		
 		break;
 	}
@@ -790,8 +832,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c8->getW();
 		int d = c8->getD();
-		char f = c8->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CdwA);
+		int c = c8->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CdwA);
 		
 		break;
 	}
@@ -805,8 +847,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c9->getW();
 		int d = c9->getD();
-		char f = c9->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CAPA);
+		int c = c9->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CAPA);
 		
 		break;
 	}
@@ -820,8 +862,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c10->getW();
 		int d = c10->getD();
-		char f = c10->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CApA);
+		int c = c10->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CApA);
 		
 		break;
 	}
@@ -835,8 +877,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c11->getW();
 		int d = c11->getD();
-		char f = c11->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CapA);
+		int c = c11->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CapA);
 		
 		break;
 	}
@@ -850,8 +892,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c12->getW();
 		int d = c12->getD();
-		char f = c12->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CMOI);
+		int c = c12->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CMOI);
 		
 		break;
 	}
@@ -865,8 +907,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c13->getW();
 		int d = c13->getD();
-		char f = c13->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CDI);
+		int c = c13->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CDI);
 		
 		break;
 	}
@@ -880,8 +922,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c14->getW();
 		int d = c14->getD();
-		char f = c14->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CYI);
+		int c = c14->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CYI);
 		
 		break;
 	}
@@ -895,8 +937,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c15->getW();
 		int d = c15->getD();
-		char f = c15->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CMI);
+		int c = c15->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CMI);
 		
 		break;
 	}
@@ -910,8 +952,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		
 		int w = c16->getW();
 		int d = c16->getD();
-		char f = c16->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CSI);
+		int c = c16->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CSI);
 		
 		break;
 	}
@@ -924,8 +966,8 @@ void FMTOut::csubcode(RefFMTNode _t,
 		if( actPar == NULL) break;
 		int w = c17->getW();
 		int d = c17->getD();
-		char f = c17->getFill();
-		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, &f, BaseGDL::CSF);
+		int c = c17->getCode();
+		SizeT tCount = actPar->OFmtCal( os, valIx, r, w, d, NULL, c, BaseGDL::CSF);
 		
 		break;
 	}
@@ -950,7 +992,7 @@ void FMTOut::csubcode(RefFMTNode _t,
 		_t = _t->getNextSibling();
 		
 				if( actPar == NULL) break;
-				SizeT tCount = actPar->OFmtCal( os, valIx, r, 0, 0, (char*)c19->getText().c_str(), BaseGDL::STRING);
+				SizeT tCount = actPar->OFmtCal( os, valIx, r, 0, 0, (char*)c19->getText().c_str(), 0, BaseGDL::STRING);
 		
 		break;
 	}
@@ -970,7 +1012,7 @@ const char* FMTOut::tokenNames[] = {
 	"EOF",
 	"<2>",
 	"NULL_TREE_LOOKAHEAD",
-	"ALL",
+	"CSTYLE",
 	"CSTR",
 	"CSTR1",
 	"CSTR2",
@@ -980,9 +1022,11 @@ const char* FMTOut::tokenNames[] = {
 	"HEXESC",
 	"HDIGIT",
 	"CD",
+	"CSE",
 	"CE",
 	"CI",
 	"CF",
+	"CSG",
 	"CG",
 	"CO",
 	"CB",
@@ -990,6 +1034,10 @@ const char* FMTOut::tokenNames[] = {
 	"CX",
 	"CZ",
 	"CDOT",
+	"PM",
+	"MP",
+	"PLUS",
+	"MOINS",
 	"DIGITS",
 	"CNUMBER",
 	"CWS",
@@ -1010,7 +1058,9 @@ const char* FMTOut::tokenNames[] = {
 	"F",
 	"D",
 	"E",
+	"SE",
 	"G",
+	"SG",
 	"I",
 	"O",
 	"B",
@@ -1047,10 +1097,10 @@ const char* FMTOut::tokenNames[] = {
 	0
 };
 
-const unsigned long FMTOut::_tokenSet_0_data_[] = { 134217728UL, 523263UL, 0UL, 0UL };
-// FORMAT STRING "tl" "tr" TERM NONL Q T X A F E G I O B Z ZZ C 
+const unsigned long FMTOut::_tokenSet_0_data_[] = { 0UL, 134152130UL, 0UL, 0UL };
+// FORMAT STRING "tl" "tr" TERM NONL Q T X A F E SE G SG I O B Z ZZ C 
 const antlr::BitSet FMTOut::_tokenSet_0(_tokenSet_0_data_,4);
-const unsigned long FMTOut::_tokenSet_1_data_[] = { 0UL, 4294443137UL, 15UL, 0UL, 0UL, 0UL, 0UL, 0UL };
+const unsigned long FMTOut::_tokenSet_1_data_[] = { 0UL, 4160757824UL, 4095UL, 0UL, 0UL, 0UL, 0UL, 0UL };
 // STRING X CMOA CMoA CmoA CHI ChI CDWA CDwA CdwA CAPA CApA CapA CMOI CDI 
 // CYI CMI CSI CSF 
 const antlr::BitSet FMTOut::_tokenSet_1(_tokenSet_1_data_,8);
