@@ -3,7 +3,7 @@
 
 #include <antlr/config.hpp>
 #include "GDLInterpreterTokenTypes.hpp"
-/* $ANTLR 2.7.7 (20130428): "gdlc.i.g" -> "GDLInterpreter.hpp"$ */
+/* $ANTLR 2.7.7 (2006-11-01): "gdlc.i.g" -> "GDLInterpreter.hpp"$ */
 #include <antlr/TreeParser.hpp>
 
 
@@ -34,7 +34,8 @@
 //#define GDL_DEBUG
 //#undef GDL_DEBUG
 //#define GDL_DEBUG_HEAP
-
+bool IsEnabledGC(); // defined in GDLInterpreter.hpp with EnableGC(bool);
+void EnableGC(bool);
 
 class CUSTOM_API GDLInterpreter : public antlr::TreeParser, public GDLInterpreterTokenTypes
 {
@@ -47,6 +48,7 @@ private:
     friend class BaseGDL;
     friend class ProgNode;
     friend class ARRAYDEFNode;
+    friend class ARRAYDEF_GENERALIZED_INDGENNode;
     friend class STRUCNode;
     friend class NSTRUCNode;
     friend class NSTRUC_REFNode;
@@ -114,7 +116,7 @@ public:
     static bool SearchCompilePro(const std::string& pro, bool searchForPro); 
     static int GetFunIx( ProgNodeP);
     static int GetFunIx( const std::string& subName);
-    static int GetProIx( ProgNodeP);//const std::string& subName);
+    static int GetProIx( ProgNodeP, bool throwImmediately=false);//const std::string& subName);
     static int GetProIx( const std::string& subName);
     DStructGDL* ObjectStruct( DObjGDL* self, ProgNodeP mp);
     void SetRootR( ProgNodeP tt, DotAccessDescT* aD, BaseGDL* r, ArrayIndexListT* aL);
@@ -128,7 +130,7 @@ public:
 
 private: 
 
-    static void SetProIx( ProgNodeP f); // triggers read/compile
+    static void SetProIx( ProgNodeP f, bool throwImmediately=false); // triggers read/compile
     static void AdjustTypes( BaseGDL*&, BaseGDL*&);
 
 
@@ -224,6 +226,9 @@ public:
 //         return false;
 //     }
 
+//   static bool IsEnabledGC() { return enable_GC;}
+	static bool IsEnabledGC() { return true;}
+
     // the New... functions 'own' their BaseGDL*
     SizeT NewObjHeap( SizeT n=1, DStructGDL* var=NULL)
     {
@@ -302,17 +307,98 @@ public:
        }
     }
 
-   static void DecRef( DPtr id)
+   static DByteGDL* IsEnabledGC( DPtrGDL* p)
+   {
+		SizeT nEl=p->N_Elements();
+		if( nEl == 0) return new DByteGDL( 0);
+		DByteGDL* ret = new DByteGDL( p->Dim());
+		Guard<DByteGDL> guard(ret);
+		for( SizeT ix=0; ix < nEl; ix++)
+		{
+			DPtr id= (*p)[ix];
+		   if( id != 0)
+			   {
+			   HeapT::iterator it=heap.find( id);
+			   if( it != heap.end() and (*it).second.IsEnabledGC())
+					(*ret)[ix] = 1;
+			   }
+		}
+		return guard.release();
+   }
+   static DByteGDL* IsEnabledGCObj( DObjGDL* p)
+   {
+        SizeT nEl=p->N_Elements();
+        if( nEl == 0) return new DByteGDL( 0);
+        DByteGDL* ret = new DByteGDL( p->Dim());
+        Guard<DByteGDL> guard(ret);
+        for( SizeT ix=0; ix < nEl; ix++)
+   {
+            DObj id= (*p)[ix];
+		   if( id != 0)
+			   {
+			   ObjHeapT::iterator it=objHeap.find( id);
+			   if( it != objHeap.end() and (*it).second.IsEnabledGC())
+					(*ret)[ix] = 1;
+			   }
+        }
+        return guard.release();
+   }
+
+   static void EnableGC( DPtr id, bool set=true)
    {
        if( id != 0)
            {
+		   HeapT::iterator it=heap.find( id);
+		   if( it != heap.end()) (*it).second.EnableGC(set);
+           }
+   }
+   static void EnableGC( DPtrGDL* p, bool set=true)
+   {
+        SizeT nEl=p->N_Elements();
+        for( SizeT ix=0; ix < nEl; ix++)
+        {
+            DPtr id= (*p)[ix];
+            EnableGC( id, set);
+       }
+   }
+   static void EnableAllGC() {
+        SizeT nEl = heap.size();
+        for( HeapT::iterator it=heap.begin(); it != heap.end(); ++it)
+			it->second.EnableGC(true);
+        nEl = objHeap.size();
+        for( ObjHeapT::iterator it=objHeap.begin(); it != objHeap.end(); ++it)
+			it->second.EnableGC(true);
+   }
+
+   static void EnableGCObj( DObj id, bool set=true)
+   {
+       if( id != 0)
+           {
+		   ObjHeapT::iterator it=objHeap.find( id);
+		   if( it != objHeap.end()) (*it).second.EnableGC(set);
+           }
+   }
+   static void EnableGCObj( DObjGDL* p, bool set=true)
+   {
+        SizeT nEl=p->N_Elements();
+        for( SizeT ix=0; ix < nEl; ix++)
+        {
+            DObj id= (*p)[ix];
+            EnableGCObj( id, set);
+       }
+   }
+
+   static void DecRef( DPtr id)
+   {
+       if( id != 0 and IsEnabledGC())
+           {
 #ifdef GDL_DEBUG_HEAP
                std::cout << "-- <PtrHeapVar" << id << ">" << std::endl; 
 #endif
                HeapT::iterator it=heap.find( id);
                if( it != heap.end()) 
                    { 
-                       if( (*it).second.Dec())
+                       if( (*it).second.Dec() and (*it).second.IsEnabledGC() )
                            {
 #ifdef GDL_DEBUG_HEAP
                                std::cout << "Out of scope (garbage collected): <PtrHeapVar" << id 
@@ -341,7 +427,7 @@ public:
     }
    static void DecRefObj( DObj id)
     {
-        if( id != 0)
+        if( id != 0 and IsEnabledGC())
             {
 #ifdef GDL_DEBUG_HEAP
 std::cout << "-- <ObjHeapVar" << id << ">" << std::endl; 
@@ -349,7 +435,7 @@ std::cout << "-- <ObjHeapVar" << id << ">" << std::endl;
                 ObjHeapT::iterator it=objHeap.find( id);
                 if( it != objHeap.end()) 
                     { 
-                       if( (*it).second.Dec())
+                       if( (*it).second.Dec() and (*it).second.IsEnabledGC() )
                            {
 #ifdef GDL_DEBUG_HEAP
                                std::cout << "Out of scope (garbage collected): <ObjHeapVar" << id 
@@ -380,7 +466,7 @@ std::cout << "<ObjHeapVar" << id << "> = " << (*it).second.Count() << std::endl;
     }
    static void IncRef( DPtr id)
     {
-        if( id != 0)
+        if( id != 0 and IsEnabledGC())
             {
 #ifdef GDL_DEBUG_HEAP
 std::cout << "++ <PtrHeapVar" << id << ">" << std::endl; 
@@ -409,6 +495,26 @@ std::cout << add << " + <PtrHeapVar" << id << ">" << std::endl;
                     }
             }
     }
+   static SizeT RefCountHeap( DPtr id)
+    {
+		SizeT result = 0;
+        if( id != 0)
+            {
+                HeapT::iterator it=heap.find( id);
+                if( it != heap.end()) result = (*it).second.Count();
+			}
+		return result;
+	   }
+   static SizeT RefCountHeapObj( DObj id)
+    {
+		SizeT result = 0;
+        if( id != 0)
+            {
+                ObjHeapT::iterator it=objHeap.find( id);
+                if( it != objHeap.end()) result = (*it).second.Count();
+			}
+		return result;
+	   }
    static void IncRef( DPtrGDL* p)
     {
         SizeT nEl=p->N_Elements();
@@ -420,7 +526,7 @@ std::cout << add << " + <PtrHeapVar" << id << ">" << std::endl;
     }
    static void IncRefObj( DObj id)
     {
-        if( id != 0)
+        if( id != 0 and IsEnabledGC())
             {
 #ifdef GDL_DEBUG_HEAP
 std::cout << "++ <ObjHeapVar" << id << ">" << std::endl; 
@@ -465,6 +571,12 @@ std::cout << add << " + <ObjHeapVar" << id << ">" << std::endl;
             throw HeapException();
         return it->second.get();
     }
+    static BaseGDL* GetHeapNoThrow( DPtr ID)
+    {
+        HeapT::iterator it=heap.find( ID);
+        if( it == heap.end())  return NULL;
+        return it->second.get();
+    }
     static DStructGDL*& GetObjHeap( DObj ID)
     {
         ObjHeapT::iterator it=objHeap.find( ID);
@@ -613,6 +725,9 @@ std::cout << add << " + <ObjHeapVar" << id << ">" << std::endl;
             delete (*it).second.get();
             objHeap.erase( it->first); 
         }
+// The counters are reset for easier human readability.
+       heapIx = 1;
+       objHeapIx = 1;
     }
 
     // name of data
@@ -793,9 +908,9 @@ public:
 		return GDLInterpreter::tokenNames;
 	}
 	public:  RetCode  interactive(ProgNodeP _t);
-	public:  RetCode  statement(ProgNodeP _t);
-	public:  RetCode  execute(ProgNodeP _t);
-	public:  RetCode  statement_list(ProgNodeP _t);
+	public:  RetCode  statement(ProgNodeP _t, bool throwImmediately=false);
+	public:  RetCode  execute(ProgNodeP _t, bool throwImmediately=false);
+	public:  RetCode  statement_list(ProgNodeP _t, bool throwImmediately=false);
 	public:  BaseGDL*  call_fun(ProgNodeP _t);
 	public:  BaseGDL**  call_lfun(ProgNodeP _t);
 	public: void call_pro(ProgNodeP _t);
@@ -883,10 +998,10 @@ protected:
 private:
 	static const char* tokenNames[];
 #ifndef NO_STATIC_CONSTS
-	static const int NUM_TOKENS = 237;
+	static const int NUM_TOKENS = 238;
 #else
 	enum {
-		NUM_TOKENS = 237
+		NUM_TOKENS = 238
 	};
 #endif
 	
