@@ -307,17 +307,28 @@ private:
    }
   }
   //     dimension topDim;
-  if (ix[d] == NULL) { // loop over all elements
+  if (ix[d] == NULL) 
+  { // loop over all elements
    // 	topDim=top->Dim();
    // 	dim >> topDim;
    dim >> top->Dim();
-  } else {
-   ix[d]->SetVariable(top);
-   // 	topDim=ix[d]->GetDim();
-   // 	dim >> topDim;
-   dim >> ix[d]->GetDim();
+  } 
+  else 
+  {
+    ix[d]->SetVariable(top);
+// Following code was causing problem #10 in test_bug_709.
+//    dimension addVarDim = ix[d]->GetDim();
+//    addVarDim.Purge();
+//    dim >> addVarDim;
+     if( top->Rank() < ix[d]->GetDim().Rank())
+     {
+      dimension addVarDim = ix[d]->GetDim();
+      addVarDim.Purge();
+      dim >> addVarDim;
+      //dim.AddLeft( ix[d]->GetDim(), top->Rank());
+     }
+     else dim >> ix[d]->GetDim();    
   }
-  dim.Purge();
  }
   
 private:
