@@ -250,12 +250,13 @@ bool BaseGDL::LogTrue( SizeT ix)
   throw GDLException("Operation not defined for UNDEF 4b.");
 }
 
-DLong* BaseGDL::Where( bool, SizeT&)
+void BaseGDL::Where(DLong* &ret, SizeT &passed_count, bool comp, DLong* &comp_ret)
 {
   throw GDLException("Operation not defined for UNDEF 4b.");
 }
 
-DByte* BaseGDL::TagWhere(SizeT&) {
+void BaseGDL::Where(DLong64* &ret, SizeT &passed_count, bool comp, DLong64* &comp_ret)
+{
   throw GDLException("Operation not defined for UNDEF 4b.");
 }
 
@@ -284,6 +285,11 @@ bool BaseGDL::ArrayEqual( BaseGDL*)
   throw GDLException("Operation not defined for UNDEF 6b.");
 }
 
+bool BaseGDL::ArrayNeverEqual( BaseGDL*)
+{
+  throw GDLException("Operation not defined for UNDEF 6b.");
+}
+
 // for statement compliance (int types , float types scalar only)
 void BaseGDL::ForCheck( BaseGDL**, BaseGDL**)
 {
@@ -504,22 +510,19 @@ void BaseGDL::InsertAt(  SizeT offset, BaseGDL* srcIn, ArrayIndexListT* ixList)
 }
 
 // formatting output functions
-SizeT BaseGDL::OFmtA( std::ostream* os, SizeT offset, SizeT num, int width)
+SizeT BaseGDL::OFmtA( std::ostream* os, SizeT offset, SizeT num, int width, int code)
 {throw GDLException("BaseGDL::OFmtA(...) called.");}
 
-SizeT BaseGDL::OFmtF( std::ostream* os, SizeT offs, SizeT num, int width,
-		      int prec, char fill, IOMode oM) 
+SizeT BaseGDL::OFmtF( std::ostream* os, SizeT offs, SizeT num, int width,  int prec, const int code, const BaseGDL::IOMode oM) 
 {throw GDLException("BaseGDL::OFmtF(...) called.");}
 
-SizeT BaseGDL::OFmtI( std::ostream* os, SizeT offs, SizeT num, int width, 
-		      int minN, char fill, BaseGDL::IOMode oM)
+SizeT BaseGDL::OFmtI( std::ostream* os, SizeT offs, SizeT num, int width, int minN, int code, BaseGDL::IOMode oM)
 {throw GDLException("BaseGDL::OFmtI(...) called.");}
 
 SizeT BaseGDL::IFmtCal( std::istream* is, SizeT offs, SizeT r, int width, BaseGDL::Cal_IOMode cMode)
 {throw GDLException("BaseGDL::IFmtCal(...) called.");}
 
-SizeT BaseGDL::OFmtCal( std::ostream* os, SizeT offs, SizeT num, int width, 
-			int minN, char *f, BaseGDL::Cal_IOMode oM)
+SizeT BaseGDL::OFmtCal( std::ostream* os, SizeT offs, SizeT num, int width, int minN, char *f, int code, BaseGDL::Cal_IOMode oM)
 {throw GDLException("BaseGDL::OFmtCal(...) called.");}
 
 SizeT BaseGDL::IFmtA( std::istream* is, SizeT offset, SizeT num, int width)
