@@ -22,6 +22,8 @@ namespace lib {
 
   // also used from basic_fun_jmg.cpp
   void arr( EnvT* e, dimension& dim, SizeT pOffs=0);
+  SizeT HASH_count( DStructGDL* oStructGDL);
+  SizeT LIST_count( DStructGDL* oStructGDL);
 
   BaseGDL* get_kbrd( EnvT* e);
 
@@ -46,6 +48,9 @@ namespace lib {
 
   BaseGDL* ptr_new( EnvT* e);
   BaseGDL* obj_new( EnvT* e);
+
+  BaseGDL* heap_refcount( EnvT* e);
+
   BaseGDL* call_function( EnvT* e);
   BaseGDL* call_method_function( EnvT* e);
   
@@ -95,13 +100,15 @@ namespace lib {
   BaseGDL* strpos( EnvT* e);
   BaseGDL* strtrim( EnvT* e);
 
-  BaseGDL* where_fun( EnvT* e);
   BaseGDL* total_fun( EnvT* e);
   BaseGDL* product_fun( EnvT* e);
 
   BaseGDL* n_params( EnvT* e);
   BaseGDL* keyword_set( EnvT* e);
 
+  bool array_equal_bool( BaseGDL* p0, BaseGDL* p1,
+			bool notypeconv=false, bool not_equal=false,
+			bool quiet=true);
   BaseGDL* array_equal( EnvT* e);
 
   BaseGDL* min_fun( EnvT* e);
@@ -127,6 +134,9 @@ namespace lib {
   BaseGDL* rebin_fun( EnvT* e);
 
   BaseGDL* obj_class( EnvT* e);
+
+  BaseGDL* obj_hasmethod( EnvT* e);
+
   BaseGDL* obj_isa( EnvT* e);
 
   BaseGDL* n_tags( EnvT* e);
@@ -152,6 +162,8 @@ namespace lib {
 
   BaseGDL* rotate( EnvT* e);
 
+  BaseGDL* routine_filepath( EnvT* e);
+
   // the following by Sylwester Arabas 
   // (slayoo@users.sourceforge.net)
   BaseGDL* reverse( EnvT* e);
