@@ -20,9 +20,11 @@
 
 #include <string>
 #include <fstream>
+#include <limits>
 
 #include "envt.hpp"
 #include "dinterpreter.hpp"
+#include "prognode.hpp"
 #include "basic_pro_jmg.hpp"
 
 #define MAXNDLL 40
@@ -38,8 +40,8 @@ namespace lib {
 
   using namespace std;
 
-  void (*dynPro[MAXNDLL/2])( EnvT* e);
-  BaseGDL*(*dynFun[MAXNDLL/2])( EnvT* e);
+  LibPro dynPro[MAXNDLL/2];
+  LibFun dynFun[MAXNDLL/2];
 
   void point_lun( EnvT* e) 
   { 
@@ -62,7 +64,14 @@ namespace lib {
       BaseGDL** retPos = &e->GetPar( 1);
 
       GDLDelete(*retPos);
-      *retPos = new DLongGDL( actUnit.Tell());
+
+      // see https://github.com/gnudatalanguage/gdl/issues/441
+      DLong64 pos = actUnit.Tell();
+      if (pos > std::numeric_limits<DLong>::max()) {
+        *retPos = new DLong64GDL( pos);
+      } else {
+        *retPos = new DLongGDL( pos);
+      }
       return;
 
     } else {
@@ -72,7 +81,6 @@ namespace lib {
     }
   }
 
-   
   void linkimage( EnvT* e) 
   {
 
@@ -141,11 +149,11 @@ namespace lib {
 
 #if defined(_WIN32) && !defined(__CYGWIN__)
     if (funcType == 0) {
-      (void* &) dynPro[count_pro] = 
-	(void *) GetProcAddress(module[count], entryName.c_str());
+      dynPro[count_pro] = 
+	(LibPro) GetProcAddress(module[count], entryName.c_str());
     } else if (funcType == 1) {
-      (BaseGDL* &) dynFun[count_fun] = 
-	(BaseGDL*) GetProcAddress(module[count], entryName.c_str());
+      dynFun[count_fun] = 
+	(LibFun) GetProcAddress(module[count], entryName.c_str());
     } else {
       printf("Improper function type: %d\n", funcType);
       FreeLibrary(module[count]);
@@ -153,11 +161,11 @@ namespace lib {
     }
 #else
     if (funcType == 0) {
-      (void* &) dynPro[count_pro] = 
-	(void *) dlsym(module[count], entryName.c_str());
+      dynPro[count_pro] = 
+        (LibPro) dlsym(module[count], entryName.c_str());
     } else if (funcType == 1) {
-      (BaseGDL* &) dynFun[count_fun] = 
-	(BaseGDL*) dlsym(module[count], entryName.c_str());
+      dynFun[count_fun] = 
+	(LibFun) dlsym(module[count], entryName.c_str());
     } else {
       printf("Improper function type: %d\n", funcType);
       dlclose(module[count]);
@@ -587,8 +595,11 @@ namespace lib {
 			break;
         case GDL_STRING:    return new DStringGDL(s);
 			break;
+        default:
+        break;  //already exited due to throw above.
     }
     assert( false);
+    return NULL; //no -Wreturn-type warnings.
   }
 
 
