@@ -124,7 +124,8 @@ static	void operator delete( void *ptr);
   Data_(const Ty& d_);
 
   // new array, no zero or indgen
-  Data_(const dimension& dim_,  BaseGDL::InitType iT);
+  Data_(const dimension& dim_,  BaseGDL::InitType iT,
+        DDouble start = 0, DDouble increment = 1);
   
   // new array, zero fields
   Data_(const dimension& dim_);
@@ -243,12 +244,18 @@ static	void operator delete( void *ptr);
 
   // not all compilers can handle template friend member functions
 #ifndef _MSC_VER
-#if defined( TEMPLATE_FRIEND_OK_) || (__GNUC__ >= 4)
+#  if __GNUC__ >= 4 
+#    if defined(__clang__)
+       // suppress: warning: dependent nested name specifier 'Data_<Sp2>::' for friend class declaration is not supported; turning off access control for 'Data_' [-Wunsupported-friend]
+#      pragma clang diagnostic push
+#      pragma clang diagnostic ignored "-Wunsupported-friend"
   // make all other Convert2 functions friends
   template<class Sp2>  
   friend BaseGDL* Data_<Sp2>::Convert2( DType destTy, 
 					BaseGDL::Convert2Mode);
-#else
+#      pragma clang diagnostic pop
+#    endif
+#  else
   // this explicit version does not work with GCC 4.0
   friend BaseGDL* Data_<SpDByte>::Convert2( DType destTy, BaseGDL::Convert2Mode);
   friend BaseGDL* Data_<SpDInt>::Convert2( DType destTy, BaseGDL::Convert2Mode);
@@ -265,20 +272,21 @@ static	void operator delete( void *ptr);
   friend BaseGDL* Data_<SpDComplex>::Convert2( DType destTy, BaseGDL::Convert2Mode);
   friend BaseGDL* Data_<SpDComplexDbl>::Convert2( DType destTy, BaseGDL::Convert2Mode);
 
-#endif
+#  endif
 #endif
 
   bool True();
   bool False();
   bool LogTrue();
   bool LogTrue( SizeT ix);
-  DLong* Where( bool comp, SizeT& count);
-  DByte* TagWhere(SizeT& count);
+  void Where(DLong* &ret, SizeT &passed_count, bool comp, DLong* &comp_ret);
+  void Where(DLong64* &ret, SizeT &passed_count, bool comp, DLong64* &comp_ret);
   Data_<SpDByte>* LogNeg();
   int  Sgn(); // returns -1,0,1
   bool Equal( BaseGDL*) const;
   bool EqualNoDelete( const BaseGDL*) const;
   bool ArrayEqual( BaseGDL*);
+  bool ArrayNeverEqual( BaseGDL*);
   void ForCheck( BaseGDL**, BaseGDL** =NULL);
   bool ForCondUp( BaseGDL*);
   bool ForCondDown( BaseGDL*);
@@ -425,6 +433,9 @@ static	void operator delete( void *ptr);
   // used by interpreter, calls CatInsert
   Data_* CatArray( ExprListT& exprList, const SizeT catRank, 
 		   const SizeT rank);
+  // used for concatenation, called from CatArray
+  // assumes that everything is checked (see CatInfo)
+  void CatInsert( const Data_* srcArr, const SizeT atDim, SizeT& at);
 
   // assigns srcIn to this at ixList, if ixList is NULL does linear copy
   // assumes: ixList has this already set as variable
@@ -462,13 +473,10 @@ static	void operator delete( void *ptr);
   std::istream& Read( std::istream& os, bool swapEndian, bool compress,
 		      XDR *xdrs);
   
-  SizeT OFmtA( std::ostream* os, SizeT offset, SizeT num, int width);
-  SizeT OFmtF( std::ostream* os, SizeT offs, SizeT num, int width, 
-		int prec, char fill, BaseGDL::IOMode oM = BaseGDL::FIXED);
-  SizeT OFmtI( std::ostream* os, SizeT offs, SizeT num, int width, 
-		int minN, char fill, BaseGDL::IOMode oM = BaseGDL::DEC);
-  SizeT OFmtCal( std::ostream* os, SizeT offs, SizeT num, int width, 
-		 int minN, char *f, BaseGDL::Cal_IOMode oM = BaseGDL::DEFAULT);
+  SizeT OFmtA( std::ostream* os, SizeT offset, SizeT num, int width, const int code=0);
+  SizeT OFmtF( std::ostream* os, SizeT offs, SizeT num, int width, int prec, const int code=0, const BaseGDL::IOMode oM = BaseGDL::FIXED);
+  SizeT OFmtI( std::ostream* os, SizeT offs, SizeT num, int width, int minN, int code=0, BaseGDL::IOMode oM = BaseGDL::DEC);
+  SizeT OFmtCal( std::ostream* os, SizeT offs, SizeT num, int width, int minN, char *f, int code=0, BaseGDL::Cal_IOMode oM = BaseGDL::DEFAULT);
   // formatting input functions
   SizeT IFmtA( std::istream* is, SizeT offset, SizeT num, int width); 
   SizeT IFmtF( std::istream* is, SizeT offs, SizeT num, int width); 
@@ -487,9 +495,6 @@ private:
   // inserts srcIn at ixDim, used by AssignAt(...)
   // respects the exact structure
   void InsAt( Data_* srcIn, ArrayIndexListT* ixList, SizeT offset = 0);
-  // used for concatenation, called from CatArray
-  // assumes that everything is checked (see CatInfo)
-  void CatInsert( const Data_* srcArr, const SizeT atDim, SizeT& at);
 
   // only to be used here
 #undef GDL_DECLARE_FUNCTION
