@@ -25,6 +25,15 @@
 using namespace std;
 
 vector< void*> DStructGDL::freeList;
+#ifdef HAVE_LIBWXWIDGETS
+#include <wx/wx.h>
+wxMutex mutexNewDelete;
+#define LOCK_MUTEXNEWDELETE	mutexNewDelete.Lock();
+#define UNLOCK_MUTEXNEWDELETE	mutexNewDelete.Unlock();
+#else
+#define LOCK_MUTEXNEWDELETE	;
+#define UNLOCK_MUTEXNEWDELETE	;
+#endif
 
 void* DStructGDL::operator new( size_t bytes)
 {
@@ -32,28 +41,36 @@ void* DStructGDL::operator new( size_t bytes)
 	
 	if( freeList.size() > 0)
 	{
-		void* res = freeList.back();
-		freeList.pop_back();
-		return res;	
+	    LOCK_MUTEXNEWDELETE
+	    void* res = freeList.back();
+	    freeList.pop_back();
+	    UNLOCK_MUTEXNEWDELETE
+	    
+	    return res;	
 	}
 
 	//cout << "Alloc: " << bytes << "  " << "STRUCT" << endl;
 
-	const size_t newSize = multiAlloc - 1;
-	freeList.resize( newSize);
 	char* res = static_cast< char*>( malloc( sizeof( DStructGDL) * multiAlloc)); // one more than newSize
+	const size_t newSize = multiAlloc - 1;
+
+	LOCK_MUTEXNEWDELETE
+	freeList.resize( newSize);
 	for( size_t i=0; i<newSize; ++i)
 	{
 		freeList[ i] = res;
 		res += sizeof( DStructGDL);
 	} 
+	UNLOCK_MUTEXNEWDELETE
 	
 	return res;
 }
 
 void DStructGDL::operator delete( void *ptr)
 {
+	LOCK_MUTEXNEWDELETE
 	freeList.push_back( ptr);
+	UNLOCK_MUTEXNEWDELETE
 }
 
 DStructGDL::~DStructGDL() 
@@ -807,6 +824,7 @@ void DStructGDL::InsAt( DStructGDL* srcIn, ArrayIndexListT* ixList)
 
   //const DStructGDL* srcArr=static_cast<const DStructGDL*>(srcIn->Convert2( t));
   dimension srcDim=srcIn->Dim();
+  srcDim.Purge(); // newly inserted: variant of ticket #675
     
   //  SizeT nDim   =RankIx(ixDim.Rank());
   SizeT srcNDim=RankIx(srcDim.Rank()); // number of source dimensions
@@ -997,7 +1015,7 @@ bool DStructGDL::EqualNoDelete( const BaseGDL* r) const
 
 void DStructGDL::MinMax( DLong* minE, DLong* maxE, 
 			 BaseGDL** minVal, BaseGDL** maxVal, bool omitNaN,
-			 SizeT start, SizeT stop, SizeT step, DLong valIx)
+             SizeT start, SizeT stop, SizeT step, DLong valIx, bool useAbs)
 {
   throw GDLException("Struct expression not allowed in this context.");
 }
