@@ -557,9 +557,9 @@ DStructGDL* NewResult() const
   { throw GDLException("Struct expression not allowed in this context.");}
   bool LogTrue( SizeT ix)
   { throw GDLException("Struct expression not allowed in this context.");}
-  DLong* Where( bool, SizeT&)
+  void Where(DLong* &ret, SizeT &passed_count, bool comp, DLong* &comp_ret)
   { throw GDLException("Struct expression not allowed in this context.");}
-  DByte* TagWhere( SizeT&)
+  void Where(DLong64* &ret, SizeT &passed_count, bool comp, DLong64* &comp_ret)
   { throw GDLException("Struct expression not allowed in this context.");}
   Data_<SpDByte>* LogNeg()
   { throw GDLException("Struct expression not allowed in this context.");}
@@ -567,6 +567,7 @@ DStructGDL* NewResult() const
   bool Equal( BaseGDL*) const;
   bool EqualNoDelete( const BaseGDL*) const;
   bool ArrayEqual( BaseGDL*);
+  bool ArrayNeverEqual( BaseGDL*);
   // 'for' statement compliance (int types , float types scalar only)
   void ForCheck( BaseGDL**, BaseGDL** =NULL);
   bool ForCondUp( BaseGDL*);
@@ -710,11 +711,9 @@ DStructGDL* NewResult() const
 
   // formatting output functions
   
-  SizeT OFmtA( std::ostream* os, SizeT offset, SizeT num, int width); 
-  SizeT OFmtF( std::ostream* os, SizeT offs, SizeT num, int width, 
-		int prec, char fill, BaseGDL::IOMode oM = FIXED);
-  SizeT OFmtI( std::ostream* os, SizeT offs, SizeT num, int width, 
-		int minN, char fill, BaseGDL::IOMode oM = DEC);
+  SizeT OFmtA( std::ostream* os, SizeT offset, SizeT num, int width, int code); 
+  SizeT OFmtF( std::ostream* os, SizeT offs, SizeT num, int width, int prec, const int code=0, const BaseGDL::IOMode oM = FIXED);
+  SizeT OFmtI( std::ostream* os, SizeT offs, SizeT num, int width, int minN, int code=0, BaseGDL::IOMode oM = DEC);
   
   SizeT IFmtA( std::istream* is, SizeT offset, SizeT num, int width); 
   SizeT IFmtF( std::istream* is, SizeT offs, SizeT num, int width); 
@@ -727,7 +726,7 @@ private:
   
   void OFmtAll( SizeT offs, SizeT r,
 		SizeT& firstOut, SizeT& firstOffs, SizeT& tCount, SizeT& tCountOut);
-  SizeT OFmtCal( std::ostream* os, SizeT offs, SizeT r, int w, int d, char *f,  BaseGDL::Cal_IOMode oMode);   
+  SizeT OFmtCal( std::ostream* os, SizeT offs, SizeT r, int w, int d, char *f,  int code, BaseGDL::Cal_IOMode oMode);   
   // inserts srcIn at ixDim
   // respects the exact structure
   // used by Assign -> old data must be freed
