@@ -37,6 +37,8 @@ public:
   DVar(const std::string& n, BaseGDL* = 0); 
   ~DVar();
 
+  void Delete(); // for ResetObjects() to resolve COMMON/STRUCT mutual dependency
+  
   const std::string& Name() const {return name;}
 
   BaseGDL*& Data() 
@@ -47,9 +49,10 @@ public:
   {
     return d;
   }
+  void SetData(BaseGDL* val){d=val;}
 };
 
-typedef std::deque<DVar*>        VarListT;
+typedef std::vector<DVar*>        VarListT;
 
 class DVar_eq: public std::unary_function<DVar,bool>
 {
