@@ -22,14 +22,15 @@ namespace lib {
 
   // library functions
   BaseGDL* file_test( EnvT* e);
+  BaseGDL* file_lines( EnvT* e);
 
+  std::string PathSeparator();
   void cd_pro( EnvT* e);
 
   BaseGDL* expand_path( EnvT* e);
 
-#ifndef _MSC_VER
+  BaseGDL* file_expand_path( EnvT* e);
   BaseGDL* file_search( EnvT* e);
-#endif
 
   BaseGDL* file_same( EnvT* e);
 
@@ -37,7 +38,11 @@ namespace lib {
 
   BaseGDL* file_basename( EnvT* e);
   BaseGDL* file_dirname( EnvT* e);
-
+  BaseGDL* file_readlink( EnvT* e);
+  void file_copy( EnvT* e);
+  void file_move( EnvT* e);
+  void file_link( EnvT* e);
+  
   // helper functions
   void ExpandPath( FileListT& result,
 		   const DString& dirN, 
@@ -48,6 +53,7 @@ namespace lib {
 
   // SA:
   void file_mkdir( EnvT* e);
+  void file_delete( EnvT* e);
 
 } // namespace
 
