@@ -173,9 +173,24 @@ void InitGDL()
   lib::SetGDLGenericGSLErrorHandler();
 }
 
+static bool trace_me;
+
 // SA: for use in COMMAND_LINE_ARGS()
 namespace lib {
-  extern std::vector<char*> command_line_args;
+  extern std::vector<std::string> command_line_args;
+  bool gdlarg_present(const char* s)
+  {
+		for (size_t i = 0; i < command_line_args.size(); i++)
+			  if( command_line_args[i] == s )  return true;
+		return false;
+		  }
+  bool trace_arg()
+  {
+		for (size_t i = 0; i < command_line_args.size(); i++) 
+			  if( command_line_args[i] == "trace" )  return true;
+		return false;
+   }
+
 }
 
 int main(int argc, char *argv[])
@@ -195,6 +210,12 @@ int main(int argc, char *argv[])
   bool strict_syntax=false;
   bool syntaxOptionSet=false;
 
+  //start with a default value:
+  useWxWidgetsForGraphics = false;
+  bool force_no_wxgraphics = false;
+
+  useDSFMTAcceleration = true;
+
   for( SizeT a=1; a< argc; ++a)
     {
       if( string( argv[a]) == "--help" | string( argv[a]) == "-h")
@@ -212,7 +233,12 @@ int main(int argc, char *argv[])
       cout << "                     Use enviromnment variable \"GDL_IS_FUSSY\" to set up permanently this feature." << endl;
 	  cout << "  --sloppy           Sets the traditional (default) compiling option where \"()\"  can be used both with functions and arrays." << endl;
       cout << "                     Needed to counteract temporarily the effect of the enviromnment variable \"GDL_IS_FUSSY\"." << endl;
-          cout << endl;
+      cout << "  --use-wx           Tells GDL to use WxWidgets graphics instead of X11 or Windows. (nicer plots)." << endl;
+      cout << "                     Also enabled by setting the environment variable GDL_USE_WX to a non-null value." << endl;
+      cout << "  --no-use-wx        Tells GDL no to use WxWidgets graphics, even if env. var. \"GDL_USE_WX\" is set." << endl;
+      cout << "  --no-dSFMT         Tells GDL not to use double precision SIMD oriented Fast Mersenne Twister(dSFMT) for random doubles." << endl;
+      cout << "                     Also disable by setting the environment variable GDL_NO_DSFMT to a non-null value." << endl;
+      cout << endl;
 	  cout << "IDL-compatible options:" << endl;
 	  cout << "  -arg value tells COMMAND_LINE_ARGS() to report" << endl;
           cout << "             the following argument (may be specified more than once)" << endl;
@@ -238,11 +264,11 @@ int main(int argc, char *argv[])
           cerr << "gdl: -arg must be followed by a user argument." << endl;
           return 0;
         } 
-        lib::command_line_args.push_back(argv[++a]);
+        lib::command_line_args.push_back(string(argv[++a]));
       }
       else if( string( argv[a]) == "-args")
       {
-        for (int i = a + 1; i < argc; i++) lib::command_line_args.push_back(argv[i]);
+        for (int i = a + 1; i < argc; i++) lib::command_line_args.push_back(string(argv[i]));
         break;
       }
       else if (string(argv[a])=="-quiet" | string(argv[a])=="--quiet" | string(argv[a])=="-q") 
@@ -278,7 +304,7 @@ int main(int argc, char *argv[])
 	  // (e.g. $ gdl -e "")
 	}
       else if (
-	       string(argv[a]) == "-demo" || 
+	    string(argv[a]) == "-demo" || 
         string(argv[a]) == "-em" || 
         string(argv[a]) == "-novm" ||
         string(argv[a]) == "-queue" ||
@@ -300,7 +326,19 @@ int main(int argc, char *argv[])
       {
           strict_syntax = false;
           syntaxOptionSet = true;
+      }
+      else if (string(argv[a]) == "--no-dSFMT")
+      {
+           useDSFMTAcceleration = false;
+      }
+      else if (string(argv[a]) == "--use-wx")
+      {
+          useWxWidgetsForGraphics = true;
       }      
+      else if (string(argv[a]) == "--no-use-wx")
+      {
+           force_no_wxgraphics = true;
+      }
       else if (string(argv[a]) == "--fakerelease")
       {
         if (a == argc - 1)
@@ -326,7 +364,14 @@ int main(int argc, char *argv[])
     cerr << argv[0] << ": " << "-e option cannot be specified with batch files" << endl;
     return 0;
   }
-
+  
+  //before InitGDL() as InitGDL() starts graphic!
+  std::string useWX=GetEnvString("GDL_USE_WX");
+  if ( useWX.length() > 0) useWxWidgetsForGraphics=true; //not necessary "YES".
+  if (force_no_wxgraphics) useWxWidgetsForGraphics=false; //this has the last answer, whatever the setup.
+  if (useWxWidgetsForGraphics) cerr << "- Using WxWidgets as graphics library (windows and widgets)." <<endl;
+  
+  
   InitGDL();
 
   // must be after !cpu initialisation
@@ -346,8 +391,10 @@ int main(int argc, char *argv[])
         "- Default library routine search path used (GDL_PATH/IDL_PATH env. var. not set): " << endl << 
         "  " << gdlPath << endl;
     }
-  std::string useWX=GetEnvString("GDL_USE_WX");
-  if (useWX == "YES" || useWX == "yes") cerr << "- Using WxWidgets as graphics library (windows and widgets)." <<endl;
+
+  
+  if (useDSFMTAcceleration && (GetEnvString("GDL_NO_DSFMT").length() > 0)) useDSFMTAcceleration=false;
+
   SysVar::SetGDLPath( gdlPath);
   
   if (!pretendRelease.empty()) SysVar::SetFakeRelease(pretendRelease);
@@ -370,7 +417,7 @@ int main(int argc, char *argv[])
   if (gdlde || (isatty(0) && !quiet))
   {
     cerr << "- Please report bugs, feature or help requests and patches at:" << endl <<
-      "  http://sourceforge.net/projects/gnudatalanguage/" << endl << endl;
+      "  https://github.com/gnudatalanguage/gdl" << endl << endl;
   }
 //   else
 //     {
