@@ -284,7 +284,12 @@ void GDLFrame::OnShowRequest( wxCommandEvent& event)
   if( !frame->IsShown())
   {
     widget->SetSizeHints(); //fundamental, insure main frame wrapping around widgets.
-    bool stat = frame->Show(true);
+//    //I though found it: how to not have the focus for graphic windows. But this has adverse effects. 
+//    if (frame->focusNotPermitted()) {
+//      frame->ShowWithoutActivating();
+//    }
+//    else 
+      bool stat = frame->Show(true);
   }
   event.Skip();
 }
@@ -456,7 +461,28 @@ void GDLFrame::OnComboBox( wxCommandEvent& event)
 
   GDLWidget::PushEvent( baseWidgetID, widgcbox);
 }
+void GDLFrame::OnComboBoxTextEnter( wxCommandEvent& event)
+{
+#if (GDL_DEBUG_ALL_EVENTS || GDL_DEBUG_TEXT_EVENTS)
+  wxMessageOutputStderr().Printf(_T("in GDLFrame::OnComboBoxTextEvent: %d\n"),event.GetId());
+#endif
 
+  WidgetIDT baseWidgetID = GDLWidget::GetTopLevelBase( event.GetId());
+  int selectValue = event.GetSelection();
+  
+  // create GDL event struct
+  DStructGDL*  widgcbox;
+  wxString strValue = event.GetString();
+
+  widgcbox = new DStructGDL( "WIDGET_COMBOBOX");
+  widgcbox->InitTag("ID", DLongGDL( event.GetId()));
+  widgcbox->InitTag("TOP", DLongGDL( baseWidgetID));
+  widgcbox->InitTag("HANDLER", DLongGDL( baseWidgetID ));
+  widgcbox->InitTag("INDEX", DLongGDL( selectValue));
+  widgcbox->InitTag("STR", DStringGDL( string(strValue.mb_str(wxConvUTF8)) ));
+
+  GDLWidget::PushEvent( baseWidgetID, widgcbox);
+}
 void GDLFrame::OnDropList( wxCommandEvent& event)
 {
 #if (GDL_DEBUG_ALL_EVENTS || GDL_DEBUG_OTHER_EVENTS)
