@@ -37,7 +37,7 @@
 #  endif
 #endif
 
-#include <Windows.h>
+#include <windows.h>
 #include <map>
 
 #ifdef USE_WINGDI_NOT_WINGCC
