@@ -97,7 +97,8 @@ namespace lib {
   DLong mapH5DatatypesToGDL(DLong h5type){
 //must be in order, from most complicated to simplest, string at end
 
-if (H5Tequal(h5type , H5T_NATIVE_LDOUBLE )) return GDL_LDOUBLE;
+//not until LDOUBLE Is handled everywhere!!
+//    if (H5Tequal(h5type , H5T_NATIVE_LDOUBLE )) return GDL_LDOUBLE;
 if (H5Tequal(h5type , H5T_NATIVE_DOUBLE )) return GDL_DOUBLE;
 if (H5Tequal(h5type , H5T_NATIVE_FLOAT )) return GDL_FLOAT;
 
@@ -252,6 +253,25 @@ return GDL_UNDEF;
   }
 
 
+  BaseGDL* h5f_create_fun( EnvT* e)
+  {
+    DLong h5f_id;
+    
+    DString h5fFilename;
+    e->AssureScalarPar<DStringGDL>( 0, h5fFilename);
+    WordExp( h5fFilename);
+
+    h5f_id = H5Fcreate( h5fFilename.c_str(), H5F_ACC_EXCL, H5P_DEFAULT, H5P_DEFAULT);
+    //    h5f_id = H5Fopen(h5fFilename.c_str(), H5F_ACC_RDONLY, H5P_DEFAULT);
+    if (h5f_id < 0) 
+    { 
+      string msg; 
+      e->Throw(hdf5_error_message(msg)); 
+    }
+    
+    return new DLongGDL( h5f_id );
+  }
+
   BaseGDL* h5f_open_fun( EnvT* e)
   {
     DLong h5f_id;
