@@ -45,7 +45,7 @@ namespace SysVar
   void UpdateSTime();
 
   // updates !D
-  void UpdateD();//long &xSize, long &ySize);
+//  void UpdateD();//long &xSize, long &ySize);
 
   DStructGDL* Version();
 
@@ -99,6 +99,7 @@ namespace SysVar
   
   // initialize the predefined system variables (!IDNAME)
   void InitSysVar();
+  void SetFakeRelease( DString str);
 }
 
 #endif
