@@ -26,6 +26,7 @@
 
 #include "basic_fun.hpp"
 #include "basic_pro.hpp"
+#include "gdlhelp.hpp"
 
 #include "list.hpp"
 #include "hash.hpp"
@@ -40,6 +41,7 @@
 
 #include "gsl_fun.hpp"
 
+#include "where.hpp"
 #include "convol.hpp"
 #include "smooth.hpp"
 #include "brent.hpp"
@@ -95,8 +97,9 @@ void LibInit()
   const string listKey[]={"EXTRACT", "LENGTH", "NO_COPY", KLISTEND};
   new DLibFunRetNew(lib::list_fun,string("LIST"),-1,listKey);
 
-  const string hashKey[]={"NO_COPY", KLISTEND};
+  const string hashKey[]={"EXTRACT", "LOWERCASE", "NO_COPY", "FOLD_CASE", KLISTEND};
   new DLibFunRetNew(lib::hash_fun,string("HASH"),-1,hashKey);
+  new DLibFunRetNew(lib::orderedhash_fun,string("ORDEREDHASH"),-1,hashKey);
 
   new DLibFun(lib::scope_level,string("SCOPE_LEVEL"),0);
 
@@ -151,6 +154,7 @@ void LibInit()
   new DLibFunRetNew(lib::obj_class,string("OBJ_CLASS"),1,obj_classKey);
 
   new DLibFunRetNew(lib::obj_isa,string("OBJ_ISA"),2,NULL,NULL,false,2);
+  new DLibFunRetNew(lib::obj_hasmethod,string("OBJ_HASMETHOD"),2);
 
   const string rebinKey[]={"SAMPLE",KLISTEND};
   new DLibFunRetNew(lib::rebin_fun,string("REBIN"),9,rebinKey);
@@ -170,8 +174,9 @@ void LibInit()
                                 "TEST_DIRECTORY", "TEST_EXECUTABLE", "TEST_READ",
                                  "TEST_REGULAR", "TEST_WRITE", "TEST_ZERO_LENGTH",
                                  "TEST_SYMLINK",
+                                 "DIRECTORY","SYMLINK","REGULAR","ZERO_LENGTH",
                                  KLISTEND};
-  new DLibFunRetNew(lib::file_search,string("FILE_SEARCH"),2,file_searchKey);
+  new DLibFunRetNew(lib::file_search,string("FILE_SEARCH"),3,file_searchKey);
 
   const string file_expand_pathKey[]={KLISTEND};
   new DLibFunRetNew(lib::file_expand_path,string("FILE_EXPAND_PATH"),1,file_expand_pathKey);
@@ -216,12 +221,34 @@ void LibInit()
   new DLibFunRetNew(lib::file_dirname,string("FILE_DIRNAME"),1,file_dirnameKey);
 
 
+  const string file_moveKey[]={"ALLOW_SAME", "OVERWRITE", "REQUIRE_DIRECTORY", 
+			"VERBOSE", "NOEXPAND_PATH",KLISTEND};
+  new DLibPro(lib::file_move,string("FILE_MOVE"),2,file_moveKey);
+  
+  //exists as stub procedure for _WIN32
+#ifndef _WIN32
+  const string file_linkKey[]={"ALLOW_SAME", "HARDLINK", 
+			"VERBOSE", "NOEXPAND_PATH",KLISTEND};
+  new DLibPro(lib::file_link,string("FILE_LINK"),2,file_linkKey);
+#endif  
+  const string file_copyKey[]={"ALLOW_SAME", "OVERWRITE","FORCE", "REQUIRE_DIRECTORY", 
+			"VERBOSE", "NOEXPAND_PATH","RECURSIVE","COPY_SYMLINK",KLISTEND};
+  new DLibPro(lib::file_copy,string("FILE_COPY"),2,file_copyKey);
+
+  const string file_deleteKey[]={"ALLOW_NONEXISTENT","NOEXPAND_PATH","RECURSIVE",
+			"QUIET","VERBOSE",KLISTEND};
+  new DLibPro(lib::file_delete,string("FILE_DELETE"),-1,file_deleteKey);
+
+
   const string file_sameKey[]={"NOEXPAND_PATH",KLISTEND};
   new DLibFunRetNew(lib::file_same,string("FILE_SAME"),2,file_sameKey);
 
   const string file_infoKey[]={"NOEXPAND_PATH",KLISTEND};
   new DLibFunRetNew(lib::file_info,string("FILE_INFO"),2,file_infoKey);
 
+  const string file_linesKey[]={"NOEXPAND_PATH","COMPRESS",KLISTEND};
+  new DLibFunRetNew(lib::file_lines,string("FILE_LINES"),1,file_linesKey);
+
   const string file_mkdirKey[]={"NOEXPAND_PATH",KLISTEND};
   new DLibPro(lib::file_mkdir,string("FILE_MKDIR"),-1,file_mkdirKey);
 
@@ -253,14 +280,19 @@ void LibInit()
   const string exitKey[]={"NO_CONFIRM","STATUS",KLISTEND};
   new DLibPro(lib::exitgdl,string("EXIT"),0,exitKey);
   
-  const string helpKey[]={"ALL_KEYS","BRIEF","FULL","CALLS","DEVICE","FUNCTIONS","HELP","INFO",
+  const string helpKey[]={"ALL_KEYS","BRIEF","FULL","CALLS",
+	           "DEBUG","DEVICE","FUNCTIONS","HEAP_VARIABLES","HELP","INFO","FILES",
 			  "INTERNAL_LIB_GDL","KEYS","LAST_MESSAGE","LIB","MEMORY","NAMES",
-			  "OUTPUT","PATH_CACHE","PREFERENCES","PROCEDURES",
+		"OBJECTS","OUTPUT","PATH_CACHE","PREFERENCES","PROCEDURES",
 			  "RECALL_COMMANDS","ROUTINES","SOURCE_FILES","STRUCTURES",
               "SYSTEM_VARIABLES","TRACEBACK", "COMMON","LEVEL", KLISTEND};
-  const string helpWarnKey[]={"BREAKPOINTS","DLM","FILES","HEAP_VARIABLES","MESSAGES",
-			      "OBJECTS","SHARED_MEMORY", KLISTEND};
+  const string helpWarnKey[]={"BREAKPOINTS","DLM", "MESSAGES",
+			      "SHARED_MEMORY", KLISTEND};
   new DLibPro(lib::help_pro,string("HELP"),-1,helpKey,helpWarnKey);
+
+  new DLibPro(lib::delvar_pro,string("DELVAR"),-1,NULL,NULL);
+  DLibPro* hide = new DLibPro(lib::findvar_pro,string("FINDVAR"),-1,NULL,NULL);
+  hide->SetHideHelp(true);
   
   //stub to avoid setting errors on pref_set. One may want to really write pref_set,
   // but this function is just here to prevent setting !ERR=-1 when stumbling on a pref_set command,
@@ -277,10 +309,15 @@ void LibInit()
   // as the same functions are called "FORMAT" till "MONTH"
   // must be the first four keywords. The inner print_os function is BASED on this ORDER!
   //NOTE THAT AM_PM, DAYS_OF_WEEK and MONTHS are silently ignored!!!
+  //implied print is a feature introduced in idl8.3 and shared by print/printf, string and fix(type=7)
   #define COMMONKEYWORDSFORSTRINGFORMATTING "FORMAT","AM_PM","DAYS_OF_WEEK","MONTHS"
   const string printKey[]={COMMONKEYWORDSFORSTRINGFORMATTING, "STDIO_NON_FINITE",KLISTEND};
-  new DLibPro(lib::print,string("PRINT"),-1,printKey);
-  new DLibPro(lib::printf,string("PRINTF"),-1,printKey);
+  const string impliedprintKey[]={COMMONKEYWORDSFORSTRINGFORMATTING, "STDIO_NON_FINITE","IMPLIED_PRINT",KLISTEND};
+  //At the moment, print accepts silently "IMPLIED_PRINT" as this is used in autoprint feature.
+  new DLibPro(lib::print,string("PRINT"),-1,impliedprintKey);
+  //but PRINTF issues a warning, as it is not yet supported
+  const string printfWarnKey[]={"IMPLIED_PRINT",KLISTEND};
+  new DLibPro(lib::printf,string("PRINTF"),-1,printKey,printfWarnKey);
   // allow printing (of expressions) with all keywords 
   // (easier to implement this way)
   new DLibPro(lib::stop,string("STOP"),-1,printKey); 
@@ -293,7 +330,8 @@ void LibInit()
   new DLibPro(lib::reads,string("READS"),-1,readsKey);
 
   const string stringKey[]={COMMONKEYWORDSFORSTRINGFORMATTING,"PRINT",KLISTEND};
-  new DLibFun(lib::string_fun,string("STRING"),-1,stringKey);
+  const string stringWarnKey[]={"IMPLIED_PRINT",KLISTEND};
+  new DLibFun(lib::string_fun,string("STRING"),-1,stringKey,stringWarnKey);
 
   const string defsysvKey[]={"EXISTS",KLISTEND};
   new DLibPro(lib::defsysv,string("DEFSYSV"),3,defsysvKey); 
@@ -302,6 +340,9 @@ void LibInit()
   new DLibPro(lib::heap_gc,string("HEAP_GC"),0,heap_gcKey); 
   new DLibPro(lib::heap_free,string("HEAP_FREE"),1,heap_gcKey);
 
+  const string heap_refcount[]={"DISABLE","ENABLE","IS_ENABLED",KLISTEND};
+  new DLibFunRetNew(lib::heap_refcount,string("HEAP_REFCOUNT"),1,heap_refcount);
+
 
   new DLibPro(lib::ptr_free,string("PTR_FREE"),-1);
 
@@ -326,7 +367,7 @@ void LibInit()
   const string ptr_newKey[]={"NO_COPY","ALLOCATE_HEAP",KLISTEND};
   new DLibFunRetNew(lib::ptr_new,string("PTR_NEW"),1,ptr_newKey);
 
-  const string obj_validKey[]={"CAST","COUNT",KLISTEND};
+  const string obj_validKey[]={"CAST","COUNT","GET_HEAP_IDENTIFIER",KLISTEND};
   new DLibFunRetNew(lib::ptr_valid,string("PTR_VALID"),1,obj_validKey);
   new DLibFunRetNew(lib::obj_valid,string("OBJ_VALID"),1,obj_validKey);
   
@@ -342,19 +383,21 @@ void LibInit()
   
   const string indKey[]={"TYPE","BYTE","COMPLEX","DCOMPLEX",
 			 "DOUBLE","FLOAT","L64","LONG",
-			 "STRING","UINT","UL64","ULONG",KLISTEND};
-  new DLibFunRetNew(lib::bindgen,string("BINDGEN"),MAXRANK,NULL,NULL,true);
+			 "STRING","UINT","UL64","ULONG",
+			 "START", "INCREMENT", KLISTEND};
+  const string xindKey[]={"START", "INCREMENT", KLISTEND};
+  new DLibFunRetNew(lib::bindgen,string("BINDGEN"),MAXRANK,xindKey,NULL,true);
   new DLibFunRetNew(lib::indgen,string("INDGEN"),MAXRANK,indKey,NULL,true);
-  new DLibFunRetNew(lib::uindgen,string("UINDGEN"),MAXRANK,NULL,NULL,true);
-  new DLibFunRetNew(lib::sindgen,string("SINDGEN"),MAXRANK,NULL,NULL,true);
-  new DLibFunRetNew(lib::lindgen,string("LINDGEN"),MAXRANK,NULL,NULL,true);
-  new DLibFunRetNew(lib::ulindgen,string("ULINDGEN"),MAXRANK,NULL,NULL,true);
-  new DLibFunRetNew(lib::l64indgen,string("L64INDGEN"),MAXRANK,NULL,NULL,true);
-  new DLibFunRetNew(lib::ul64indgen,string("UL64INDGEN"),MAXRANK,NULL,NULL,true);
-  new DLibFunRetNew(lib::findgen,string("FINDGEN"),MAXRANK,NULL,NULL,true);
-  new DLibFunRetNew(lib::dindgen,string("DINDGEN"),MAXRANK,NULL,NULL,true);
-  new DLibFunRetNew(lib::cindgen,string("CINDGEN"),MAXRANK,NULL,NULL,true);
-  new DLibFunRetNew(lib::dcindgen,string("DCINDGEN"),MAXRANK,NULL,NULL,true);
+  new DLibFunRetNew(lib::uindgen,string("UINDGEN"),MAXRANK,xindKey,NULL,true);
+  new DLibFunRetNew(lib::sindgen,string("SINDGEN"),MAXRANK,xindKey,NULL,true);
+  new DLibFunRetNew(lib::lindgen,string("LINDGEN"),MAXRANK,xindKey,NULL,true);
+  new DLibFunRetNew(lib::ulindgen,string("ULINDGEN"),MAXRANK,xindKey,NULL,true);
+  new DLibFunRetNew(lib::l64indgen,string("L64INDGEN"),MAXRANK,xindKey,NULL,true);
+  new DLibFunRetNew(lib::ul64indgen,string("UL64INDGEN"),MAXRANK,xindKey,NULL,true);
+  new DLibFunRetNew(lib::findgen,string("FINDGEN"),MAXRANK,xindKey,NULL,true);
+  new DLibFunRetNew(lib::dindgen,string("DINDGEN"),MAXRANK,xindKey,NULL,true);
+  new DLibFunRetNew(lib::cindgen,string("CINDGEN"),MAXRANK,xindKey,NULL,true);
+  new DLibFunRetNew(lib::dcindgen,string("DCINDGEN"),MAXRANK,xindKey,NULL,true);
 
   new DLibFunRetNew(lib::n_elements,string("N_ELEMENTS"),1,NULL,NULL,true,1);
 
@@ -396,11 +439,15 @@ void LibInit()
   new DLibPro(lib::writeu,string("WRITEU"),-1,writeuKey);
   new DLibPro(lib::readu,string("READU"),-1,writeuKey);
 
-  const string resolve_routineWarnKey[]={"COMPILE_FULL_FILE",KLISTEND};
-  const string resolve_routineKey[]={"NO_RECOMPILE","IS_FUNCTION","EITHER",KLISTEND};
+  const string resolve_routineWarnKey[]={"SKIP_EXISTING",KLISTEND};
+  const string resolve_routineKey[]={"NO_RECOMPILE","IS_FUNCTION","EITHER","COMPILE_FULL_FILE","QUIET",KLISTEND};
   new DLibPro(lib::resolve_routine,string("RESOLVE_ROUTINE"),1,
 	      resolve_routineKey,resolve_routineWarnKey);
 
+  const string routine_filepathKey[]={"EITHER","IS_FUNCTION", KLISTEND};
+  new DLibFunRetNew(lib::routine_filepath,string("ROUTINE_FILEPATH"),1,
+				routine_filepathKey);
+
   const string assocKey[]={"PACKED",KLISTEND};
   new DLibFunRetNew(lib::assoc,string("ASSOC"),3,assocKey);
 
@@ -420,7 +467,8 @@ void LibInit()
 */
 // that's apparently the desired bahaviour, see bug no. 3151760
   const string fixKey[]={"TYPE","PRINT",KLISTEND};
-  new DLibFun(lib::fix_fun,string("FIX"),10,fixKey,NULL);
+  const string fixWarnKey[]={"IMPLIED_PRINT",KLISTEND};
+  new DLibFun(lib::fix_fun,string("FIX"),10,fixKey,fixWarnKey);
 
   new DLibFun(lib::uint_fun,string("UINT"),10,NULL,NULL);
   new DLibFun(lib::long_fun,string("LONG"),10,NULL,NULL);
@@ -490,7 +538,7 @@ void LibInit()
   new DLibFunRetNew(lib::strpos,string("STRPOS"),3,strposKey,NULL,true,2);
   new DLibPro(lib::strput,string("STRPUT"),3,NULL,NULL,2);
   
-  const string whereKey[]={"COMPLEMENT","NCOMPLEMENT","NULL",KLISTEND};
+  const string whereKey[]={"COMPLEMENT","NCOMPLEMENT","NULL","L64",KLISTEND};
   new DLibFunRetNew(lib::where_fun,string("WHERE"),2,whereKey);
 
   const string totalKey[]={"CUMULATIVE","DOUBLE","NAN","INTEGER","PRESERVE_TYPE",KLISTEND};
@@ -502,7 +550,7 @@ void LibInit()
   new DLibFunRetNew(lib::n_params,string("N_PARAMS"),1); // IDL allows one parameter
   new DLibFunRetNew(lib::keyword_set,string("KEYWORD_SET"),1);
 
-  const string array_equalKey[]={"NO_TYPECONV",KLISTEND};
+  const string array_equalKey[]={"NO_TYPECONV","NOT_EQUAL","QUIET",KLISTEND};
   new DLibFunRetNew(lib::array_equal,string("ARRAY_EQUAL"),2,array_equalKey,NULL,true);
   
   const string minKey[]={"MAX","NAN","SUBSCRIPT_MAX","DIMENSION","ABSOLUTE",KLISTEND};
@@ -551,14 +599,9 @@ void LibInit()
   const string set_plotKey[]={"COPY","INTERPOLATE",KLISTEND};
   new DLibPro(lib::set_plot,string("SET_PLOT"),1,set_plotKey);
 
-#ifdef HAVE_X  
   const string get_screen_sizeKey[]={"RESOLUTION","DISPLAY_NAME",KLISTEND};
   new DLibFunRetNew(lib::get_screen_size,string("GET_SCREEN_SIZE"),1,get_screen_sizeKey);
-#else
-  const string get_screen_sizeKey[]={"RESOLUTION",KLISTEND};
-  // DisplayName option or parameter only with X11.
-  new DLibFunRetNew(lib::get_screen_size,string("GET_SCREEN_SIZE"),0,get_screen_sizeKey);
-#endif
+
   const string tvlctKey[]={"GET","HLS","HSV",KLISTEND};
   new DLibPro(lib::tvlct,string("TVLCT"),4,tvlctKey);
 
@@ -947,8 +990,8 @@ void LibInit()
 
   const string ll_arc_distanceKey[] = {"DEGREES", KLISTEND };
   new DLibFunRetNew(lib::ll_arc_distance, string("LL_ARC_DISTANCE"), 3, ll_arc_distanceKey);
-
-  const string command_line_argsKey[] = {"COUNT", KLISTEND };
+  const string command_line_argsKey[] = {"COUNT","RESET","SET", KLISTEND }; //note: reset and set are unsupported extensions.
+// original  const string command_line_argsKey[] = {"COUNT", KLISTEND };
   new DLibFunRetNew(lib::command_line_args_fun, string("COMMAND_LINE_ARGS"), 0, command_line_argsKey);
 
   const string pmKey[] = {"FORMAT", "TITLE", KLISTEND };
