@@ -72,29 +72,42 @@ void LibInit_ac()
   new DLibFunRetNew(lib::fz_roots_fun,string("FZ_ROOTS"),3,fz_rootsKey);
   const string fx_rootKey[]={"DOUBLE","ITMAX","STOP","TOL",KLISTEND};
   new DLibFunRetNew(lib::fx_root_fun,string("FX_ROOT"),2,fx_rootKey);
-  
+
 #endif
-  
+
   const string spl1Key[]={"YP0","YPN_1","DOUBLE","HELP",KLISTEND};
   new DLibFunRetNew(lib::spl_init_fun,string("SPL_INIT"),2,spl1Key);
   const string spl2Key[]={"DOUBLE","HELP",KLISTEND};
   new DLibFunRetNew(lib::spl_interp_fun,string("SPL_INTERP"),4,spl2Key);
 
-  const string robertsKey[]={"HELP",KLISTEND};
-  new DLibFunRetNew(lib::roberts_fun,string("ROBERTS"),1,robertsKey);
-  const string sobelKey[]={"HELP",KLISTEND};
-  new DLibFunRetNew(lib::sobel_fun,string("SOBEL"),1,sobelKey);
-  const string prewittKey[]={"HELP",KLISTEND};
-  new DLibFunRetNew(lib::prewitt_fun,string("PREWITT"),1,prewittKey);
+  const string helpKey[]={"HELP",KLISTEND};
+  new DLibFunRetNew(lib::roberts_fun,string("ROBERTS"),1,helpKey);
+  new DLibFunRetNew(lib::sobel_fun,string("SOBEL"),1,helpKey);
+  new DLibFunRetNew(lib::prewitt_fun,string("PREWITT"),1,helpKey);
+
+  /* NOTE: 2018-09-07 by rexso (remi.solaas at edinsights dot no)
+   *
+   * ERODE and DILATE currently implemented in IDL,
+   * available in pro/erode.pro and pro/dilate.pro
+   * with grayscale support. Uncomment when the C++
+   * implementation is complete.
+   */
+  const string erodeKey[]={"HELP","GRAY","PRESERVE_TYPE","UINT","ULONG","VALUES",KLISTEND};
+  new DLibFunRetNew(lib::erode_fun,string("ERODE_INTERNALGDL"),5,erodeKey);
+
+  const string dilateKey[]={"HELP","GRAY","PRESERVE_TYPE","UINT","ULONG","VALUES",
+			    "CONSTRAINED","BACKGROUND",KLISTEND};
+  new DLibFunRetNew(lib::dilate_fun,string("DILATE_INTERNALGDL"),5,dilateKey);
+
 
   const string matrix_multiplyKey[]={"ATRANSPOSE","BTRANSPOSE",KLISTEND};
   new DLibFunRetNew(lib::matrix_multiply,string("MATRIX_MULTIPLY"),2,matrix_multiplyKey);
 
-  // Levan Loria and Alain Coulais, September 2014 : to be extensively tested
+// Levan Loria and Alain Coulais, September 2014 : to be extensively tested
 // please replace smooth with one of these functions only when thoroughly tested.
 //  const string smoothKey[]={"NAN",KLISTEND};
 //  new DLibFunRetNew(lib::smooth2_fun,string("SMOOTH2"),2,smoothKey);
-//  new DLibFunRetNew(lib::smooth3_fun,string("SMOOTH3"),2,smoothKey); 
-
+//  new DLibFunRetNew(lib::smooth3_fun,string("SMOOTH3"),2,smoothKey);
+  
 }
 
