@@ -124,10 +124,9 @@ void LibInit_jmg()
 #endif
 
   const string randomKey[]={"DOUBLE","GAMMA","LONG","NORMAL",
-			    "BINOMIAL","POISSON","UNIFORM","ULONG",KLISTEND};
-  const string randomWarnKey[]={"RAN1", KLISTEND}; //since IDL 8.2, change of random algo (we used already the good one).
-  new DLibFunRetNew(lib::random_fun,string("RANDOMU"),MAXRANK+1,randomKey,randomWarnKey);
-  new DLibFunRetNew(lib::random_fun,string("RANDOMN"),MAXRANK+1,randomKey,randomWarnKey);
+			    "BINOMIAL","POISSON","UNIFORM","ULONG","RAN1",KLISTEND}; //note WARNING: RAN1 has a special meaning for GDL, see code.
+  new DLibFunRetNew(lib::random_fun,string("RANDOMU"),MAXRANK+1,randomKey);
+  new DLibFunRetNew(lib::random_fun,string("RANDOMN"),MAXRANK+1,randomKey);
 
   const string checkmathKey[]={"MASK","NOCLEAR","PRINT",KLISTEND};
   new DLibFunRetNew(lib::check_math_fun,string("CHECK_MATH"),2,checkmathKey);
@@ -148,11 +147,6 @@ void LibInit_jmg()
   const string macharKey[]={"DOUBLE",KLISTEND};
   new DLibFunRetNew(lib::machar_fun,string("MACHAR"),0,macharKey);
 
-// crashes on my machine (GD) and is not used.  
-//  const string rk4Key[]={"DOUBLE",KLISTEND};
-//  new DLibFunRetNew(lib::rk4jmg_fun,string("RK4JMG"),5,rk4Key);
-
-
 #if defined(USE_LIBPROJ4)||defined(USE_LIBPROJ4_NEW)
   const string map_proj_forwardKey[]={"MAP_STRUCTURE","RADIANS","POLYGONS","POLYLINES","CONNECTIVITY","FILL",KLISTEND};  //WARNING FIXED ORDER for GetMapAsMapStructureKeyword()
   new DLibFunRetNew(lib::map_proj_forward_fun,
@@ -198,8 +192,8 @@ void LibInit_jmg()
   const string triangulateWarnKey[]={"REPEATS", "TOLERANCE",KLISTEND};
   new DLibPro(lib::GDL_Triangulate,string("TRIANGULATE"),4,triangulateKey,triangulateWarnKey);
 
-  
-#ifdef PL_HAVE_QHULL
+//to be written and do not forget to uncomment QHULL in CMakeLists and config.h.cmake  
+#ifdef HAVE_QHULL
 
   const string qhullKey[]={"BOUNDS", "CONNECTIVITY", "DELAUNAY", "SPHERE", "VDIAGRAM" ,"VNORMALS", "VVERTICES", KLISTEND};
   new DLibPro(lib::qhull,string("QHULL"),8,qhullKey);
@@ -216,11 +210,11 @@ void LibInit_jmg()
   const string poly_2dKey[]={"CUBIC","MISSING",KLISTEND};
   new DLibFunRetNew(lib::poly_2d_fun,string("POLY_2D"),6,poly_2dKey);
 
-  const string make_arrayKey[]={"NOZERO","DIMENSION","INDEX","SIZE",
-				"TYPE","VALUE","BYTE","INTEGER",
-				"UINT","LONG","ULONG","L64","UL64",
-				"FLOAT","DOUBLE","COMPLEX",
-				"DCOMPLEX","STRING","PTR","OBJ",KLISTEND};
+  const string make_arrayKey[]={"DIMENSION", "INCREMENT", "INDEX", "NOZERO",
+                                 "SIZE", "START", "TYPE", "VALUE", "BOOLEAN",
+                                 "BYTE", "COMPLEX", "DCOMPLEX", "DOUBLE",
+                                 "FLOAT", "INTEGER", "L64", "LONG", "OBJ",
+                                 "PTR", "STRING", "UINT", "UL64", "ULONG", KLISTEND};
   new DLibFunRetNew(lib::make_array,string("MAKE_ARRAY"),MAXRANK,make_arrayKey);
 
   const string reformKey[]={"OVERWRITE",KLISTEND};
