@@ -18,13 +18,13 @@
 /*
 
   using the Besel functions provided by GSL
- 
+
   http://www.physics.ohio-state.edu/~ntg/780/gsl_examples/J0_test.cpp
   http://www.gnu.org/software/gsl/manual/html_node/Bessel-Functions.html
 
   ----------------------- Warning -------------
 
-  (obsolete) As is on 20/April/2007: Warning : GSL allows only INTEGER type for order 
+  (obsolete) As is on 20/April/2007: Warning : GSL allows only INTEGER type for order
   Thibaut contributes to extend to REAL in July 2009
 
   Important information: since bad formating issue in IDL
@@ -101,9 +101,9 @@
 
 
 // change by Alain C., June 1st 2015 : IDL 8.4 behavior
-#define GM_DF2()					\
-  							\
-  DDoubleGDL* res;                                      \
+#define GM_DF2()							\
+									\
+  DDoubleGDL* res;							\
   /*/  cout << p0->Rank() << " " <<p0->Dim() <<" " <<p0->N_Elements() <<endl;*/ \
   /* //cout << p1->Rank() << " " << p1->Dim()<<" " <<p1->N_Elements() <<endl;*/ \
 									\
@@ -119,25 +119,25 @@
   /*  cout << res->Rank() << " " << res->Dim()<<" " << res->N_Elements() <<endl;*/ \
   									\
   SizeT nElp = res->N_Elements();					\
-  
-#define GM_DF2_OLD()					\
-							\
+
+#define GM_DF2_OLD()							\
+									\
   DDoubleGDL* res;							\
   cout << p0->Rank() << " " << p0->Dim() <<" " <<p0->N_Elements() <<endl; \
   cout << p1->Rank() << " " << p1->Dim() <<" " <<p1->N_Elements() <<endl; \
 									\
   if (nElp0 == 1 && nElp1 == 1)						\
-    res = new DDoubleGDL(1, BaseGDL::NOZERO);		\
-  else if (nElp0 > 1 && nElp1 == 1)			\
-    res = new DDoubleGDL(p0->Dim(), BaseGDL::NOZERO);	\
-  else if (nElp0 == 1 && nElp1 > 1)			\
-    res = new DDoubleGDL(p1->Dim(), BaseGDL::NOZERO);	\
-  else if (nElp0 <= nElp1)				\
-    res = new DDoubleGDL(p0->Dim(), BaseGDL::NOZERO);	\
-  else							\
-    res = new DDoubleGDL(p1->Dim(), BaseGDL::NOZERO);	\
-							\
-  SizeT nElp = res->N_Elements();			\
+    res = new DDoubleGDL(1, BaseGDL::NOZERO);				\
+  else if (nElp0 > 1 && nElp1 == 1)					\
+    res = new DDoubleGDL(p0->Dim(), BaseGDL::NOZERO);			\
+  else if (nElp0 == 1 && nElp1 > 1)					\
+    res = new DDoubleGDL(p1->Dim(), BaseGDL::NOZERO);			\
+  else if (nElp0 <= nElp1)						\
+    res = new DDoubleGDL(p0->Dim(), BaseGDL::NOZERO);			\
+  else									\
+    res = new DDoubleGDL(p1->Dim(), BaseGDL::NOZERO);			\
+									\
+  SizeT nElp = res->N_Elements();					\
 
 #define GM_CV0()					\
   static DInt doubleKWIx = e->KeywordIx("DOUBLE");	\
@@ -199,13 +199,13 @@
 
 namespace lib {
 
-using namespace std;
+  using namespace std;
 #ifndef _MSC_VER
-using std::isinf;
+  using std::isinf;
 #endif
 
 #if defined(USE_EIGEN)
-using namespace Eigen;
+  using namespace Eigen;
 #endif
 
   BaseGDL* beseli_fun(EnvT* e)
@@ -224,11 +224,11 @@ using namespace Eigen;
 
     // we need to check if N values (array) are Integer or not
     int test=0;
-    
+
     for (count = 0;count<nElp1;++count)
       if (abs((*p1_float)[count]-(float)(*p1)[count]) > 0.000001) // don't know if a "machar" value exists
 	test=1;
-	
+
     if (test==0)
       {
 	if(nElp0==1)
@@ -291,7 +291,7 @@ using namespace Eigen;
 
     // we need to check if N values (array) are Integer or not
     int test=0;
-    
+
     for (count = 0;count<nElp1;++count)
       if (abs((*p1_float)[count]-(float)(*p1)[count]) > 0.000001) // don't know if a "machar" value exists
 	test=1;
@@ -331,7 +331,7 @@ using namespace Eigen;
 	    for (count = 0;count<nElp;++count)
 	      (*res)[count] = gsl_sf_bessel_Jnu((*p1_float)[count],(*p0)[0]);
 	  }
-
+	
 	else if(nElp1==1)
 	  {
 	    for (count = 0;count<nElp;++count)
@@ -367,9 +367,9 @@ using namespace Eigen;
     for (count = 0;count<nElp0;++count)
       if ((*p0)[count] < dzero) // don't know if a "machar" value exists
         e->Throw("Value of X is out of allowed range (Only positive values).");
-    
+
     int test=0;
-    
+
     for (count = 0;count<nElp1;++count)
       if (abs((*p1_float)[count]-(float)(*p1)[count]) > 0.000001) // don't know if a "machar" value exists
 	test=1;
@@ -442,14 +442,14 @@ using namespace Eigen;
     GM_CC1();
     GM_CV2();
   }
-    
+
   // very preliminary version:
   // should not work when N LT 0
   // should return Inf at x==0
   // should not work for x LT 0
-    
+
   BaseGDL* besely_fun(EnvT* e)
-  { 
+  {
     AC_HELP();
     GM_5P0(1);
     AC_2P1();
@@ -463,7 +463,7 @@ using namespace Eigen;
         e->Throw("Value of X is out of allowed range (Only positive values).");
 
     int test=0;
-    
+
     for (count = 0;count<nElp1;++count)
       if (abs((*p1_float)[count]-(float)(*p1)[count]) > 0.000001) // don't know if a "machar" value exists
 	test=1;
@@ -554,10 +554,10 @@ using namespace Eigen;
       int size_of_s = sizeof(inline_help) / sizeof(inline_help[0]);
       e->Help(inline_help, size_of_s);
     }
-    
+
     DDoubleGDL* Xpos = e->GetParAs<DDoubleGDL>(0);
     SizeT nElpXpos = Xpos->N_Elements();
- 
+
     DDoubleGDL* Ypos = e->GetParAs<DDoubleGDL>(1);
     SizeT nElpYpos = Ypos->N_Elements();
 
@@ -576,7 +576,7 @@ using namespace Eigen;
     SizeT count, count1;
 
     // before all, we check wether inputs arrays does contains NaN or Inf
-    DStructGDL *Values =  SysVar::Values();   //MUST NOT BE STATIC, due to .reset 
+    DStructGDL *Values =  SysVar::Values();   //MUST NOT BE STATIC, due to .reset
     DDouble d_nan=(*static_cast<DDoubleGDL*>(Values->GetTag(Values->Desc()->TagIndex("D_NAN"), 0)))[0];
 
     for (count = 0; count < nElpXpos; ++count) {
@@ -602,7 +602,7 @@ using namespace Eigen;
       if (step < 0.0) {
 	if (flag_skip == 0) {
 	  cout << "SPL_INIT (warning): at least one x[n+1]-x[n] step is negative: X is assumed to be ordered" << endl;
-	  flag_skip = 1; 
+	  flag_skip = 1;
 	}
       }
       if (abs(step) == 0.0) {
@@ -616,24 +616,24 @@ using namespace Eigen;
     DDoubleGDL* U;
     U = new DDoubleGDL(nElpXpos, BaseGDL::NOZERO);
     U_guard.Reset(U); // delete upon exit
-    
+
     // may be we will have to check the size of these arrays ?
     static int yp0Ix=e->KeywordIx("YP0");
     BaseGDL* Yderiv0=e->GetKW(yp0Ix);
     DDoubleGDL* YP0;
 
-    if(Yderiv0 !=NULL && !isinf((*(YP0=e->GetKWAs<DDoubleGDL>(yp0Ix)))[0] )){ 
+    if(Yderiv0 !=NULL && !isinf((*(YP0=e->GetKWAs<DDoubleGDL>(yp0Ix)))[0] )){
       // first derivative at the point X0 is defined and different to Inf
       (*res)[0]=-0.5;
-      (*U)[0] = ( 3. / ((*Xpos)[1]-(*Xpos)[0])) * (((*Ypos)[1]-(*Ypos)[0]) / 
+      (*U)[0] = ( 3. / ((*Xpos)[1]-(*Xpos)[0])) * (((*Ypos)[1]-(*Ypos)[0]) /
 						   ((*Xpos)[1]-(*Xpos)[0]) - (*YP0)[0] );
 
-    }else{ 
+    }else{
       // YP0 is omitted or equal to Inf
       (*res)[0]=0.;
       (*U)[0]=0.;
     }
-  
+
     double psig, pu, x, xm, xp, y, ym, yp, p, dx, qn;
 
     for (count = 1; count < nElpXpos-1; ++count) {
@@ -641,12 +641,12 @@ using namespace Eigen;
       xm=(*Xpos)[count-1];
       xp=(*Xpos)[count+1];
       psig=(x-xm)/(xp-xm);
-      
+
       y=(*Ypos)[count];
       ym=(*Ypos)[count-1];
       yp=(*Ypos)[count+1];
       pu=((ym-y)/(xm-x)-(y-yp)/(x-xp))/(xm-xp);
-      
+
       p=psig*(*res)[count-1]+2.;
       (*res)[count]=(psig-1.)/p;
       (*U)[count]=(6.00*pu-psig*(*U)[count-1])/p;
@@ -655,8 +655,8 @@ using namespace Eigen;
     BaseGDL* YderivN=e->GetKW(ypn_1Ix);
     DDoubleGDL* YPN;
 
-    if(YderivN !=NULL && !isinf((*(YPN=e->GetKWAs<DDoubleGDL>(ypn_1Ix)))[0] )){ 
-      // first derivative at the point XN-1 is defined and different to Inf 
+    if(YderivN !=NULL && !isinf((*(YPN=e->GetKWAs<DDoubleGDL>(ypn_1Ix)))[0] )){
+      // first derivative at the point XN-1 is defined and different to Inf
       (*res)[nElpXpos-1] =0.;
       qn=0.5;
 
@@ -667,18 +667,18 @@ using namespace Eigen;
       // YPN_1 is omitted or equal to Inf
       qn=0.;
       (*U)[nElpXpos-1]=0.;
-    } 
+    }
 
     (*res)[nElpXpos-1] =((*U)[nElpXpos-1]-qn*(*U)[nElpXpos-2])/(qn*(*res)[nElpXpos-2]+ 1.);
 
     for (count = nElpXpos-2; count != -1; --count){
       (*res)[count] =(*res)[count]*(*res)[count+1]+(*U)[count];
     }
-      
+
     GM_CV0();
-    
+
   }
-  
+
   BaseGDL* spl_interp_fun( EnvT* e)
   {
     static int HELPIx=e->KeywordIx("HELP");
@@ -694,11 +694,11 @@ using namespace Eigen;
 	"This function should be called only after use of SPL_INIT() !"};
       int size_of_s = sizeof(inline_help) / sizeof(inline_help[0]);
       e->Help(inline_help, size_of_s);
-    }   
+    }
 
     DDoubleGDL* Xpos = e->GetParAs<DDoubleGDL>(0);
     SizeT nElpXpos = Xpos->N_Elements();
-    DType t0 = e->GetParDefined(0)->Type(); 
+    DType t0 = e->GetParDefined(0)->Type();
 
     DDoubleGDL* Ypos = e->GetParAs<DDoubleGDL>(1);
     SizeT nElpYpos = Ypos->N_Elements();
@@ -709,10 +709,10 @@ using namespace Eigen;
     // Do the 3 arrays have same lengths ?
     if ((nElpXpos != nElpYpos) || (nElpXpos != nElpYderiv2))
       e->Throw("Arguments XA, YA, and Y2A must have the same number of elements.");
-    
+
     DDoubleGDL* Xnew = e->GetParAs<DDoubleGDL>(3);
     SizeT nElpXnew = Xnew->N_Elements();
-    
+
     DDoubleGDL* res;
     res = new DDoubleGDL(nElpXnew, BaseGDL::NOZERO);
 
@@ -732,7 +732,7 @@ using namespace Eigen;
       }
       h=(*Xpos)[ihi]-(*Xpos)[ilo];
       if (abs(h) == 0.0)  e->Throw("SPL_INTERP: Bad XA input (XA not ordered or zero step in XA).");
-      
+
       if (debug == 1) cout << "h " << h << " lo/hi" << ilo << " " <<ihi<< endl;
       aa=((*Xpos)[ihi]-xcur)/h;
       bb=(xcur-(*Xpos)[ilo])/h;
@@ -743,27 +743,136 @@ using namespace Eigen;
     GM_CV0();
   }
 
-  BaseGDL* sobel_fun( EnvT* e){
-    e->Throw( "sorry, SOBEL not ready.");
+
+  template<typename T2,typename T,typename T3>
+  T2* Sobel_Template(T* p0,T3 a)
+  {
+    SizeT nbX = p0->Dim(0);
+    SizeT nbY = p0->Dim(1);
+    T2* res = new T2(p0->Dim(), BaseGDL::NOZERO);
+
+    //DDoubleGDL z = new DDoubleGDL[nbX,nbY];
+    for( SizeT k=0; k<=nbY-1; k++)
+      {
+        (*res)[0+nbX*k]=0;
+        (*res)[nbX-1+nbX*k]=0;
+      }
+    for( SizeT j=0; j<= nbX-1; j++)
+      {
+        (*res)[j+0]=0;
+        (*res)[j+nbX*(nbY-1)]=0;
+      }
+
+
+    for( SizeT k=1; k<=nbY-2; k++)
+      {
+        for( SizeT j=1; j<= nbX-2; j++)
+	  {
+            a =   labs    ((*p0)[j+1+nbX*(k+1)]+2*(*p0)[j+1+nbX*k]+(*p0)[j+1+nbX*(k-1)]
+			   -    ((*p0)[j-1+nbX*(k+1)]+2*(*p0)[j-1+nbX*k]+(*p0)[j-1+nbX*(k-1)]))
+	      +
+	      labs    ((*p0)[j-1+nbX*(k-1)]+2*(*p0)[j+nbX*(k-1)]+(*p0)[j+1+nbX*(k-1)]
+		       -   ((*p0)[j-1+nbX*(k+1)]+2*(*p0)[j+nbX*(k+1)]+(*p0)[j+1+nbX*(k+1)]));
+            (*res)[j+nbX*k]=a;
+	  }
+      }
+
+    return res;
+  }
+  BaseGDL* sobel_fun( EnvT* e)
+  {
+    BaseGDL* p0 = e->GetParDefined(0);
+
+    string txt=" expression not allowed in this context: ";
+    if (p0->Type() == GDL_STRING) e->Throw("String"+txt+ e->GetParString(0));
+    if (p0->Type() == GDL_PTR) e->Throw("Pointer"+txt+ e->GetParString(0));
+    if (p0->Type() == GDL_STRUCT) e->Throw("Structure"+txt+ e->GetParString(0));
+    if (p0->Type() == GDL_OBJ) e->Throw("Object"+txt+ e->GetParString(0));
+
+    if( p0->Rank() != 2)
+      e->Throw( "Array must have 2 dimensions: "+ e->GetParString(0));
+
+    switch (p0->Type()) {
+    case GDL_BYTE:{
+      long int a;
+      return Sobel_Template<DIntGDL>(static_cast<DByteGDL*>(p0),a);
+    }
+    case GDL_INT: {long int a;
+	return Sobel_Template<DIntGDL>(static_cast<DIntGDL*> (p0),a);
+    }
+    case GDL_UINT:{long int a;
+	return Sobel_Template<DUIntGDL>(static_cast<DUIntGDL*> (p0),a);
+    }
+    case GDL_LONG:{long int a;
+	return Sobel_Template<DLongGDL>(static_cast<DLongGDL*> (p0),a);
+    }
+    case GDL_ULONG:{long int a;
+	return Sobel_Template<DULongGDL>(static_cast<DULongGDL*> (p0),a);
+    }
+    case GDL_LONG64:{long int a;
+	return Sobel_Template<DLong64GDL>(static_cast<DLong64GDL*> (p0),a);
+    }
+    case GDL_ULONG64:{long int a;
+	return Sobel_Template<DULong64GDL>(static_cast<DULong64GDL*> (p0),a);
+    }
+    case GDL_FLOAT:{long double a;
+	return Sobel_Template<DFloatGDL>(static_cast<DFloatGDL*> (p0),a);
+    }
+    case GDL_DOUBLE: {long double a;
+	return Sobel_Template<DDoubleGDL>(static_cast<DDoubleGDL*> (p0),a);
+    }
+    case GDL_COMPLEX: { long int a;
+	DDoubleGDL* p0 = e->GetParAs<DDoubleGDL>(0);
+	return Sobel_Template<DComplexGDL>(static_cast<DDoubleGDL*> (p0),a);
+    }
+    case GDL_COMPLEXDBL:{long double a;
+	DDoubleGDL* p0 = e->GetParAs<DDoubleGDL>(0);
+	return Sobel_Template<DComplexDblGDL>(static_cast<DDoubleGDL*> (p0),a);
+    }
+
+    default: e->Throw( "Should not reach this point, please report");
+
+    }
     return NULL;
   }
 
   BaseGDL* roberts_fun( EnvT* e){
-  
-    DDoubleGDL* p0 = e->GetParAs<DDoubleGDL>(0);
-    if( p0->Rank() != 2)
+
+    //    BaseGDL* p0 = e->GetParDefined(0);
+
+    int type=e->GetParDefined(0)->Type();
+
+    string txt=" expression not allowed in this context: ";
+    if (type == GDL_STRING) e->Throw("String"+txt+ e->GetParString(0));
+    if (type == GDL_PTR) e->Throw("Pointer"+txt+ e->GetParString(0));
+    if (type == GDL_STRUCT) e->Throw("Structure"+txt+ e->GetParString(0));
+    if (type == GDL_OBJ) e->Throw("Object"+txt+ e->GetParString(0));
+
+    //    DDoubleGDL* p0 = e->GetParAs<DDoubleGDL>(0);
+    if (e->GetParDefined(0)->Rank()  != 2)
       e->Throw( "Array must have 2 dimensions: "+ e->GetParString(0));
+    
+    DDoubleGDL* p0 = e->GetParAs<DDoubleGDL>(0);
 
     DDoubleGDL* res = new DDoubleGDL(p0->Dim(), BaseGDL::NOZERO);
     SizeT nbX = p0->Dim(0);
     SizeT nbY = p0->Dim(1);
-    
-    int debug=0;
-    if (debug ==1) {
-      cout << "nbX : " << nbX << endl; 
-      cout << "nbY : " << nbY << endl; 
-    }
 
+    bool debug=false;
+    if (debug) {
+      cout << "nbX : " << nbX << endl;
+      cout << "nbY : " << nbY << endl;
+    }
+    for( SizeT k=0; k<=nbY-1; k++)
+      {
+
+        (*res)[nbX-1+nbX*k]=0;
+      }
+    for( SizeT j=0; j<= nbX-1; j++)
+      {
+
+        (*res)[j+nbX*(nbY-1)]=0;
+      }
     //DDoubleGDL z = new DDoubleGDL[nbX,nbY];
     for( SizeT k=0; k<nbY-1; k++) {
       for( SizeT j=0; j< nbX-1; j++) {
@@ -773,12 +882,417 @@ using namespace Eigen;
     }
     return res;
   }
-  
-  BaseGDL* prewitt_fun( EnvT* e){
-    e->Throw( "sorry, PREWITT not ready.");
+
+  template<typename T2,typename T,typename T3>
+  T2* Prewitt_Template(T* p0,T3 a)
+  {
+    SizeT nbX = p0->Dim(0);
+    SizeT nbY = p0->Dim(1);
+    T2* res = new T2(p0->Dim(), BaseGDL::NOZERO);
+
+    bool debug=false;
+
+    //DDoubleGDL z = new DDoubleGDL[nbX,nbY];
+    for( SizeT k=0; k<=nbY-1; k++)
+      {
+        (*res)[0+nbX*k]=0;
+        (*res)[nbX-1+nbX*k]=0;
+      }
+    for( SizeT j=0; j<= nbX-1; j++)
+      {
+        (*res)[j+0]=0;
+        (*res)[j+nbX*(nbY-1)]=0;
+      }
+
+    T3 Gx=0,Gy=0;
+    double r=0;
+
+    for( SizeT k=1; k<=nbY-2; k++)
+      {
+        for( SizeT j=1; j<= nbX-2; j++)
+	  {
+            Gx=     ((*p0)[j+1+nbX*(k+1)]+(*p0)[j+1+nbX*k]+(*p0)[j+1+nbX*(k-1)]
+		     -   ((*p0)[j-1+nbX*(k+1)]+(*p0)[j-1+nbX*k]+(*p0)[j-1+nbX*(k-1)]));
+
+            Gy=     ((*p0)[j-1+nbX*(k-1)]+(*p0)[j+nbX*(k-1)]+(*p0)[j+1+nbX*(k-1)]
+		     -   ((*p0)[j-1+nbX*(k+1)]+(*p0)[j+nbX*(k+1)]+(*p0)[j+1+nbX*(k+1)]));
+
+            if (debug) cout<<Gx<<" : "<<Gy<<"\t";
+            r=sqrt(Gx * Gx + Gy * Gy);
+            (*res)[j+nbX*k]=r;
+	  }
+        if (debug) cout<< endl;
+      }
+
+    return res;
+  }
+
+  BaseGDL* prewitt_fun( EnvT* e)
+  {
+    BaseGDL* p0 = e->GetParDefined(0);
+
+    string txt=" expression not allowed in this context: ";
+    if (p0->Type() == GDL_STRING) e->Throw("String"+txt+ e->GetParString(0));
+    if (p0->Type() == GDL_PTR) e->Throw("Pointer"+txt+ e->GetParString(0));
+    if (p0->Type() == GDL_STRUCT) e->Throw("Structure"+txt+ e->GetParString(0));
+    if (p0->Type() == GDL_OBJ) e->Throw("Object"+txt+ e->GetParString(0));
+
+    if( p0->Rank() != 2)
+      e->Throw( "Array must have 2 dimensions: "+ e->GetParString(0));
+
+    switch (p0->Type()) {
+    case GDL_BYTE:{
+      long int a;
+      return Prewitt_Template<DIntGDL>(static_cast<DByteGDL*>(p0),a);
+    }
+    case GDL_INT: {long int a;
+	return Prewitt_Template<DIntGDL>(static_cast<DIntGDL*> (p0),a);
+    }
+    case GDL_UINT:{long int a;
+	return Prewitt_Template<DUIntGDL>(static_cast<DUIntGDL*> (p0),a);
+    }
+    case GDL_LONG:{long int a;
+	return Prewitt_Template<DLongGDL>(static_cast<DLongGDL*> (p0),a);
+    }
+    case GDL_ULONG:{long int a;
+	return Prewitt_Template<DULongGDL>(static_cast<DULongGDL*> (p0),a);
+    }
+    case GDL_LONG64:{long int a;
+	return Prewitt_Template<DLong64GDL>(static_cast<DLong64GDL*> (p0),a);
+    }
+    case GDL_ULONG64:{long int a;
+	return Prewitt_Template<DULong64GDL>(static_cast<DULong64GDL*> (p0),a);
+    }
+    case GDL_FLOAT:{long int a;
+	return Prewitt_Template<DFloatGDL>(static_cast<DFloatGDL*> (p0),a);
+    }
+    case GDL_DOUBLE: {long int a;
+	return Prewitt_Template<DDoubleGDL>(static_cast<DDoubleGDL*> (p0),a);
+    }
+    case GDL_COMPLEX: { long int a;
+	DDoubleGDL* p0 = e->GetParAs<DDoubleGDL>(0);
+	return Prewitt_Template<DComplexGDL>(static_cast<DDoubleGDL*> (p0),a);
+    }
+    case GDL_COMPLEXDBL:{long int a;
+	DDoubleGDL* p0 = e->GetParAs<DDoubleGDL>(0);
+	return Prewitt_Template<DComplexDblGDL>(static_cast<DDoubleGDL*> (p0),a);
+    }
+
+    default: e->Throw( "Should not reach this point, please report");
+    }
     return NULL;
   }
 
+  BaseGDL* erode_fun( EnvT* e){
+
+    SizeT nParam = e->NParam(1);
+
+    DIntGDL* p0 = e->GetParAs<DIntGDL>(0);
+    DIntGDL* p1 = e->GetParAs<DIntGDL>(1);
+
+    static int preserveix = e->KeywordIx("PRESERVE_TYPE");
+    static int grayix = e->KeywordIx("GRAY");
+
+    switch ( p0->Rank()) {
+    case 1:{if(p1->Rank()!=1){e->Throw( "Array must have 1 dimensions: "+ e->GetParString(1));}break;}
+    case 2:{if(p1->Rank()!=2){e->Throw( "Array must have 2 dimensions: "+ e->GetParString(1));}break;}
+    case 3:{if(p1->Rank()!=3){e->Throw( "Array must have 3 dimensions: "+ e->GetParString(1));}break;}
+    default:{e->Throw( "Array must have 2 or 3 dimensions: "+ e->GetParString(0)); break;}
+    }
+
+    if (e->GetKW(grayix) != NULL)
+      {
+	e->Throw( "/GRAY not yet programmed.");
+      }
+
+    DByteGDL* res = new DByteGDL(p0->Dim(), BaseGDL::NOZERO);
+
+    if (e->GetKW(preserveix) != NULL)
+      {
+	switch (p0->Type())
+	  {
+	  case GDL_BYTE:{
+	    DByteGDL* res = new DByteGDL(p0->Dim(), BaseGDL::NOZERO);
+	    break;
+	  }
+	  case GDL_UINT:{
+	    DUIntGDL* res = new DUIntGDL(p0->Dim(), BaseGDL::NOZERO);
+	    break;
+	  }
+	  case GDL_ULONG:{
+	    DULongGDL* res = new DULongGDL(p0->Dim(), BaseGDL::NOZERO);
+	    break;
+	  }
+	  default:{
+	    e->Throw( "PRESERVE_TYPE valid only with BYTE, UINT, and ULONG.");
+	    break;
+	  }
+	  }
+      }
+
+    long int nbX = p0->Dim(0);
+    long int nbY = p0->Dim(1);
+    long int nbZ = p0->Dim(2);
+
+    long int mX = p1->Dim(0);
+    long int mY = p1->Dim(1);
+    long int mZ = p1->Dim(2);
+
+
+    long int    midx= ceil(mX/2);
+    long int    midy= ceil(mY/2);
+    long int    midz= ceil(mZ/2);
+
+
+    if (p0->Rank()==2)
+      {
+        nbZ = 1;
+        mZ = 1;
+      }
+
+    if (p0->Rank()==1)
+      {
+        nbZ = 1;
+        mZ = 1;
+        nbY = 1;
+        mY = 1;
+      }
+    if (nParam>=3)
+      {
+	DIntGDL* p2 = e->GetParAs<DIntGDL>(2);
+	midx=(*p2)[0];
+      }
+    if (nParam>=4)
+      {
+        DIntGDL* p2 = e->GetParAs<DIntGDL>(3);
+        midy=(*p2)[0];
+      }
+    if (nParam>=5)
+      {
+        DIntGDL* p2 = e->GetParAs<DIntGDL>(4);
+        midz=(*p2)[0];
+      }
+
+    bool debug=false;
+    if (debug) {
+      cout <<"midx= " <<midx<<endl;
+      cout <<"midy= " <<midy<<endl;
+      cout <<"midzs= " <<midz<<endl;
+      
+      cout <<"x= " <<nbX<<endl;
+      cout <<"y= " <<nbY<<endl;
+      cout <<"z= " <<nbZ<<endl;
+    }
+    //DDoubleGDL z = new DDoubleGDL[nbX,nbY];
+    bool bo=false;
+    for( SizeT l=-midz; l<nbZ; l++)
+      {
+        for( long int k=-midy; k<nbY; k++)
+	  {
+            for( long int j=-midx; j<nbX; j++)
+	      {
+		for( long int x=0; x<mX; x++)
+		  {
+		    if (bo==true)
+		      break;
+		    if (((j+x)>=nbX)|((j+x)<0))
+		      {
+                        bo=true;
+                        break;
+		      }
+		    for( long int y=0; y<mY; y++)
+		      {
+                        if (bo==true)
+			  break;
+                        if (((k+y)>=nbY)|((k+y)<0))
+			  {
+			    bo=true;
+			    break;
+			  }
+			for( long int z=0; z<mZ; z++)
+			  {
+			    //      cout<<"fait z "<< z <<" " ;
+                            if (((l+z)>=nbZ)|((l+z)<0))
+			      {
+				bo=true;
+				break;
+			      }
+                            if ((*p1)[x+mX*y+z*(mX*mY)]==1)
+			      if ((*p0)[(j+x)+nbX*(k+y)+(l+z)*(nbX*nbY)]
+				  !=(*p1)[x+mX*y+z*(mX*mY)])
+                                {
+				  bo=true;
+				  break;
+                                }
+			  }
+		      }
+		  }
+                if (bo==true)
+		  {
+                    if ((j+midx<nbX)&&(k+midy<nbY)&&(l+midz<nbZ))
+		      (*res)[(j+midx)+nbX*(k+midy)+(l+midz)*(nbX*nbY)] =0;
+                    bo=false;
+		  }else{     if ((j+midx<nbX)&&(k+midy<nbY)&&(l+midz<nbZ))
+		    (*res)[(j+midx)+nbX*(k+midy)+(l+midz)*(nbX*nbY)] =1;
+		}
+	      }
+	  }
+      }
+    return res;
+  }
+
+  BaseGDL* dilate_fun( EnvT* e)
+  {
+    SizeT nParam = e->NParam(1);
+
+    DIntGDL* p0 = e->GetParAs<DIntGDL>(0);
+    DIntGDL* p1 = e->GetParAs<DIntGDL>(1);
+
+    static int preserveix = e->KeywordIx("PRESERVE_TYPE");
+    static int grayix = e->KeywordIx("GRAY");
+
+    switch ( p0->Rank()) {
+    case 1:{if(p1->Rank()!=1){e->Throw( "Array must have 1 dimensions: "+ e->GetParString(1));}break;}
+    case 2:{if(p1->Rank()!=2){e->Throw( "Array must have 2 dimensions: "+ e->GetParString(1));}break;}
+    case 3:{if(p1->Rank()!=3){e->Throw( "Array must have 3 dimensions: "+ e->GetParString(1));}break;}
+    default:{e->Throw( "Array must have 2 or 3 dimensions: "+ e->GetParString(0)); break;}
+    }
+
+    if (e->GetKW(grayix) != NULL)
+      {
+	e->Throw( "/GRAY not yet programmed.");
+      }
+
+    DByteGDL* res = new DByteGDL(p0->Dim(), BaseGDL::NOZERO);
+
+    if (e->GetKW(preserveix) != NULL)
+      {
+	switch (p0->Type())
+	  {
+	  case GDL_BYTE:{
+	    DByteGDL* res = new DByteGDL(p0->Dim(), BaseGDL::NOZERO);
+	    break;
+	  }
+	  case GDL_UINT:{
+	    DUIntGDL* res = new DUIntGDL(p0->Dim(), BaseGDL::NOZERO);
+	    break;
+	  }
+	  case GDL_ULONG:{
+	    DULongGDL* res = new DULongGDL(p0->Dim(), BaseGDL::NOZERO);
+	    break;
+	  }
+	  default:{
+	    e->Throw( "PRESERVE_TYPE valid only with BYTE, UINT, and ULONG.");
+	    break;
+	  }
+	  }
+      }
+
+    long int nbX = p0->Dim(0);
+    long int nbY = p0->Dim(1);
+    long int nbZ = p0->Dim(2);
+
+    long int mX = p1->Dim(0);
+    long int mY = p1->Dim(1);
+    long int mZ = p1->Dim(2);
+
+
+    long int    midx= ceil(mX/2);
+    long int    midy= ceil(mY/2);
+    long int    midz= ceil(mZ/2);
+
+
+    if (p0->Rank()==2)
+      {
+        nbZ = 1;
+        mZ = 1;
+      }
+
+    if (p0->Rank()==1)
+      {
+        nbZ = 1;
+        mZ = 1;
+        nbY = 1;
+        mY = 1;
+      }
+    if (nParam>=3)
+      {
+	DIntGDL* p2 = e->GetParAs<DIntGDL>(2);
+	midx=(*p2)[0];
+      }
+    if (nParam>=4)
+      {
+        DIntGDL* p2 = e->GetParAs<DIntGDL>(3);
+        midy=(*p2)[0];
+      }
+    if (nParam>=5)
+      {
+        DIntGDL* p2 = e->GetParAs<DIntGDL>(4);
+        midz=(*p2)[0];
+      }
+
+    bool debug=false;
+    if (debug) {
+      cout <<"midx= " <<midx<<endl;
+      cout <<"midy= " <<midy<<endl;
+      cout <<"midzs= " <<midz<<endl;
+      
+      cout <<"x= " <<nbX<<endl;
+      cout <<"y= " <<nbY<<endl;
+      cout <<"z= " <<nbZ<<endl;
+    }
+    //DDoubleGDL z = new DDoubleGDL[nbX,nbY];
+    bool bo=false;
+    for( SizeT l=-midz; l<nbZ; l++)
+      {
+        for( long int k=-midy; k<nbY; k++)
+	  {
+            for( long int j=-midx; j<nbX; j++)
+	      {
+		for( long int x=0; x<mX; x++)
+		  {
+		    if (bo==true)
+		      break;
+		    if (((j+x)<nbX)&&((j+x)>=0))
+		      {
+			for( long int y=0; y<mY; y++)
+			  {
+                            if (bo==true)
+			      break;
+			    if (((k+y)<nbY)&&((k+y)>=0))
+			      {
+				for( long int z=0; z<mZ; z++)
+				  {
+				    //      cout<<"fait z "<< z <<" " ;
+				    if (((l+z)<nbZ)&&((l+z)>=0))
+				      {
+                                        if ((*p1)[x+mX*y+z*(mX*mY)]==1)
+					  if ((*p0)[(j+x)+nbX*(k+y)+(l+z)*(nbX*nbY)]
+					      ==(*p1)[x+mX*y+z*(mX*mY)])
+                                            {
+					      bo=true;
+					      break;
+                                            }
+				      }
+				  }
+			      }
+			  }
+		      }
+		  }
+                if (bo==true)
+		  {
+                    if ((j+midx<nbX)&&(k+midy<nbY)&&(l+midz<nbZ))
+		      (*res)[(j+midx)+nbX*(k+midy)+(l+midz)*(nbX*nbY)] =1;
+                    bo=false;
+		  }else{     if ((j+midx<nbX)&&(k+midy<nbY)&&(l+midz<nbZ))
+		    (*res)[(j+midx)+nbX*(k+midy)+(l+midz)*(nbX*nbY)] =0;
+		}
+	      }
+	  }
+      }
+    return res;
+  }
+
   BaseGDL* matrix_multiply( EnvT* e)
   {
     BaseGDL* a = e->GetParDefined(0);
@@ -812,31 +1326,31 @@ using namespace Eigen;
     // GDL_COMPLEX op GDL_DOUBLE = GDL_COMPLEXDBL
     DType cxTy = PromoteComplexOperand( aTy, bTy);
     if( cxTy != GDL_UNDEF)
-    {
-      a = a->Convert2( cxTy, BaseGDL::COPY);
-      aGuard.Init( a);
-      b = b->Convert2( cxTy, BaseGDL::COPY);
-      bGuard.Init( b);
-    }
+      {
+	a = a->Convert2( cxTy, BaseGDL::COPY);
+	aGuard.Init( a);
+	b = b->Convert2( cxTy, BaseGDL::COPY);
+	bGuard.Init( b);
+      }
     else
-    {
-      DType cTy = PromoteMatrixOperands( aTy, bTy);
+      {
+	DType cTy = PromoteMatrixOperands( aTy, bTy);
+
+	if( aTy != cTy)
+	  {
+	    a = a->Convert2( cTy, BaseGDL::COPY);
+	    aGuard.Init( a);
+	  }
+	if( bTy != cTy)
+	  {
+	    b = b->Convert2( cTy, BaseGDL::COPY);
+	    bGuard.Init( b);
+	  }
+      }
 
-      if( aTy != cTy)
-	{
-	  a = a->Convert2( cTy, BaseGDL::COPY);
-	  aGuard.Init( a);
-	}
-      if( bTy != cTy)
-	{
-	  b = b->Convert2( cTy, BaseGDL::COPY);
-	  bGuard.Init( b);
-	}
-    }
-    
     // might use eigen3
     return a->MatrixOp( b, at, bt);
   }
-  
+
 } // namespace
 
