@@ -45,10 +45,6 @@
 #define isfinite _finite
 #define signbit(d) (d < 0.0)? 1:0
 #endif
-//dirty patch to circumvent icc v.14.0.0 fatal error ("__builtin_signbit not found")
-#ifdef __INTEL_COMPILER
-#define signbit(d) (d < 0.0)? 1:0
-#endif
 namespace lib {
 
   using namespace std;
@@ -57,14 +53,6 @@ namespace lib {
   using std::isnan;
 #endif
 
-#ifdef PL_HAVE_QHULL
-extern "C" {
-  //prevent qhull using its own memory tricks. Stay on the safe side.
-    #define qh_NOmem 1
-    #include <libqhull/qhull_a.h>
-}
-#endif
-
   BaseGDL* machar_fun( EnvT* e)
   {
     long int ibeta, it, irnd, ngrd, machep, negep, iexp, minexp, maxexp;
@@ -205,39 +193,58 @@ extern "C" {
   // general template
    template< typename T, bool> struct finite_helper
    {
-     inline static BaseGDL* do_it(T* src, bool kwNaN, bool kwInfinity)
-     {
+    inline static BaseGDL* do_it(T* src, bool kwNaN, bool kwInfinity)
+    {
        DByteGDL* res = new DByteGDL( src->Dim(), BaseGDL::NOZERO);
        SizeT nEl = src->N_Elements();
-       if (kwNaN)
+
+	 #pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nEl))
+	 {
+       if (kwNaN){
+		#pragma omp for
          for ( SizeT i=0; i<nEl; ++i) (*res)[ i] = isnan((*src)[ i]);
-       else if (kwInfinity)
+       }
+       else if (kwInfinity){
+		#pragma omp for
          for ( SizeT i=0; i<nEl; ++i) (*res)[ i] = isinf((*src)[ i]);
-       else
+       }
+       else{
+		#pragma omp for
          for ( SizeT i=0; i<nEl; ++i) (*res)[ i] = isfinite((*src)[ i]);
-       return res;
+       }
      }
+     return res;
+    }
    };
 
    // partial specialization for GDL_COMPLEX, DCOMPLEX
    template< typename T> struct finite_helper<T, true>
    {
-     inline static BaseGDL* do_it(T* src, bool kwNaN, bool kwInfinity)
-     {
+    inline static BaseGDL* do_it(T* src, bool kwNaN, bool kwInfinity)
+    {
        DByteGDL* res = new DByteGDL( src->Dim(), BaseGDL::NOZERO);
        SizeT nEl = src->N_Elements();
-       if (kwNaN)
+	 #pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nEl))
+	 {
+       if (kwNaN){
+		#pragma omp for
          for ( SizeT i=0; i<nEl; ++i) 
      	    (*res)[ i] = isnan((*src)[ i].real()) || isnan((*src)[ i].imag());
-       else if (kwInfinity)
+	   }
+       else if (kwInfinity){
+		#pragma omp for
          for ( SizeT i=0; i<nEl; ++i)
            (*res)[ i] = isinf((*src)[ i].real()) || isinf((*src)[ i].imag());
-       else
+	   }
+       else{
+		#pragma omp for
          for ( SizeT i=0; i<nEl; ++i)
            (*res)[ i] = isfinite((*src)[ i].real()) && 
                         isfinite((*src)[ i].imag());
-       return res;
+	   }
      }
+     return res;
+    }
    };
 
    template< typename T, bool IS_COMPLEX>
@@ -247,67 +254,73 @@ extern "C" {
        do_it(static_cast<T*>(src), kwNaN, kwInfinity);
    };
 
+   //general signed template
    template< typename T, bool> struct finite_helper_sign
    {
      inline static BaseGDL* do_it(T* src, bool kwNaN, bool kwInfinity, DLong kwSign)
      {
 
-// #pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nEl))
 
        DByteGDL* res = new DByteGDL( src->Dim(), BaseGDL::ZERO); // ::ZERO is not working
        SizeT nEl = src->N_Elements();
-
-       //       for ( SizeT i=0; i<nEl; ++i) (*res)[i]=0;
-
-       if (kwInfinity) {
-	 if (kwSign > 0) {
-// #pragma omp for
-	   for ( SizeT i=0; i<nEl; ++i) {
-	     if (isinf((*src)[ i]) && (signbit((*src)[ i]) == 0)) (*res)[i]=1; 
-	   }
-	 } else {
-// #pragma omp for
-	   for ( SizeT i=0; i<nEl; ++i) {
-	     if (isinf((*src)[ i]) && (signbit((*src)[ i]) != 0)) (*res)[i]=1; 
-	   }
-	 }
-	 return res;	 
-       }
-       if (kwNaN) {
-	 if (kwSign > 0) {
-// #pragma omp for
-	   for ( SizeT i=0; i<nEl; ++i) {
-	     if (isnan((*src)[ i]) && (signbit((*src)[ i]) == 0)) (*res)[i]=1; 
-	   }
-	 } else {
-// #pragma omp for
-	   for ( SizeT i=0; i<nEl; ++i) {
-	     if (isnan((*src)[ i]) && (signbit((*src)[ i]) != 0)) (*res)[i]=1; 
-	   }
+	if (kwInfinity || kwNaN)
+	{
+	 #pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nEl))
+	 {
+		if (kwInfinity) {
+			if (kwSign > 0) {
+				#pragma omp for
+				for ( SizeT i=0; i<nEl; ++i) {
+					if (isinf((*src)[ i]) && (signbit((*src)[ i]) == 0)) (*res)[i]=1; 
+				}
+			} else {
+				#pragma omp for
+				for ( SizeT i=0; i<nEl; ++i) {
+					if (isinf((*src)[ i]) && (signbit((*src)[ i]) != 0)) (*res)[i]=1; 
+				}
+			}
+		}
+		if (kwNaN) {
+			if (kwSign > 0) {
+				#pragma omp for
+				for ( SizeT i=0; i<nEl; ++i) {
+					if (isnan((*src)[ i]) && (signbit((*src)[ i]) == 0)) (*res)[i]=1; 
+				}
+			} else {
+				#pragma omp for
+				for ( SizeT i=0; i<nEl; ++i) {
+					if (isnan((*src)[ i]) && (signbit((*src)[ i]) != 0)) (*res)[i]=1; 
+				}
+			}
+		}
 	 }
 	 return res;
-       }
-      assert( false);
+	}
+		assert( false);
      }
    };
 
    // partial specialization for GDL_COMPLEX, DCOMPLEX
    template< typename T> struct finite_helper_sign<T, true>
    {
-     inline static BaseGDL* do_it(T* src, bool kwNaN, bool kwInfinity, DLong kwSign)
-     {
+    inline static BaseGDL* do_it(T* src, bool kwNaN, bool kwInfinity, DLong kwSign)
+    {
        DByteGDL* res = new DByteGDL( src->Dim(), BaseGDL::ZERO);
        SizeT nEl = src->N_Elements();
        
-       for ( SizeT i=0; i<nEl; ++i)
+	 #pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nEl))
 	 {
+	  #pragma omp for
+       for ( SizeT i=0; i<nEl; ++i)
+	  {
 	   if      ((kwInfinity && isinf((*src)[ i].real()) || kwNaN && isnan((*src)[ i].real())) && signbit((*src)[ i].real())==0 && kwSign > 0) (*res)[i]=1;
 	   else if ((kwInfinity && isinf((*src)[ i].imag()) || kwNaN && isnan((*src)[ i].imag())) && signbit((*src)[ i].imag())==0 && kwSign > 0) (*res)[i]=1;
-	   else if ((kwInfinity && isinf((*src)[ i].real()) || kwNaN && isnan((*src)[ i].real())) && signbit((*src)[ i].real())==1 && kwSign < 0) (*res)[i]=1;
-	   else if ((kwInfinity && isinf((*src)[ i].imag()) || kwNaN && isnan((*src)[ i].imag())) && signbit((*src)[ i].imag())==1 && kwSign < 0) (*res)[i]=1;	 
-	 }
-       return res;
-     }
+	   else if ((kwInfinity && isinf((*src)[ i].real()) || kwNaN && isnan((*src)[ i].real())) && signbit((*src)[ i].real())!=0 && kwSign < 0) (*res)[i]=1;
+	   else if ((kwInfinity && isinf((*src)[ i].imag()) || kwNaN && isnan((*src)[ i].imag())) && signbit((*src)[ i].imag())!=0 && kwSign < 0) (*res)[i]=1;	 
+	  }
+     } 
+     return res;
+    } 
    };
 
    template< typename T, bool IS_COMPLEX>
@@ -1791,240 +1804,4 @@ DDouble * generate_interpolation_kernel(int kernel_type, DDouble cubicParameter)
     return tab ;
 }
 
-// used in rk4jmg_fun below only
-//  void executeString( EnvBaseT* caller, istringstream *istr)
-//  {
-//    // P.S:  I don't know how this works.  Ask Marc.
-//
-//    RefDNode theAST;
-//    GDLLexer lexer(*istr, "",GDLParser::NONE);
-//    GDLParser& parser = lexer.Parser();
-//    parser.interactive();
-//    theAST = parser.getAST();
-//    RefDNode trAST;
-//    GDLTreeParser treeParser( caller);
-//    treeParser.interactive(theAST);
-//    trAST = treeParser.getAST();
-//    ProgNodeP progAST = ProgNode::NewProgNode( trAST);
-//    Guard< ProgNode> progAST_guard( progAST);
-//
-//	// Marc: necessary for correct FOR loop handling
-//	assert( dynamic_cast<EnvUDT*>(caller) != NULL);
-//    EnvUDT* env = static_cast<EnvUDT*>(caller);
-//    int nForLoopsIn = env->NForLoops();
-//    int nForLoops = ProgNode::NumberForLoops( progAST, nForLoopsIn);
-//	env->ResizeForLoops( nForLoops);
-//
-//    RetCode retCode = caller->Interpreter()->execute( progAST);
-//  
-//  	env->ResizeForLoops( nForLoopsIn);
-//}
-
-
-//  BaseGDL* rk4jmg_fun(EnvT* e)
-//  {  
-//    // Get current DOY HR MN SEC and form unique tag
-//    struct tm *curtime;
-//    time_t bintime;
-//    char time_str[128];
-//    time( &bintime);
-//    curtime = gmtime( &bintime);
-//    strftime( time_str, 128, "%j%H%M%S", curtime);
-//    DString tag = time_str;
-//
-//    SizeT nParam = e->NParam(5);
-//    // Result = RK4( Y, Dydx, X, H, Derivs [, /GDL_DOUBLE] )
-//
-//    BaseGDL* par = e->GetParDefined( 0);
-//
-//    // Get # of y-elements
-//    SizeT nEy = par->N_Elements();
-//    //    cout << "nEy: " << nEy << endl;
-//
-//    bool doubleFlag = false;
-//    if ( par->Type() == GDL_DOUBLE) doubleFlag = true;
-//    static int DOUBLEIx = e->KeywordIx("DOUBLE");
-//    if ( e->KeywordSet( DOUBLEIx)) doubleFlag = true;
-//
-//    DString retTypeString;
-//    if ( doubleFlag) 
-//      retTypeString = "DOUBLE (";
-//    else
-//      retTypeString = "FLOAT (";
-//    //    cout << doubleFlag << endl;
-//
-//    // Get Name of GDL-code derivative function
-//    DString derivName;
-//    e->AssureScalarPar<DStringGDL>( 4, derivName); 
-//
-//
-//    // Check if GDL-code derivative function exist
-//    vector<DString> fList;
-//    bool found = false;
-//    for( FunListT::iterator i=funList.begin(); i != funList.end(); i++) {
-//      fList.push_back((*i)->ObjectName());
-//    }
-//    for( SizeT i = 0; i<funList.size(); ++i) {
-//	if ( StrUpCase(derivName) == fList[ i]) {
-//	  found = true;
-//	  break;
-//	}
-//    }
-//    if ( found == false) {
-//      return NULL;
-//    }
-//
-//
-//    ostringstream ostr;
-//    int xI;
-//
-//    // Get current level of calling stack
-//    EnvStackT& callStack = e->Interpreter()->CallStack();
-//    DLong curlevnum = callStack.size()-1;
-//
-//    // Get calling procedure
-//    DSubUD* pro = static_cast<DSubUD*>(callStack[curlevnum-1]->GetPro());
-//
-//    // Get total number of current variables & keywords at calling level
-//    SizeT nVar = pro->Size();
-//    SizeT nKey = pro->NKey();
-//
-//    // Get GDL variable names for y, dydx, x, h
-//    DString varName[4];
-//    DLong nTemp = 0;
-//    // For each RK4 function parameter 
-//    for( SizeT i = 0; i<4; ++i) {
-//      BaseGDL *val = e->GetPar( i);
-//      // Loop through all variables
-//      found = false;
-//      for( SizeT j = 0; j<nVar; ++j) {
-//	par = ((EnvT*)(callStack[curlevnum-1]))->GetPar( j-nKey);
-//
-//	// If match then get and save variable name
-//	if ( par == val) {
-//	  varName[i] = pro->GetVarName( j);
-//	  found = true;
-//	  break;
-//	}
-//      }
-//
-//      // If variable name not found then make temp variable
-//      if ( !found) {
-//	if ( i == 0) varName[i] = "TEMP_Y_" + tag;
-//	if ( i == 1) varName[i] = "TEMP_DYDX_" + tag;
-//	if ( i == 2) varName[i] = "TEMP_X_" + tag;
-//	if ( i == 3) varName[i] = "TEMP_H_" + tag;
-//
-//	SizeT u = pro->AddVar(StrUpCase(varName[i]));
-//	SizeT s = callStack[curlevnum-1]->AddEnv();
-//
-//	BaseGDL*& par = ((EnvT*)(callStack[curlevnum-1]))->GetPar( s-nKey);
-//	BaseGDL* res = e->GetPar( i)->Dup();
-//	memcpy(&par, &res, 4);
-//
-//	nTemp++;
-//      }
-//    }
-//
-//
-//    // Form input variable names
-//    DString Y    = varName[0];
-//    DString DYDX = varName[1];
-//    DString X    = varName[2];
-//    DString H    = varName[3];
-//
-//    DString H_2    = "0.5 * "        + varName[3];
-//    DString H_1_6  = "(1.D0 / 6) * " + varName[3];
-//
-//    // Form output variable names
-//    DString varName_K2 = "K2_" + tag;
-//    DString varName_K3 = "K3_" + tag;
-//    DString varName_K4 = "K4_" + tag;
-//    DString varName_Y1 = "Y1_" + tag;
-//
-//    // Build execution string for: k2 = f(x + h/2, y + h * k1/2)
-//    ostr << varName_K2.c_str() << " = " << derivName.c_str() << "(" ;
-//    ostr << X.c_str() << " + " << H_2.c_str() << ", ";
-//    ostr << Y.c_str() << " + " << H_2.c_str() << " * " << DYDX.c_str();
-//    ostr << ") & ";
-//
-//    // Build execution string for: k3 = f(x + h/2, y + h * k2/2)
-//    ostr << varName_K3.c_str() << " = " << derivName.c_str() << "(" ;
-//    ostr << X.c_str() << " + " << H_2.c_str() << ", ";
-//    ostr << Y.c_str() << " + " << H_2.c_str() << " * " << varName_K2.c_str();
-//    ostr << ") & ";
-//
-//    // Build execution string for: k4 = f(x + h, y + h * k3)
-//    ostr << varName_K4.c_str() << " = " << derivName.c_str() << "(" ;
-//    ostr << X.c_str() << " + " << H.c_str() << ", ";
-//    ostr << Y.c_str() << " + " << H.c_str() << " * " << varName_K3.c_str();
-//    ostr << ") & ";
-//
-//    // Build exec string for: yi+1 = yi + (1/6) * h * [k1 + 2k2 + 2k3 + k4]
-//    ostr << varName_Y1.c_str() << " = " << retTypeString.c_str() << Y.c_str();
-//    ostr << " + " << H_1_6.c_str() << " * (";
-//    ostr << DYDX.c_str() << " + 2 * " << varName_K2.c_str(); 
-//    ostr << " + 2 * " << varName_K3.c_str() << " + " << varName_K4.c_str();
-//    ostr << ") )";
-//
-//    DString line = ostr.rdbuf()->str();
-//    istringstream istr;
-//    istr.str(line+"\n");
-//    //    cout << line.c_str() << endl;
-//
-//    // Execute command string
-//    EnvBaseT* caller;
-//    caller = e->Caller();
-//// ms: commented out to comply with new stack handling
-////     e->Interpreter()->CallStack().pop_back();
-//
-//    executeString( caller, &istr);
-//
-//    // Retrieve return values for Y_N+1
-//    xI = pro->FindVar(StrUpCase( varName_Y1));
-//    par = ((EnvT*)(callStack[curlevnum-1]))->GetPar( xI-nKey);
-//
-//    DFloatGDL*  res_f;
-//    DDoubleGDL* res_d;
-//
-//    if ( doubleFlag) {
-//      res_d = new DDoubleGDL(nEy, BaseGDL::NOZERO);
-//
-//      for( SizeT i = 0; i<nEy; ++i) {
-//	(*res_d)[i] = (*(DDoubleGDL*) par)[i];
-//	//	cout << "y1 " << i << ": " << (*res_d)[i] << endl;
-//      }
-//    } else {
-//      res_f = new DFloatGDL(nEy, BaseGDL::NOZERO);
-//
-//      for( SizeT i = 0; i<nEy; ++i) {
-//	(*res_f)[i] = (*(DFloatGDL*) par)[i];
-//	//	cout << "y1 " << i << ": " << (*res_f)[i] << endl;
-//      }
-//    }
-//
-//    // Delete temporary output variables
-//    for( SizeT i = 0; i<nTemp; ++i) {
-//      pro->DelVar( xI--);
-//      callStack[curlevnum-1]->DelEnv();
-//    }
-//
-//    pro->DelVar( xI--);
-//    callStack[curlevnum-1]->DelEnv();
-//
-//    pro->DelVar( xI--);
-//    callStack[curlevnum-1]->DelEnv();
-//
-//    pro->DelVar( xI--);
-//    callStack[curlevnum-1]->DelEnv();
-//
-//    pro->DelVar( xI);
-//    callStack[curlevnum-1]->DelEnv();
-//
-//    if ( doubleFlag) 
-//      return res_d;
-//    else
-//      return res_f;
-//  }
-
 } // namespace
