@@ -29,8 +29,9 @@ using namespace std;
 
 namespace lib {
 
+  // AC 2018 : since 8.4, IDL made change and solved ambiguities related to this problem.
   // important comment: as for Besel family, in IDL, VOIGT([2.],[0,1,2]) !=  VOIGT(2.,[0,1,2])
-  // We don't follow this dangerous situation, we do have   VOIGT([2.],[0,1,2]) ==  VOIGT(2.,[0,1,2])
+  // We now follow this situation in GDL too (see "test_math_function_dim.pro")
 
   BaseGDL* voigt_fun(EnvT* e)
   { 
@@ -40,12 +41,13 @@ namespace lib {
       e->Throw(" function VOIGT takes 2 params: 'Result = VOIGT(A,U)'  ");
 
     DFloatGDL* A = e->GetParAs<DFloatGDL>(0);
-    if(e->GetParDefined(0)->Type() == GDL_COMPLEX || e->GetParDefined(0)->Type() == GDL_COMPLEXDBL)
-      e->Throw(" no complex : ");
+
+    //AC2018    if(e->GetParDefined(0)->Type() == GDL_COMPLEX || e->GetParDefined(0)->Type() == GDL_COMPLEXDBL)
+    // e->Throw(" no complex : ");
     
     DFloatGDL* U = e->GetParAs<DFloatGDL>(1);
-    if(e->GetParDefined(1)->Type() == GDL_COMPLEX || e->GetParDefined(1)->Type() == GDL_COMPLEXDBL)
-      e->Throw(" no complex : ");
+    //AC2018 if(e->GetParDefined(1)->Type() == GDL_COMPLEX || e->GetParDefined(1)->Type() == GDL_COMPLEXDBL)
+    //e->Throw(" no complex : ");
 
     // Use to define NaN which is returned if one parameter of humlik function is Not A Number 
     DStructGDL *Values =  SysVar::Values();   //MUST NOT BE STATIC, due to .reset                                                 
@@ -194,9 +196,16 @@ namespace lib {
 	  }		
       }
 
-    if( e->GetParDefined(0)->Type() == GDL_DOUBLE ||e->GetParDefined(1)->Type() == GDL_DOUBLE ) 
+    // fake Double promotion if needed ...
+    DType t0=e->GetParDefined(0)->Type();
+    DType t1=e->GetParDefined(1)->Type();
+    static DInt doubleKWIx = e->KeywordIx("DOUBLE");
+
+    if (t0 == GDL_DOUBLE || t0 == GDL_COMPLEXDBL ||
+	t1 == GDL_DOUBLE || t1 == GDL_COMPLEXDBL ||
+	e->KeywordSet(doubleKWIx))		
       return res->Convert2(GDL_DOUBLE,BaseGDL::CONVERT);
-    
+
     return res;
 
   } //end of voigt_fun
@@ -259,8 +268,7 @@ namespace lib {
 
     //-------------------------------- Allocation -----------------------------------//
     BaseGDL *Steptwo,*Stepthree,*Stepfour;
-    SizeT i;
-    DDoubleGDL *HH,*H6,*XplusH,*Ytampon,*XH,*Yout,* dym,* dyt;
+    DDoubleGDL *HH,*H6,*XplusH,*Ytampon,*XH,*Yout,*dym,*dyt;
 
     Ytampon = new DDoubleGDL(Yvals->Dim(),BaseGDL::NOZERO);
     Yout = new DDoubleGDL(Yvals->Dim(),BaseGDL::NOZERO);
@@ -304,7 +312,7 @@ namespace lib {
 	funIx = GDLInterpreter::GetFunIx(RK_Diff );
 	
 	//-----------------FIRST STEP-------------------//
-	for (i=0;i<Yvals->N_Elements();++i)
+	for (SizeT i=0;i<Yvals->N_Elements();++i)
 	  (*Ytampon)[i]=(*Yvals)[i]+(*HH)[0]*(*dydxvals)[i]; 
 
 	BaseGDL* Ytmp=static_cast<BaseGDL*>(Ytampon);
@@ -318,13 +326,10 @@ namespace lib {
 	  
 	//Conversion BaseGDL*-> DDoubleGDL* in order to use the RK_Diff function result.
 	dyt= static_cast<DDoubleGDL*>(Steptwo->Convert2(GDL_DOUBLE,BaseGDL::CONVERT));
-	  
-	  
 
 	//-------------SECOND STEP-------------------//	
-	for (i=0;i<Yvals->N_Elements();++i)
+	for (SizeT i=0;i<Yvals->N_Elements();++i)
 	  (*Ytampon)[i]=(*Yvals)[i]+(*HH)[0]*(*dyt)[i];
-
 	  	  
 	//  2nd CALL to user function "differentiate"
 	PushNewEnvRK(e, funList[ funIx],&XHO,&Ytmp);	
@@ -338,12 +343,11 @@ namespace lib {
 	  
 	  
 	//--------------THIRD STEP-------------------//
-	for (i=0;i<Yvals->N_Elements();++i)
+	for (SizeT i=0;i<Yvals->N_Elements();++i)
 	  {
 	    (*Ytampon)[i]=(*Yvals)[i]+ (*H)[0]*(*dym)[i];
 	    (*dym)[i] += (*dyt)[i];
 	  }
-
 	  
 	// 3rd CALL to user function "differentiate"
 	PushNewEnvRK(e, funList[ funIx],&XplusHO,&Ytmp);
@@ -355,7 +359,7 @@ namespace lib {
 	dyt= static_cast<DDoubleGDL*>(Stepfour->Convert2(GDL_DOUBLE,BaseGDL::CONVERT));
 	  
 	//--------------FOURTH STEP-------------------//
-	for (i=0;i<Yvals->N_Elements();++i)
+	for (SizeT i=0;i<Yvals->N_Elements();++i)
 	  (*Yout)[i]= (*Yvals)[i] + (*H6)[0] * ( (*dydxvals)[i]+(*dyt)[i]+ 2.00000*(*dym)[i] );
 	  
 	static int doubleKWIx = e->KeywordIx("DOUBLE");
