@@ -43,36 +43,6 @@ namespace lib {
 		  long int *machep, long int *negep, long int *iexp, long int *minexp,
 		  long int *maxexp, double *eps, double *epsneg, double *xmin, double *xmax );
 
-#ifdef USE_LIBPROJ4
-#define GDL_COMPLEX COMPLEX2
-
-#ifdef USE_LIBPROJ4_NEW
-#define PROJTYPE PROJ
-#define LPTYPE PROJ_LP
-#define XYTYPE PROJ_XY
-#define PJ_INIT proj_init
-#define PJ_FWD proj_fwd
-#define PJ_INV proj_inv
-#else
-#define PROJTYPE PJ
-#define LPTYPE LP
-#define XYTYPE XY
-#define PJ_INIT pj_init
-#define PJ_FWD pj_fwd
-#define PJ_INV pj_inv
-#endif
-
-extern "C" {
-#include "lib_proj.h"
-}
-
-  PROJTYPE *map_init();
-  static PROJTYPE *ref;
-  static PROJTYPE *prev_ref;
-
-#define COMPLEX2 GDL_COMPLEX
-#endif
-
 #ifdef _MSC_VER
 #  define isinf !_finite
 #  define isfinite _finite
