@@ -41,7 +41,9 @@
 namespace lib {
 
   using namespace std;
+#ifndef _MSC_VER
   using std::isnan;
+#endif
 
   //const int szdbl=sizeof(double);
   //const int szflt=sizeof(float);
@@ -55,6 +57,11 @@ namespace lib {
 ************************************************************/
   BaseGDL* la_cholsol_fun ( EnvT* e)
   {
+    
+    Message("We have troubles related to LA_CHOLDC/LA_CHOLSOL and Eigen");
+    Message("Help and contributions very welcome");
+    Message(" ");
+    
     //    set_num_threads();
 
     SizeT nParam=e->NParam(2);
@@ -87,7 +94,8 @@ namespace lib {
    long NbCol,NbRow;
 
 /*************************Double**************************************/
-    if(( p0->Type() == GDL_DOUBLE) || e->KeywordSet("DOUBLE"))
+    static int DOUBLEIx=e->KeywordIx("DOUBLE");
+    if(( p0->Type() == GDL_DOUBLE) || e->KeywordSet(DOUBLEIx))
       {
 
 	DDoubleGDL* p0D = static_cast<DDoubleGDL*>
@@ -125,9 +133,6 @@ namespace lib {
   }
 
 
-
-
-
 /***********************************************************
 ********************Cholesky_Solution***********************
 ************************************************************/
@@ -138,9 +143,9 @@ namespace lib {
     //    set_num_threads();
     
     SizeT nParam=e->NParam(3);
-    BaseGDL* p0 = e->GetParDefined( 0);
-    BaseGDL* p1 = e->GetParDefined( 1);
-    BaseGDL* p2 = e->GetParDefined( 2);
+    BaseGDL* p0 = e->GetNumericParDefined( 0);
+    BaseGDL* p1 = e->GetNumericParDefined( 1);
+    BaseGDL* p2 = e->GetNumericParDefined( 2);
 
 /*********************************Checking_if_arguments_are_OK*********************/   
 
@@ -171,7 +176,8 @@ namespace lib {
 
 
 /*************************Double**************************************/
-    if(( p0->Type() == GDL_DOUBLE) || e->KeywordSet("DOUBLE"))
+    static int DOUBLEIx=e->KeywordIx("DOUBLE");
+    if(( p0->Type() == GDL_DOUBLE) || e->KeywordSet(DOUBLEIx))
       {
 
 	DDoubleGDL* p0D = static_cast<DDoubleGDL*>
@@ -205,7 +211,7 @@ namespace lib {
       }
 
 /*************************Complex**************************************/
-    if( p0->Type() == GDL_COMPLEX && !e->KeywordSet("DOUBLE")) 
+    if( p0->Type() == GDL_COMPLEX && !e->KeywordSet(DOUBLEIx)) 
       {
 
       DComplexGDL* p0C = static_cast<DComplexGDL*>
@@ -357,6 +363,11 @@ namespace lib {
 ************************************************************/
 void la_choldc_pro( EnvT* e) 
   {
+
+    Message("We have troubles related to LA_CHOLDC/LA_CHOLSOL and Eigen");
+    Message("Help and contributions very welcome");
+    Message(" ");
+
     SizeT    nParam = e->NParam(1);
     BaseGDL* p0     = e->GetParDefined( 0);
     SizeT    nEl    = p0->N_Elements();
@@ -377,9 +388,10 @@ void la_choldc_pro( EnvT* e)
 
 
     long NbCol,NbRow;
-
+    static int DOUBLEIx=e->KeywordIx("DOUBLE");
+    static int UPPERIx=e->KeywordIx("UPPER");
 /*************************Complex_Double**************************************/
-    if( p0->Type() == GDL_COMPLEXDBL || (p0->Type() == GDL_COMPLEX && e->KeywordSet("DOUBLE"))) {
+    if( p0->Type() == GDL_COMPLEXDBL || (p0->Type() == GDL_COMPLEX && e->KeywordSet(DOUBLEIx))) {
 
       DComplexDblGDL* p0C = static_cast<DComplexDblGDL*>
 	(p0->Convert2(GDL_COMPLEXDBL , BaseGDL::COPY));
@@ -388,7 +400,7 @@ void la_choldc_pro( EnvT* e)
       Map<Matrix<complex<double>,Dynamic,Dynamic> > m0(&(*p0C)[0], NbCol,NbRow);
       MatrixXcd tmp_res;
 
-      if(e->KeywordSet("UPPER"))
+      if(e->KeywordSet(UPPERIx))
 	{
 	  LLT<MatrixXcd,Upper>solver;
 	  solver.compute(m0);
@@ -427,7 +439,7 @@ void la_choldc_pro( EnvT* e)
       Map<Matrix<complex<float>,Dynamic,Dynamic> > m0(&(*p0C)[0], NbCol,NbRow);
       MatrixXcf tmp_res;
 
-      if(e->KeywordSet("UPPER"))
+      if(e->KeywordSet(UPPERIx))
 	{
 	  LLT<MatrixXcf,Upper>solver;
 	  solver.compute(m0);
@@ -456,7 +468,7 @@ void la_choldc_pro( EnvT* e)
     }
 
 /*************************Double**************************************/
-    else  if(( p0->Type() == GDL_DOUBLE) || e->KeywordSet("DOUBLE")) {
+    else  if(( p0->Type() == GDL_DOUBLE) || e->KeywordSet(DOUBLEIx)) {
       
       DDoubleGDL* p0D = static_cast<DDoubleGDL*>
 	(p0->Convert2( GDL_DOUBLE, BaseGDL::COPY));
@@ -465,7 +477,7 @@ void la_choldc_pro( EnvT* e)
       Map<Matrix<double,Dynamic,Dynamic> > m0(&(*p0D)[0], NbCol,NbRow);
       MatrixXd tmp_res;   
 
-      if(e->KeywordSet("UPPER"))
+      if(e->KeywordSet(UPPERIx))
 	{
 	  LLT<MatrixXd,Upper>solver;
 	  solver.compute(m0);
@@ -510,7 +522,7 @@ void la_choldc_pro( EnvT* e)
 	Map<Matrix<float,Dynamic,Dynamic> > m0(&(*p0SS)[0], NbCol,NbRow);
 	MatrixXf tmp_res;
 
-	if(e->KeywordSet("UPPER"))
+	if(e->KeywordSet(UPPERIx))
 	  {
 	    LLT<MatrixXf,Upper>solver;
 	    solver.compute(m0);
@@ -550,12 +562,9 @@ void la_choldc_pro( EnvT* e)
   void choldc_pro( EnvT* e) 
   {
 
-    //#if defined _OPENMP 
-    // set_num_threads();
-    //#endif
-    // BaseGDL* p0 = e->GetNumericArrayParDefined( 0);
-    BaseGDL* p0 = e->GetParDefined( 0);
-    //         BaseGDL* p0 = e->GetPar( 0);
+    BaseGDL* p0 = e->GetNumericParDefined( 0);
+    //BaseGDL* p0 = e->GetParDefined( 0);
+
     SizeT nParam=e->NParam(2);
     long singular=0;
     SizeT nEl = p0->N_Elements();
@@ -579,10 +588,10 @@ void la_choldc_pro( EnvT* e)
     long NbCol,NbRow;
 
     //   cout <<  p0->Type() << endl;
-
+    static int DOUBLEIx=e->KeywordIx("DOUBLE");
 
 /*************************Complex**************************************/
-    if( p0->Type() == GDL_COMPLEX && !e->KeywordSet("DOUBLE")) {
+    if( p0->Type() == GDL_COMPLEX && !e->KeywordSet(DOUBLEIx)) {
       DComplexGDL* p0C = static_cast<DComplexGDL*>
 	(p0->Convert2(GDL_COMPLEX , BaseGDL::COPY));  
       NbCol=p0->Dim(0);
@@ -654,7 +663,7 @@ void la_choldc_pro( EnvT* e)
     }
 
 /*************************Double**************************************/
-    else  if(( p0->Type() == GDL_DOUBLE) || e->KeywordSet("DOUBLE")) {
+    else  if(( p0->Type() == GDL_DOUBLE) || e->KeywordSet(DOUBLEIx)) {
       
       DDoubleGDL* p0D = static_cast<DDoubleGDL*>
 	(p0->Convert2( GDL_DOUBLE, BaseGDL::COPY));
@@ -749,43 +758,43 @@ void la_choldc_pro( EnvT* e)
 
 
 
-
-  template< typename T>
-  int cp2data_template( BaseGDL* p0, T* data, SizeT nEl, 
-			SizeT offset, SizeT stride_in, SizeT stride_out)
-  {
-    switch ( p0->Type()) {
-    case GDL_DOUBLE: 
-      cp2data2_template< DDoubleGDL, T>( p0, data, nEl, offset, 
-					 stride_in, stride_out);
-      break;
-    case GDL_FLOAT: 
-      cp2data2_template< DFloatGDL, T>( p0, data, nEl, offset, 
-					stride_in, stride_out);
-      break;
-    case GDL_LONG:
-      cp2data2_template< DLongGDL, T>( p0, data, nEl, offset, 
-				       stride_in, stride_out);
-      break;
-    case GDL_ULONG: 
-      cp2data2_template< DULongGDL, T>( p0, data, nEl, offset, 
-					stride_in, stride_out);
-      break;
-    case GDL_INT: 
-      cp2data2_template< DIntGDL, T>( p0, data, nEl, offset, 
-				      stride_in, stride_out);
-      break;
-    case GDL_UINT: 
-      cp2data2_template< DUIntGDL, T>( p0, data, nEl, offset, 
-				       stride_in, stride_out);
-      break;
-    case GDL_BYTE: 
-      cp2data2_template< DByteGDL, T>( p0, data, nEl, offset, 
-				       stride_in, stride_out);
-      break;
-    }
-    return 0;
-  }
+// UNUSED, copy of gsl_fun: bad habit!
+//  template< typename T>
+//  int cp2data_template( BaseGDL* p0, T* data, SizeT nEl, 
+//			SizeT offset, SizeT stride_in, SizeT stride_out)
+//  {
+//    switch ( p0->Type()) {
+//    case GDL_DOUBLE: 
+//      cp2data2_template< DDoubleGDL, T>( p0, data, nEl, offset, 
+//					 stride_in, stride_out);
+//      break;
+//    case GDL_FLOAT: 
+//      cp2data2_template< DFloatGDL, T>( p0, data, nEl, offset, 
+//					stride_in, stride_out);
+//      break;
+//    case GDL_LONG:
+//      cp2data2_template< DLongGDL, T>( p0, data, nEl, offset, 
+//				       stride_in, stride_out);
+//      break;
+//    case GDL_ULONG: 
+//      cp2data2_template< DULongGDL, T>( p0, data, nEl, offset, 
+//					stride_in, stride_out);
+//      break;
+//    case GDL_INT: 
+//      cp2data2_template< DIntGDL, T>( p0, data, nEl, offset, 
+//				      stride_in, stride_out);
+//      break;
+//    case GDL_UINT: 
+//      cp2data2_template< DUIntGDL, T>( p0, data, nEl, offset, 
+//				       stride_in, stride_out);
+//      break;
+//    case GDL_BYTE: 
+//      cp2data2_template< DByteGDL, T>( p0, data, nEl, offset, 
+//				       stride_in, stride_out);
+//      break;
+//    }
+//    return 0;
+//  }
 
 #endif
 } //namespace lib
