@@ -28,19 +28,17 @@
 #include <fstream>
 #include <memory>
 #include <algorithm>
-#include <gsl/gsl_sys.h>
-#include <gsl/gsl_linalg.h>
-#include <gsl/gsl_sf.h>
-#include <netcdfcpp.h>
+
+#include <netcdf.h>
 
 #include "datatypes.hpp"
-#include "math_utl.hpp"
 #include "envt.hpp"
 #include "dpro.hpp"
 #include "dinterpreter.hpp"
+
 #include "ncdf_cl.hpp"
-#include "terminfo.hpp"
-#include "typedefs.hpp"
+//#include "terminfo.hpp"
+//#include "typedefs.hpp"
 
 
 
@@ -57,27 +55,10 @@ namespace lib {
   
   void exceed_message(const char * name,int index, int set)
   {
-    int mema=3;
     string mess;
     mess=name;
-    mess+="Limit exceeded on index ";
-    char * n=new char(mema);
-    while (snprintf(n, sizeof n, "%d", index) >= sizeof n)
-      {   delete n; mema++; n=new char(mema);
-      }
-    mess+=n;
-    delete n;
-    
-    mess+=", setting to ";
-    mema=3;
-    n=new char(mema);
-    while (snprintf(n, sizeof n, "%d", set) >= sizeof n)
-      {
-	delete n;mema++; n=new char(mema);
-      }
-    mess+=n;
-    delete n;
-    mess+=".";
+    mess+="Limit exceeded on index "+i2s(index);
+    mess+=", setting to "+i2s(set)+".";
     Message(mess);
 
   }
@@ -87,28 +68,14 @@ namespace lib {
     int mema=3;
     string mess;
     mess=name;
-    mess+="Value of index";
-    char * n=new char(mema);
-    while (snprintf(n, sizeof n, "%d", index) >= sizeof n)
-      {   delete n; mema++; n=new char(mema);
-      }
-    mess+=n;
-    delete n;
+    mess+="Value of index "+i2s(index);
     if(set > 0) 
       mess+=" is negative or zero, setting to ";
     else if(set == 0) 
       mess+=" is negative , setting to ";
     else
       mess+=" INTERNAL ERROR NCDF_VAR_CL.CPP negzero_message";
-    
-    mema=3;
-    n=new char(mema);
-    while (snprintf(n, sizeof n, "%d", set) >= sizeof n)
-      {
-	delete n;mema++; n=new char(mema);
-      }
-    mess+=n;
-    delete n;
+    mess+=i2s(set);
     mess+=".";
     Message(mess);
 
@@ -118,6 +85,7 @@ namespace lib {
   template <typename T> 
   void ncdf_var_handle_error(EnvT *e, int status, const char *function, T *data)
   {
+//    cout << function << endl;
     if (data != NULL and status != NC_NOERR) GDLDelete(data);
     ncdf_handle_error(e, status, function);
   }
@@ -489,14 +457,19 @@ else if(var_type == NC_LONG)
       {
         DByteGDL* temp=new DByteGDL(dim,BaseGDL::NOZERO);
         status=nc_get_var_uchar(cdfid, varid, &(*temp)[0]);
-        ncdf_var_handle_error(e,status,"NCDF_VARGET", temp);
-        GDLDelete(e->GetParGlobal(2));  
+	if (status != NC_ERANGE) {
+	  ncdf_var_handle_error(e,status,"NCDF_VARGET (ici)", temp);
+	} else {
+	  Warning("Warning in NCDF_VARGET: NC_ERANGE during BYTE reading");
+	  ncdf_var_handle_error(e,status,"NCDF_VARGET (ici)", temp);
+	}
+	GDLDelete(e->GetParGlobal(2));  
         e->GetParGlobal(2)=temp;      	
       } 
       else if (var_type == NC_CHAR)
       {
         DByteGDL* temp = new DByteGDL(dim, BaseGDL::NOZERO);
-        status = nc_get_var_uchar(cdfid, varid, &(*temp)[0]);
+        status = nc_get_var_text(cdfid, varid, (char*) &(*temp)[0]);
         ncdf_var_handle_error(e, status, "NCDF_VARGET", temp);
         GDLDelete(e->GetParGlobal(2));
         e->GetParGlobal(2) = temp;
@@ -618,7 +591,7 @@ else if(var_type == NC_LONG)
         else if (var_type == NC_CHAR)
         {
           DByteGDL *temp = new DByteGDL(dim, BaseGDL::NOZERO);
-          status = nc_get_vara_uchar(cdfid, varid, off, cou, &(*temp)[0]);
+          status = nc_get_vara_text(cdfid, varid, off, cou, (char*) &(*temp)[0]);
           ncdf_var_handle_error(e, status, "NCDF_VARGET", temp);
           GDLDelete(e->GetParGlobal(2));
           e->GetParGlobal(2) = temp;
@@ -660,22 +633,9 @@ else if(var_type == NC_LONG)
               int mema=3;
               string mess;
               mess = "NCDF_VARGET: Requested read is larget than data in dimension ";
-              char * n=new char(mema);
-              while (snprintf(n, sizeof n, "%d", i) >= sizeof n)
-              {
-                delete n; mema++; n=new char(mema);
-              }
-              mess+=n;
-              delete n;
+              mess+=i2s(i);
               mess+=". Reducing COUNT to ";
-              mema=3;
-              n=new char[3];
-              while (snprintf(n, sizeof n, "%d",  cou[trans[i]]) >= sizeof n)
-              { 
-                delete n; mema++; n=new char(mema);
-              }
-              mess+=n;
-              delete n;
+              mess+=i2s(cou[trans[i]]);
               mess+=".";
               Message(mess);
             }	
@@ -734,7 +694,7 @@ else if(var_type == NC_LONG)
         else if (var_type == NC_CHAR)
         {
           DByteGDL *temp = new DByteGDL(dim, BaseGDL::NOZERO);
-          status = nc_get_vars_uchar(cdfid, varid, off, cou, stri, &(*temp)[0]);
+          status = nc_get_vars_text(cdfid, varid, off, cou, stri, (char*) &(*temp)[0]);
           ncdf_var_handle_error(e, status, "NCDF_VARGET", temp);
           GDLDelete(e->GetParGlobal(2));
           e->GetParGlobal(2) = temp;      	
@@ -764,12 +724,12 @@ else if(var_type == NC_LONG)
       {
 	v=e->GetParDefined(2);
 	DIntGDL* dim_in=static_cast<DIntGDL*>(v->Convert2(GDL_INT, BaseGDL::COPY));
-	auto_ptr<DIntGDL> dim_in_guard( dim_in);
+	Guard<DIntGDL> dim_in_guard( dim_in);
 	var_ndims=dim_in->N_Elements();
 	if(var_ndims > NC_MAX_VAR_DIMS)
 	  {
 	    throw GDLException(e->CallingNode(),
-			       "Too many elements error 1 in array"				       +e->GetParString(0));
+			       "Too many elements error 1 in array"+e->GetParString(0));
 	  }					      
 
 	for (i=0; i<var_ndims;++i)
@@ -962,7 +922,7 @@ else if(var_type == NC_LONG)
       }
     }
 
-    int total = 1;
+    long total = 1;
 	  
     if (e->GetKW(0) != NULL)
     {
@@ -1042,32 +1002,37 @@ else if(var_type == NC_LONG)
       case GDL_ULONG64 :
       {
         BaseGDL* val;
-        auto_ptr<BaseGDL> val_guard(val);
+        Guard<BaseGDL> val_guard;
         switch (var_type) 
         {
           case NC_BYTE :   // 8-bit signed integer
           case NC_SHORT :  // 16-bit signed integer
             val = v->Convert2(GDL_INT, BaseGDL::COPY);
+	    val_guard.Init(val);
             status = nc_put_vars_short(cdfid, varid, offset, count, stride,
               &((*static_cast<DIntGDL*>(val))[0])); 
             break;
           case NC_CHAR :   // 8-bit unsigned integer
             val = v->Convert2(GDL_BYTE, BaseGDL::COPY);
+	    val_guard.Init(val);
             status = nc_put_vars_uchar(cdfid, varid, offset, count, stride,
               &((*static_cast<DByteGDL*>(val))[0])); 
             break;
           case NC_INT :    // 32-bit signed integer
             val = v->Convert2(GDL_LONG, BaseGDL::COPY);
+	    val_guard.Init(val);
             status = nc_put_vars_int(cdfid, varid, offset, count, stride,
               &((*static_cast<DLongGDL*>(val))[0]));
             break;
           case NC_FLOAT :  // 32-bit floating point
             val = v->Convert2(GDL_FLOAT, BaseGDL::COPY);
+	    val_guard.Init(val);
             status = nc_put_vars_float(cdfid, varid, offset, count, stride, 
               &((*static_cast<DFloatGDL*>(val))[0]));
             break;
           case NC_DOUBLE : // 64-bit floating point
             val = v->Convert2(GDL_DOUBLE, BaseGDL::COPY);
+	    val_guard.Init(val);
             status = nc_put_vars_double(cdfid, varid, offset, count, stride,
               &((*static_cast<DDoubleGDL*>(val))[0]));
             break;
@@ -1088,6 +1053,9 @@ else if(var_type == NC_LONG)
       case GDL_OBJ : 
         e->Throw("Object reference expression not allowed in this context: " 
           + e->GetParString(2));
+      default:
+        e->Throw("GDL internal error, please report!" 
+          + e->GetParString(2));
     }
     ncdf_handle_error(e, status, "NCDF_VARPUT");
   }
