@@ -37,6 +37,7 @@
 // extern DInterpreter* interpreter;
 
 const std::string GDL_OBJECT_NAME("GDL_OBJECT");
+const std::string GDL_CONTAINER_NAME("GDL_CONTAINER");
 
 extern VarListT      sysVarList;
 extern VarListT      sysVarRdOnlyList;
@@ -63,6 +64,13 @@ extern DLong64 CpuTPOOL_MAX_ELTS;
 
 // signals if control-c was pressed
 extern volatile bool sigControlC;
+
+// tells if wxwidgets backend for graphics is to be used...
+extern volatile bool useWxWidgetsForGraphics;
+
+//do we favor SIMD-accelerated random number generation?
+extern volatile bool useDSFMTAcceleration;
+
 extern          int  debugMode;
 
 enum DebugCode {
@@ -101,12 +109,18 @@ void SetStrict(bool value);
 bool BigEndian();
 
 int get_suggested_omp_num_threads();
+int currentNumberOfThreads();
+int currentThreadNumber();
 
 template <typename T> class RefHeap {
   private:
     T* ptr;
     SizeT count;
-      
+    // 2016.05.13 GJ:
+    bool doSave; // IDL 6.1 flag whether to include in a SAVE operation (HEAP_SAVE)
+    // access via HEAP_SAVE( Heapvars) and HEAP_NOSAVE( Heapvars [,SET=[0/1]])
+    bool enableGC;   // IDL 8.0 flag whether to perform automatic garbage collection 
+    // access via HEAP_REFCOUNT([,/ENABLE] [,/DISABLE] [,IS_ENABLED=])
     // prevent usage
     RefHeap<T>& operator=(const RefHeap<T>& other) {	return *this;}
     template<class newType> operator RefHeap<newType>() {return RefHeap<newType>(ptr);}
@@ -116,16 +130,22 @@ template <typename T> class RefHeap {
 
     SizeT Count() const { return count;}
 
+	bool IsEnabledGC() const {	return enableGC; }
+	void EnableGC( bool set=true) { enableGC = set; }
+	
+	bool IsEnabledSave() const { return doSave; }
+	void EnableSave( bool set=true) { doSave = set; }
+	
     void Inc() {++count;}
     void Add( SizeT add) {count += add;}
     bool Dec() {assert(count > 0); return (--count==0);}
 
     RefHeap(T* p = 0)
-    : ptr(p), count(1)
+    : ptr(p), count(1), doSave(false), enableGC(true)
     {}
 
     RefHeap( const RefHeap<T>& other)
-    : ptr( other.ptr), count( other.count) 
+    : ptr( other.ptr), count( other.count),  doSave( other.doSave), enableGC( other.enableGC)
     {}
 
     ~RefHeap()
@@ -154,6 +174,7 @@ namespace structDesc {
   // one can still use these as they get updated on every new creation in InitStructs()
   extern DStructDesc* LIST;
   extern DStructDesc* HASH;
+  extern DStructDesc* GDL_CONTAINER;
   extern DStructDesc* GDL_CONTAINER_NODE;
   extern DStructDesc* GDL_HASHTABLEENTRY;
   
