@@ -377,6 +377,7 @@ namespace lib {
   PLFLT AutoTick(DDouble x);
   void setIsoPort(GDLGStream* actStream,PLFLT x1,PLFLT x2,PLFLT y1,PLFLT y2,PLFLT aspect);
   void GetMinMaxVal( DDoubleGDL* val, double* minVal, double* maxVal);
+  void GetMinMaxValuesForSubset( DDoubleGDL* val, DDouble &minVal, DDouble &maxVal, SizeT endElement);
   void CheckMargin( GDLGStream* actStream,
                     DFloat xMarginL, DFloat xMarginR, DFloat yMarginB, DFloat yMarginT,
                     PLFLT& xMR, PLFLT& xML, PLFLT& yMB, PLFLT& yMT);
@@ -1203,12 +1204,12 @@ namespace lib {
     DFloat xMarginL, xMarginR, yMarginB, yMarginT;
     gdlGetDesiredAxisMargin(e, "X", xMarginL, xMarginR);
     gdlGetDesiredAxisMargin(e, "Y", yMarginB, yMarginT);
-    PLFLT sclx=actStream->nCharLength(); //current char width
-    xML=xMarginL*sclx; //margin as percentage of subpage
-    xMR=xMarginR*sclx;
-    PLFLT scly=actStream->nLineSpacing();
-    yMB=(yMarginB)*scly;
-    yMT=(yMarginT)*scly;
+    PLFLT scl=actStream->nCharLength(); //current char width
+    xML=xMarginL*scl; //margin as percentage of subpage
+    xMR=xMarginR*scl;
+    scl=actStream->nCharHeight(); //current char height
+    yMB=(yMarginB)*scl;
+    yMT=(yMarginT)*scl;
 
     if ( xML+xMR>=1.0 )
     {
@@ -1241,9 +1242,9 @@ namespace lib {
     {
         //compute position removing margins
         positionP[0]=regionP[0]+xMarginL*actStream->nCharLength();
-        positionP[1]=regionP[1]+yMarginB*actStream->nLineSpacing();//nCharHeight();
+        positionP[1]=regionP[1]+yMarginB*actStream->nCharHeight();
         positionP[2]=regionP[2]-xMarginR*actStream->nCharLength();
-        positionP[3]=regionP[3]-yMarginT*actStream->nLineSpacing();//nCharHeight();
+        positionP[3]=regionP[3]-yMarginT*actStream->nCharHeight();
     }
     //compatibility: Position NEVER outside [0,1]:
     positionP[0]=max(0.0,positionP[0]);
@@ -1328,9 +1329,9 @@ namespace lib {
     //compute world Charsize
     PLFLT xb, xe, yb, ye;
     xb=xmin-xMarginL*actStream->wCharLength();
-    xe=xmax+xMarginR*actStream->wLineSpacing();
+    xe=xmax+xMarginR*actStream->wCharLength();
     yb=ymin-yMarginB*actStream->wCharHeight();
-    ye=ymax-yMarginT*actStream->wLineSpacing();
+    ye=ymax-yMarginT*actStream->wCharHeight();
     actStream->wind(xb, xe, yb, ye);
 
 
@@ -1826,18 +1827,14 @@ namespace lib {
         data.nchars=0;
         data.TickName=TickName;
         data.nTickName=TickName->N_Elements();
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( gdlSingleAxisTickNamedFunc, &data );
         Opt+="o";
-#endif
         if (modifierCode==2) Opt+="m"; else Opt+="n";
         if (axis=="X") a->box(Opt.c_str(), TickInterval, Minor, "", 0.0, 0);
         else if (axis=="Y") a->box("", 0.0 ,0.0, Opt.c_str(), TickInterval, Minor);
         nchars=data.nchars;
         if (axis=="Y") title_position=nchars+2.5; else title_position=3.5;
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( NULL, NULL );
-#endif
       }
       //care Tickunits size is 10 if not defined because it is the size of !X.TICKUNITS.
       else if (hasTickUnitDefined) // /TICKUNITS=[several types of axes written below each other]
@@ -1852,10 +1849,8 @@ namespace lib {
         }
         muaxdata.TickUnits=TickUnits;
         muaxdata.nTickUnits=tickUnitArraySize;
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( gdlMultiAxisTickFunc, &muaxdata );
         Opt+="o";otherOpt+="o"; //use external func custom labeling
-#endif
         if (modifierCode==2) {Opt+="m"; otherOpt+="m";} else {Opt+="n"; otherOpt+="n";} //m: write numerical/right above, n: below/left (normal)
         PLFLT un,deux,trois,quatre,xun,xdeux,xtrois,xquatre;
         a->getCurrentNormBox(un,deux,trois,quatre);
@@ -1887,9 +1882,7 @@ namespace lib {
         }
         a->vpor(un,deux,trois,quatre);
         a->wind(xun,xdeux,xtrois,xquatre);
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( NULL, NULL );
-#endif
       }
       else if (TickFormat->NBytes()>0) //no /TICKUNITS=> only 1 value taken into account
       {
@@ -1898,34 +1891,26 @@ namespace lib {
         muaxdata.what=GDL_TICKFORMAT;
         muaxdata.TickFormat=TickFormat;
         muaxdata.nTickFormat=1;
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( gdlMultiAxisTickFunc, &muaxdata );
         Opt+="o";
-#endif
         if (modifierCode==2) Opt+="m"; else Opt+="n";
         if (axis=="X") a->box(Opt.c_str(), TickInterval, Minor, "", 0.0, 0);
         else if (axis=="Y") a->box("", 0.0 ,0.0, Opt.c_str(), TickInterval, Minor);
         nchars=muaxdata.nchars;
         if (axis=="Y") title_position=nchars+2; else title_position=3.5;
-#if (HAVE_PLPLOT_SLABELFUNC)        
         a->slabelfunc( NULL, NULL );
-#endif
       }
       else
       {
-#if (HAVE_PLPLOT_SLABELFUNC)
         tdata.nchars=0;
         a->slabelfunc( gdlSimpleAxisTickFunc, &tdata );
         Opt+="o";
-#endif
         if (modifierCode==2) Opt+="m"; else Opt+="n";
         if (axis=="X") a->box(Opt.c_str(), TickInterval, Minor, "", 0.0, 0);
         else if (axis=="Y") a->box("", 0.0 ,0.0, Opt.c_str(), TickInterval, Minor);
         nchars=tdata.nchars;
         if (axis=="Y") title_position=nchars+2; else title_position=3.5;
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( NULL, NULL );
-#endif
       }
 
       if (modifierCode==0 ||modifierCode==1)
@@ -2113,16 +2098,12 @@ namespace lib {
         data.counter=0;
         data.TickName=TickName;
         data.nTickName=TickName->N_Elements();
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( gdlSingleAxisTickNamedFunc, &data );
         Opt+="o";
-#endif
         if      (axis=="X") a->box3(Opt.c_str(), "" , TickInterval, Minor, "", "", 0.0, 0, "", "", 0.0, 0);
         else if (axis=="Y") a->box3("", "", 0.0 ,0.0, Opt.c_str(),"", TickInterval, Minor, "", "", 0.0, 0);
         else if (doZ) if (axis=="Z") a->box3("", "", 0.0, 0, "", "", 0.0, 0, Opt.c_str(), "", TickInterval, Minor);
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( NULL, NULL );
-#endif
       }
       //care Tickunits size is 10 if not defined because it is the size of !X.TICKUNITS.
       else if (hasTickUnitDefined) // /TICKUNITS=[several types of axes written below each other]
@@ -2137,10 +2118,8 @@ namespace lib {
         }
         muaxdata.TickUnits=TickUnits;
         muaxdata.nTickUnits=tickUnitArraySize;
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( gdlMultiAxisTickFunc, &muaxdata );
         Opt+="o";
-#endif
         for (SizeT i=0; i< muaxdata.nTickUnits; ++i) //loop on TICKUNITS axis
         {
 // no equivalent in 3d yet...
@@ -2154,9 +2133,7 @@ namespace lib {
 //          a->plstream::wind(xun,xdeux,xtrois,xquatre);
             muaxdata.counter++;
         }
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( NULL, NULL );
-#endif
       }
       else if (TickFormat->NBytes()>0) //no /TICKUNITS=> only 1 value taken into account
       {
@@ -2164,30 +2141,22 @@ namespace lib {
         muaxdata.what=GDL_TICKFORMAT;
         muaxdata.TickFormat=TickFormat;
         muaxdata.nTickFormat=1;
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( gdlMultiAxisTickFunc, &muaxdata );
         Opt+="o";
-#endif
         if      (axis=="X") a->box3(Opt.c_str(), "", TickInterval, Minor, "", "", 0.0, 0, "", "", 0.0, 0);
         else if (axis=="Y") a->box3("", "", 0.0 ,0.0, Opt.c_str(),"", TickInterval, Minor, "", "", 0.0, 0);
         else if (doZ) if (axis=="Z") a->box3("", "", 0.0, 0, "", "", 0.0, 0, Opt.c_str(), "", TickInterval, Minor);
         
-#if (HAVE_PLPLOT_SLABELFUNC)        
         a->slabelfunc( NULL, NULL );
-#endif
       }
       else
       {
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( gdlSimpleAxisTickFunc, &tdata );
         Opt+="o";
-#endif
         if      (axis=="X") a->box3(Opt.c_str(), "", TickInterval, Minor, "", "", 0.0, 0, "", "", 0.0, 0);
         else if (axis=="Y") a->box3("", "", 0.0 ,0.0, Opt.c_str(),"", TickInterval, Minor, "", "", 0.0, 0);
         else if (doZ) if (axis=="Z") a->box3("", "", 0.0, 0, "", "", 0.0, 0, Opt.c_str(), "", TickInterval, Minor);
-#if (HAVE_PLPLOT_SLABELFUNC)
         a->slabelfunc( NULL, NULL );
-#endif
       }
 
       if (TickLayout==0)
